/**
 * File customizer.js.
 *
 * Theme Customizer enhancements for a better user experience.
 *
 * Contains handlers to make Theme Customizer preview reload changes asynchronously.
 */

( function( $ ) {

	const travelism_pro_section_lists = ['hero_banner_section','blog_slider_section','blog_featured_post_section','business_service_section','shop_recent_products_section','business_about_section','trending_products_section','blog_cta_section','business_team_section','business_counter_section','blog_popular_post_section','most_read_post_section','northface_jacket_section','featured_section','video_section','wildlife_section','gallery_section','happy_clients_section','logos_section','featured_products_section','subscribe_now_section','articles_section','recent_post_section'];
    travelism_pro_section_lists.forEach( travelism_pro_homepage_scroll_preview );

    function travelism_pro_homepage_scroll_preview(item, index) {
    	// Collect information from customize-controls.js about which panels are opening.
		wp.customize.bind( 'preview-ready', function() {
			
			// Initially hide the theme option placeholders on load.
			$( '.panel-placeholder' ).hide();
			wp.customize.preview.bind( item, function( data ) {
				// Only on the front page.
				if ( ! $( 'body' ).hasClass( 'home' ) ) {
					return;
				}

				// When the section is expanded, show and scroll to the content placeholders, exposing the edit links.
				if ( true === data.expanded ) {
					$('html, body').animate({
				        'scrollTop' : $('#travelism_'+item).position().top
				    });
				} 
			});

		});
 	}

	// Site title and description.
	wp.customize( 'blogname', function( value ) {
		value.bind( function( to ) {
			$( '.site-title a' ).text( to );
		} );
	} );
	wp.customize( 'blogdescription', function( value ) {
		value.bind( function( to ) {
			$( '.site-description' ).text( to );
		} );
	} );

	// Header text color.
	wp.customize( 'header_textcolor', function( value ) {
		value.bind( function( to ) {
			if ( 'blank' === to ) {
				$( '.site-title a, .site-description' ).css( {
					'clip': 'rect(1px, 1px, 1px, 1px)',
					'position': 'absolute'
				} );
			} else {
				$( '.site-title a, .site-description' ).css( {
					'clip': 'auto',
					'position': 'relative'
				} );
				$( '.site-title a, .site-description' ).css( {
					'color': to
				} );
			}
		} );
	} );

	// Header title color.
	wp.customize( 'travelism_pro_theme_options[header_title_color]', function( value ) {
		value.bind( function( to ) {
			if ( 'blank' === to ) {
				$( '.site-title a' ).css( {
					'clip': 'rect(1px, 1px, 1px, 1px)',
					'position': 'absolute'
				} );
			} else {
				$( '.site-title a' ).css( {
					'clip': 'auto',
					'position': 'relative'
				} );
				$( '.site-title a' ).css( {
					'color': to
				} );
			}
		} );
	} );

	// Header tagline color.
	wp.customize( 'travelism_pro_theme_options[header_tagline_color]', function( value ) {
		value.bind( function( to ) {
			if ( 'blank' === to ) {
				$( '.site-description' ).css( {
					'clip': 'rect(1px, 1px, 1px, 1px)',
					'position': 'absolute'
				} );
			} else {
				$( '.site-description' ).css( {
					'clip': 'auto',
					'position': 'relative'
				} );
				$( '.site-description' ).css( {
					'color': to
				} );
			}
		} );
	} );

	// Color scheme.
	wp.customize( 'travelism_pro_theme_options[colorscheme]', function( value ) {
		value.bind( function( to ) {

			// Update color body class.
			$( 'body' )
				.removeClass( 'colors-light colors-dark colors-custom' )
				.addClass( 'colors-' + to );
		});
	});

	// Custom color hue.
	wp.customize( 'travelism_pro_theme_options[colorscheme_hue]', function( value ) {
		value.bind( function( to ) {

			// Update custom color CSS
			var style = $( '#custom-theme-colors' ),
			    color = style.data( 'color' ),
			    css = style.html();
			css = css.split( color ).join( to );
			style.html( css )
			     .data( 'color', to );
		} );
	} );

	//Update the custom additional input field in real time...
	
	//contact_number
	wp.customize( 'travelism_pro_theme_options[contact_number]', function( value ) {
		value.bind( function( to ) {
			$( '.contact-info' ).text( to );
		} );
	} );
	
	//menu_btn_label
	wp.customize( 'travelism_pro_theme_options[menu_btn_label]', function( value ) {
		value.bind( function( to ) {
			$( '#site-navigation .custom-button' ).text( to );
		} );
	} );

	//hero_banner_sub_title
	wp.customize( 'travelism_pro_theme_options[hero_banner_sub_title]', function( value ) {
		value.bind( function( to ) {
			$( '#travelism_hero_banner_section .section-subtitle' ).text( to );
		} );
	} );

	//hero_banner_btn_title
	wp.customize( 'travelism_pro_theme_options[hero_banner_btn_title]', function( value ) {
		value.bind( function( to ) {
			$( '#travelism_hero_banner_section .btn' ).text( to );
		} );
	} );

	//northface_jacket_title
	wp.customize( 'travelism_pro_theme_options[northface_jacket_title]', function( value ) {
		value.bind( function( to ) {
			$( '#travelism_northface_jacket_section .section-title' ).text( to );
		} );
	} );

	//northface_jacket_sub_title
	wp.customize( 'travelism_pro_theme_options[northface_jacket_sub_title]', function( value ) {
		value.bind( function( to ) {
			$( '#travelism_northface_jacket_section .section-subtitle' ).text( to );
		} );
	} );

	//featured_sub_title
	wp.customize( 'travelism_pro_theme_options[featured_sub_title]', function( value ) {
		value.bind( function( to ) {
			$( '#travelism_featured_section .section-subtitle' ).text( to );
		} );
	} );

	//featured_title
	wp.customize( 'travelism_pro_theme_options[featured_title]', function( value ) {
		value.bind( function( to ) {
			$( '#travelism_featured_section .section-title' ).text( to );
		} );
	} );

	//video_sub_title
	wp.customize( 'travelism_pro_theme_options[video_sub_title]', function( value ) {
		value.bind( function( to ) {
			$( '#travelism_video_section .section-subtitle' ).text( to );
		} );
	} );

	//video_title
	wp.customize( 'travelism_pro_theme_options[video_title]', function( value ) {
		value.bind( function( to ) {
			$( '#travelism_video_section .section-title' ).text( to );
		} );
	} );

	//wildlife_sub_title
	wp.customize( 'travelism_pro_theme_options[wildlife_sub_title]', function( value ) {
		value.bind( function( to ) {
			$( '#travelism_wildlife_section .section-subtitle' ).text( to );
		} );
	} );

	//wildlife_btn_label
	wp.customize( 'travelism_pro_theme_options[wildlife_btn_label]', function( value ) {
		value.bind( function( to ) {
			$( '#travelism_wildlife_section .btn' ).text( to );
		} );
	} );

	//gallery_sub_title
	wp.customize( 'travelism_pro_theme_options[gallery_sub_title]', function( value ) {
		value.bind( function( to ) {
			$( '#travelism_gallery_section .section-subtitle' ).text( to );
		} );
	} );

	//gallery_title
	wp.customize( 'travelism_pro_theme_options[gallery_title]', function( value ) {
		value.bind( function( to ) {
			$( '#travelism_gallery_section .section-title' ).text( to );
		} );
	} );

	//gallery_btn_label
	wp.customize( 'travelism_pro_theme_options[gallery_btn_label]', function( value ) {
		value.bind( function( to ) {
			$( '#travelism_gallery_section .btn' ).text( to );
		} );
	} );

	//happy_clients_section_sub_title
	wp.customize( 'travelism_pro_theme_options[happy_clients_section_sub_title]', function( value ) {
		value.bind( function( to ) {
			$( '#travelism_happy_clients_section .section-subtitle' ).text( to );
		} );
	} );

	//happy_clients_section_title
	wp.customize( 'travelism_pro_theme_options[happy_clients_section_title]', function( value ) {
		value.bind( function( to ) {
			$( '#travelism_happy_clients_section .section-title' ).text( to );
		} );
	} );

	//articles_sub_title
	wp.customize( 'travelism_pro_theme_options[articles_sub_title]', function( value ) {
		value.bind( function( to ) {
			$( '#travelism_articles_section .section-subtitle' ).text( to );
		} );
	} );

	//articles_title
	wp.customize( 'travelism_pro_theme_options[articles_title]', function( value ) {
		value.bind( function( to ) {
			$( '#travelism_articles_section .section-title' ).text( to );
		} );
	} );

	//blog_slider_btn_label
	wp.customize( 'travelism_pro_theme_options[blog_slider_btn_label]', function( value ) {
		value.bind( function( to ) {
			$( '#travelism_blog_slider_section .btn-primary' ).text( to );
		} );
	} );

	//blog_popular_post_title
	wp.customize( 'travelism_pro_theme_options[blog_popular_post_title]', function( value ) {
		value.bind( function( to ) {
			$( '#travelism_blog_popular_post_section .section-title' ).text( to );
		} );
	} );

	//most_read_post_title
	wp.customize( 'travelism_pro_theme_options[most_read_post_title]', function( value ) {
		value.bind( function( to ) {
			$( '#travelism_most_read_post_section .section-title' ).text( to );
		} );
	} );

	//recent_post_title
	wp.customize( 'travelism_pro_theme_options[recent_post_title]', function( value ) {
		value.bind( function( to ) {
			$( '#travelism_recent_post_section .section-title' ).text( to );
		} );
	} );

	//business_service_sub_title
	wp.customize( 'travelism_pro_theme_options[business_service_sub_title]', function( value ) {
		value.bind( function( to ) {
			$( '#travelism_business_service_section .section-subtitle' ).text( to );
		} );
	} );

	//business_service_title
	wp.customize( 'travelism_pro_theme_options[business_service_title]', function( value ) {
		value.bind( function( to ) {
			$( '#travelism_business_service_section .section-title' ).text( to );
		} );
	} );

	//business_about_sub_title
	wp.customize( 'travelism_pro_theme_options[business_about_sub_title]', function( value ) {
		value.bind( function( to ) {
			$( '#travelism_business_about_section .section-subtitle' ).text( to );
		} );
	} );

	//business_about_btn_title
	wp.customize( 'travelism_pro_theme_options[business_about_btn_title]', function( value ) {
		value.bind( function( to ) {
			$( '#travelism_business_about_section .btn' ).text( to );
		} );
	} );

	//business_team_sub_title
	wp.customize( 'travelism_pro_theme_options[business_team_sub_title]', function( value ) {
		value.bind( function( to ) {
			$( '#travelism_business_team_section .section-subtitle' ).text( to );
		} );
	} );

	//business_team_title
	wp.customize( 'travelism_pro_theme_options[business_team_title]', function( value ) {
		value.bind( function( to ) {
			$( '#travelism_business_team_section .section-title' ).text( to );
		} );
	} );

	//shop_recent_products_sub_title
	wp.customize( 'travelism_pro_theme_options[shop_recent_products_sub_title]', function( value ) {
		value.bind( function( to ) {
			$( '#travelism_shop_recent_products_section .section-subtitle' ).text( to );
		} );
	} );

	//shop_recent_products_title
	wp.customize( 'travelism_pro_theme_options[shop_recent_products_title]', function( value ) {
		value.bind( function( to ) {
			$( '#travelism_shop_recent_products_section .section-title' ).text( to );
		} );
	} );

	//subscribe_now_title
	wp.customize( 'travelism_pro_theme_options[subscribe_now_title]', function( value ) {
		value.bind( function( to ) {
			$( '#travelism_subscribe_now_section h2.section-title' ).text( to );
		} );
	} );

	//custom field real time color refresh 
	wp.customize( 'travelism_pro_theme_options[menu_bg_color]', function( value ) {
		value.bind( function( to ) {
			$( '.fixed-header #masthead.nav-shrink' ).css( 'background-color', to );
		} );
	} );

	wp.customize( 'travelism_pro_theme_options[menu_item_color]', function( value ) {
		value.bind( function( to ) {
			$( '.main-navigation a, #masthead .custom-button, .main-navigation ul.nav-menu > li > a > svg' ).css( 'color', to );
			$( '.main-navigation a, #masthead .custom-button, .main-navigation ul.nav-menu > li > a > svg' ).css( 'fill', to );
		} );
	} );

	wp.customize( 'travelism_pro_theme_options[menu_no_color]', function( value ) {
		value.bind( function( to ) {
			$( '#masthead .contact-info.clear a, #masthead .contact-info svg' ).css( 'color', to );
			$( '#masthead .contact-info.clear a, #masthead .contact-info svg' ).css( 'fill', to );
		} );
	} );

	wp.customize( 'travelism_pro_theme_options[menu_button_color]', function( value ) {
		value.bind( function( to ) {
			$( '#masthead .custom-button' ).css( 'background-color', to );
			$( '#masthead .custom-button' ).css( 'border-color', to );
		} );
	} );

	wp.customize( 'travelism_pro_theme_options[footer_overlay_color]', function( value ) {
		value.bind( function( to ) {
			$( '#colophon .overlay' ).css( 'background-color', to );
		} );
	} );

	wp.customize( 'travelism_pro_theme_options[footer_bg_color]', function( value ) {
		value.bind( function( to ) {
			$( '#colophon' ).css( 'background-color', to );
		} );
	} );

	wp.customize( 'travelism_pro_theme_options[widget_title_color]', function( value ) {
		value.bind( function( to ) {
			$( '#colophon .widget-title' ).css( 'color', to );
		} );
	} );

	wp.customize( 'travelism_pro_theme_options[footer_social_icon_color]', function( value ) {
		value.bind( function( to ) {
			$( '#colophon .site-info .social-icons li a svg' ).css( 'fill', to );
		} );
	} );

	wp.customize( 'travelism_pro_theme_options[widget_content_color]', function( value ) {
		value.bind( function( to ) {
			$( '#colophon a, #colophon p, #colophon li, .site-footer strong' ).css( 'color', to );
		} );
	} );

	wp.customize( 'travelism_pro_theme_options[banner_image_overlay_color]', function( value ) {
		value.bind( function( to ) {
			$( '#page-site-header .overlay' ).css( 'background-color', to );
		} );
	} );

	wp.customize( 'travelism_pro_theme_options[banner_bg_color]', function( value ) {
		value.bind( function( to ) {
			$( '#page-site-header' ).css( 'background-color', to );
		} );
	} );

		wp.customize( 'travelism_pro_theme_options[breadcrumb_title_color]', function( value ) {
		value.bind( function( to ) {
			$( '#page-site-header .page-title, #breadcrumb-list .trail-items li' ).css( 'color', to );
		} );
	} );
	
	wp.customize( 'travelism_pro_theme_options[breadcrumb_path_color]', function( value ) {
		value.bind( function( to ) {
			$( '#breadcrumb-list .trail-items li a' ).css( 'color', to );
		} );
	} );
	
	wp.customize( 'travelism_pro_theme_options[breadcrumb_alignment]', function( value ) {
		value.bind( function( to ) {
			$( '#page-site-header .wrapper' ).css( 'text-align', to );
		} );
	} );


} )( jQuery );
