<?php
/**
 * Customizer active callbacks
 *
 * @package Theme Palace
 * @subpackage Travelism Pro
 * @since Travelism Pro 1.0.0
 */

if ( ! function_exists( 'travelism_pro_is_loader_enable' ) ) :
	/**
	 * Check if loader is enabled.
	 *
	 * @since Travelism Pro 1.0.0
	 * @param WP_Customize_Control $control WP_Customize_Control instance.
	 * @return bool Whether the control is active to the current preview.
	 */
	function travelism_pro_is_loader_enable( $control ) {
		return $control->manager->get_setting( 'travelism_pro_theme_options[loader_enable]' )->value();
	}
endif;

if ( ! function_exists( 'travelism_pro_is_breadcrumb_enable' ) ) :
	/**
	 * Check if breadcrumb is enabled.
	 *
	 * @since Travelism Pro 1.0.0
	 * @param WP_Customize_Control $control WP_Customize_Control instance.
	 * @return bool Whether the control is active to the current preview.
	 */
	function travelism_pro_is_breadcrumb_enable( $control ) {
		return $control->manager->get_setting( 'travelism_pro_theme_options[breadcrumb_enable]' )->value();
	}
endif;

function travelism_pro_is_banner_image_section_enable( $control ) {
	return ( true === ( $control->manager->get_setting( 'travelism_pro_theme_options[banner_image_enable]' )->value() ));
}

function travelism_pro_is_banner_image_section_disable( $control ) {
	return ( false === ( $control->manager->get_setting( 'travelism_pro_theme_options[banner_image_enable]' )->value() ));
}

if ( ! function_exists( 'travelism_pro_is_pagination_enable' ) ) :
	/**
	 * Check if pagination is enabled.
	 *
	 * @since Travelism Pro 1.0.0
	 * @param WP_Customize_Control $control WP_Customize_Control instance.
	 * @return bool Whether the control is active to the current preview.
	 */
	function travelism_pro_is_pagination_enable( $control ) {
		return $control->manager->get_setting( 'travelism_pro_theme_options[pagination_enable]' )->value();
	}
endif;

if ( ! function_exists( 'travelism_pro_is_static_homepage_enable' ) ) :
	/**
	 * Check if static homepage is enabled.
	 *
	 * @since Travelism Pro 1.0.0
	 * @param WP_Customize_Control $control WP_Customize_Control instance.
	 * @return bool Whether the control is active to the current preview.
	 */
	function travelism_pro_is_static_homepage_enable( $control ) {
		return ( 'page' == $control->manager->get_setting( 'show_on_front' )->value() );
	}
endif;

/**
 * Check if cart_icon section is enabled.
 *
 * @since Travelism Pro 1.0.0
 * @param WP_Customize_Control $control WP_Customize_Control instance.
 * @return bool Whether the control is active to the current preview.
 */
function travelism_pro_is_cart_icon_section_enable( $control ) {
	return ( $control->manager->get_setting( 'travelism_pro_theme_options[menu_button_enable]' )->value() );
}

function travelism_pro_is_menu_sticky_enable( $control ) {
	return ( $control->manager->get_setting( 'travelism_pro_theme_options[menu_sticky]' )->value() );
}

/**
 * Check if footer_section section is enabled.
 *
 * @since Travelism Pro 1.0.0
 * @param WP_Customize_Control $control WP_Customize_Control instance.
 * @return bool Whether the control is active to the current preview.
 */
function travelism_pro_is_footer_section_section_enable( $control ) {
	return ( $control->manager->get_setting( 'travelism_pro_theme_options[footer_copyright_enable]' )->value() );
}

function travelism_pro_is_footer_bg_image_enable( $control ) {
	return ( $control->manager->get_setting( 'travelism_pro_theme_options[footer_image_enable]' )->value() );
}

function travelism_pro_is_footer_bg_color_enable( $control ) {
	return ( false === $control->manager->get_setting( 'travelism_pro_theme_options[footer_image_enable]' )->value() );
}

/**
 * Front Page Active Callbacks
 */

/*====================Hero Banner======================*/

/**
 * Check if hero_banner section is enabled.
 *
 * @since Travelism Pro 1.0.0
 * @param WP_Customize_Control $control WP_Customize_Control instance.
 * @return bool Whether the control is active to the current preview.
 */
function travelism_pro_is_hero_banner_section_enable( $control ) {
	return ( $control->manager->get_setting( 'travelism_pro_theme_options[hero_banner_section_enable]' )->value() );
}

/**
 * Check if hero_banner section content type is post.
 *
 * @since Travelism Pro 1.0.0
 * @param WP_Customize_Control $control WP_Customize_Control instance.
 * @return bool Whether the control is active to the current preview.
 */
function travelism_pro_is_hero_banner_section_content_post_enable( $control ) {
	$content_type = $control->manager->get_setting( 'travelism_pro_theme_options[hero_banner_content_type]' )->value();
	return travelism_pro_is_hero_banner_section_enable( $control ) && ( 'post' == $content_type );
}

/**
 * Check if hero_banner section content type is page.
 *
 * @since Travelism Pro 1.0.0
 * @param WP_Customize_Control $control WP_Customize_Control instance.
 * @return bool Whether the control is active to the current preview.
 */
function travelism_pro_is_hero_banner_section_content_page_enable( $control ) {
	$content_type = $control->manager->get_setting( 'travelism_pro_theme_options[hero_banner_content_type]' )->value();
	return travelism_pro_is_hero_banner_section_enable( $control ) && ( 'page' == $content_type );
}

/**
 * Check if hero_banner section content type is custom.
 *
 * @since Travelism Pro 1.0.0
 * @param WP_Customize_Control $control WP_Customize_Control instance.
 * @return bool Whether the control is active to the current preview.
 */
function travelism_pro_is_hero_banner_section_content_custom_enable( $control ) {
	$content_type = $control->manager->get_setting( 'travelism_pro_theme_options[hero_banner_content_type]' )->value();
	return travelism_pro_is_hero_banner_section_enable( $control ) && ( 'custom' == $content_type );
}

/*====================Northface Jacket======================*/

/**
 * Check if Northface Jacket section is enabled.
 *
 * @since Travelism Pro 1.0.0
 * @param WP_Customize_Control $control WP_Customize_Control instance.
 * @return bool Whether the control is active to the current preview.
 */
function travelism_pro_is_northface_jacket_section_enable( $control ) {
	return ( $control->manager->get_setting( 'travelism_pro_theme_options[northface_jacket_section_enable]' )->value() ) && class_exists( 'WooCommerce' );
}

/**
 * Check if Northface Jacket section content type is product.
 *
 * @since Travelism Pro 1.0.0
 * @param WP_Customize_Control $control WP_Customize_Control instance.
 * @return bool Whether the control is active to the current preview.
 */
function travelism_pro_is_northface_jacket_section_content_product_enable( $control ) {
	$content_type = $control->manager->get_setting( 'travelism_pro_theme_options[northface_jacket_content_type]' )->value();
	return travelism_pro_is_northface_jacket_section_enable( $control ) && ( 'product' == $content_type );
}

/**
 * Check if Northface Jacket section content type is product category.
 *
 * @since Travelism Pro 1.0.0
 * @param WP_Customize_Control $control WP_Customize_Control instance.
 * @return bool Whether the control is active to the current preview.
 */
function travelism_pro_is_northface_jacket_section_content_product_category_enable( $control ) {
	$content_type = $control->manager->get_setting( 'travelism_pro_theme_options[northface_jacket_content_type]' )->value();
	return travelism_pro_is_northface_jacket_section_enable( $control ) && ( 'product-category' == $content_type );
}


/*====================featured section===================*/

/**
 * Check if featured section is enabled.
 *
 * @since Travelism Pro 1.0.0
 * @param WP_Customize_Control $control WP_Customize_Control instance.
 * @return bool Whether the control is active to the current preview.
 */
function travelism_pro_is_featured_section_enable( $control ) {
	return ( $control->manager->get_setting( 'travelism_pro_theme_options[featured_section_enable]' )->value() );
}

/**
 * Check if featured section content type is page.
 *
 * @since Travelism Pro 1.0.0
 * @param WP_Customize_Control $control WP_Customize_Control instance.
 * @return bool Whether the control is active to the current preview.
 */
function travelism_pro_is_featured_section_content_page_enable( $control ) {
	$content_type = $control->manager->get_setting( 'travelism_pro_theme_options[featured_content_type]' )->value();
	return travelism_pro_is_featured_section_enable( $control ) && ( 'page' == $content_type );
}

/**
 * Check if featured section content type is post.
 *
 * @since Travelism Pro 1.0.0
 * @param WP_Customize_Control $control WP_Customize_Control instance.
 * @return bool Whether the control is active to the current preview.
 */
function travelism_pro_is_featured_section_content_post_enable( $control ) {
	$content_type = $control->manager->get_setting( 'travelism_pro_theme_options[featured_content_type]' )->value();
	return travelism_pro_is_featured_section_enable( $control ) && ( 'post' == $content_type );
}

/**
 * Check if featured section content type is trip.
 *
 * @since Travelism Pro 1.0.0
 * @param WP_Customize_Control $control WP_Customize_Control instance.
 * @return bool Whether the control is active to the current preview.
 */
function travelism_pro_is_featured_section_content_trip_enable( $control ) {
	$content_type = $control->manager->get_setting( 'travelism_pro_theme_options[featured_content_type]' )->value();
	return travelism_pro_is_featured_section_enable( $control ) && ( 'trip' == $content_type );
}

/**
 * Check if featured section content type is category.
 *
 * @since Travelism Pro 1.0.0
 * @param WP_Customize_Control $control WP_Customize_Control instance.
 * @return bool Whether the control is active to the current preview.
 */
function travelism_pro_is_featured_section_content_category_enable( $control ) {
	$content_type = $control->manager->get_setting( 'travelism_pro_theme_options[featured_content_type]' )->value();
	return travelism_pro_is_featured_section_enable( $control ) && ( 'category' == $content_type );
}

/**
 * Check if featured section content type is trip types.
 *
 * @since Travelism Pro 1.0.0
 * @param WP_Customize_Control $control WP_Customize_Control instance.
 * @return bool Whether the control is active to the current preview.
 */
function travelism_pro_is_featured_section_content_trip_types_enable( $control ) {
	$content_type = $control->manager->get_setting( 'travelism_pro_theme_options[featured_content_type]' )->value();
	return travelism_pro_is_featured_section_enable( $control ) && ( 'trip-types' == $content_type );
}

/**
 * Check if featured section content type is destination.
 *
 * @since Travelism Pro 1.0.0
 * @param WP_Customize_Control $control WP_Customize_Control instance.
 * @return bool Whether the control is active to the current preview.
 */
function travelism_pro_is_featured_section_content_destination_enable( $control ) {
	$content_type = $control->manager->get_setting( 'travelism_pro_theme_options[featured_content_type]' )->value();
	return travelism_pro_is_featured_section_enable( $control ) && ( 'destination' == $content_type );
}

/**
 * Check if featured section content type is activity.
 *
 * @since Travelism Pro 1.0.0
 * @param WP_Customize_Control $control WP_Customize_Control instance.
 * @return bool Whether the control is active to the current preview.
 */
function travelism_pro_is_featured_section_content_activity_enable( $control ) {
	$content_type = $control->manager->get_setting( 'travelism_pro_theme_options[featured_content_type]' )->value();
	return travelism_pro_is_featured_section_enable( $control ) && ( 'activity' == $content_type );
}

/*====================video section===================*/

/**
 * Check if video section is enabled.
 *
 * @since Travelism Pro 1.0.0
 * @param WP_Customize_Control $control WP_Customize_Control instance.
 * @return bool Whether the control is active to the current preview.
 */
function travelism_pro_is_video_section_enable( $control ) {
	return ( $control->manager->get_setting( 'travelism_pro_theme_options[video_section_enable]' )->value() );
}

/**
 * Check if video section content type is page.
 *
 * @since Travelism Pro 1.0.0
 * @param WP_Customize_Control $control WP_Customize_Control instance.
 * @return bool Whether the control is active to the current preview.
 */
function travelism_pro_is_video_section_content_page_enable( $control ) {
	$content_type = $control->manager->get_setting( 'travelism_pro_theme_options[video_content_type]' )->value();
	return travelism_pro_is_video_section_enable( $control ) && ( 'page' == $content_type );
}

/**
 * Check if video section content type is post.
 *
 * @since Travelism Pro 1.0.0
 * @param WP_Customize_Control $control WP_Customize_Control instance.
 * @return bool Whether the control is active to the current preview.
 */
function travelism_pro_is_video_section_content_post_enable( $control ) {
	$content_type = $control->manager->get_setting( 'travelism_pro_theme_options[video_content_type]' )->value();
	return travelism_pro_is_video_section_enable( $control ) && ( 'post' == $content_type );
}

/**
 * Check if video section content type is trip.
 *
 * @since Travelism Pro 1.0.0
 * @param WP_Customize_Control $control WP_Customize_Control instance.
 * @return bool Whether the control is active to the current preview.
 */
function travelism_pro_is_video_section_content_trip_enable( $control ) {
	$content_type = $control->manager->get_setting( 'travelism_pro_theme_options[video_content_type]' )->value();
	return travelism_pro_is_video_section_enable( $control ) && ( 'trip' == $content_type );
}

/**
 * Check if video section content type is category.
 *
 * @since Travelism Pro 1.0.0
 * @param WP_Customize_Control $control WP_Customize_Control instance.
 * @return bool Whether the control is active to the current preview.
 */
function travelism_pro_is_video_section_content_category_enable( $control ) {
	$content_type = $control->manager->get_setting( 'travelism_pro_theme_options[video_content_type]' )->value();
	return travelism_pro_is_video_section_enable( $control ) && ( 'category' == $content_type );
}

/**
 * Check if video section content type is trip types.
 *
 * @since Travelism Pro 1.0.0
 * @param WP_Customize_Control $control WP_Customize_Control instance.
 * @return bool Whether the control is active to the current preview.
 */
function travelism_pro_is_video_section_content_trip_types_enable( $control ) {
	$content_type = $control->manager->get_setting( 'travelism_pro_theme_options[video_content_type]' )->value();
	return travelism_pro_is_video_section_enable( $control ) && ( 'trip-types' == $content_type );
}

/**
 * Check if video section content type is destination.
 *
 * @since Travelism Pro 1.0.0
 * @param WP_Customize_Control $control WP_Customize_Control instance.
 * @return bool Whether the control is active to the current preview.
 */
function travelism_pro_is_video_section_content_destination_enable( $control ) {
	$content_type = $control->manager->get_setting( 'travelism_pro_theme_options[video_content_type]' )->value();
	return travelism_pro_is_video_section_enable( $control ) && ( 'destination' == $content_type );
}

/**
 * Check if video section content type is activity.
 *
 * @since Travelism Pro 1.0.0
 * @param WP_Customize_Control $control WP_Customize_Control instance.
 * @return bool Whether the control is active to the current preview.
 */
function travelism_pro_is_video_section_content_activity_enable( $control ) {
	$content_type = $control->manager->get_setting( 'travelism_pro_theme_options[video_content_type]' )->value();
	return travelism_pro_is_featured_section_enable( $control ) && ( 'activity' == $content_type );
}

/*====================wildlife section===================*/

/**
 * Check if wildlife section is enabled.
 *
 * @since Travelism Pro 1.0.0
 * @param WP_Customize_Control $control WP_Customize_Control instance.
 * @return bool Whether the control is active to the current preview.
 */
function travelism_pro_is_wildlife_section_enable( $control ) {
	return ( $control->manager->get_setting( 'travelism_pro_theme_options[wildlife_section_enable]' )->value() );
}

/**
 * Check if wildlife section content type is page.
 *
 * @since Travelism Pro 1.0.0
 * @param WP_Customize_Control $control WP_Customize_Control instance.
 * @return bool Whether the control is active to the current preview.
 */
function travelism_pro_is_wildlife_section_content_page_enable( $control ) {
	$content_type = $control->manager->get_setting( 'travelism_pro_theme_options[wildlife_content_type]' )->value();
	return travelism_pro_is_wildlife_section_enable( $control ) && ( 'page' == $content_type );
}

/**
 * Check if wildlife section content type is post.
 *
 * @since Travelism Pro 1.0.0
 * @param WP_Customize_Control $control WP_Customize_Control instance.
 * @return bool Whether the control is active to the current preview.
 */
function travelism_pro_is_wildlife_section_content_post_enable( $control ) {
	$content_type = $control->manager->get_setting( 'travelism_pro_theme_options[wildlife_content_type]' )->value();
	return travelism_pro_is_wildlife_section_enable( $control ) && ( 'post' == $content_type );
}

/**
 * Check if wildlife section content type is trip.
 *
 * @since Travelism Pro 1.0.0
 * @param WP_Customize_Control $control WP_Customize_Control instance.
 * @return bool Whether the control is active to the current preview.
 */
function travelism_pro_is_wildlife_section_content_trip_enable( $control ) {
	$content_type = $control->manager->get_setting( 'travelism_pro_theme_options[wildlife_content_type]' )->value();
	return travelism_pro_is_wildlife_section_enable( $control ) && ( 'trip' == $content_type );
}

/*====================gallery section===================*/

/**
 * Check if gallery section is enabled.
 *
 * @since Travelism Pro 1.0.0
 * @param WP_Customize_Control $control WP_Customize_Control instance.
 * @return bool Whether the control is active to the current preview.
 */
function travelism_pro_is_gallery_section_enable( $control ) {
	return ( $control->manager->get_setting( 'travelism_pro_theme_options[gallery_section_enable]' )->value() );
}

/**
 * Check if gallery section content type is page.
 *
 * @since Travelism Pro 1.0.0
 * @param WP_Customize_Control $control WP_Customize_Control instance.
 * @return bool Whether the control is active to the current preview.
 */
function travelism_pro_is_gallery_section_content_page_enable( $control ) {
	$content_type = $control->manager->get_setting( 'travelism_pro_theme_options[gallery_content_type]' )->value();
	return travelism_pro_is_gallery_section_enable( $control ) && ( 'page' == $content_type );
}

/**
 * Check if gallery section content type is post.
 *
 * @since Travelism Pro 1.0.0
 * @param WP_Customize_Control $control WP_Customize_Control instance.
 * @return bool Whether the control is active to the current preview.
 */
function travelism_pro_is_gallery_section_content_post_enable( $control ) {
	$content_type = $control->manager->get_setting( 'travelism_pro_theme_options[gallery_content_type]' )->value();
	return travelism_pro_is_gallery_section_enable( $control ) && ( 'post' == $content_type );
}

/**
 * Check if gallery section content type is trip.
 *
 * @since Travelism Pro 1.0.0
 * @param WP_Customize_Control $control WP_Customize_Control instance.
 * @return bool Whether the control is active to the current preview.
 */
function travelism_pro_is_gallery_section_content_trip_enable( $control ) {
	$content_type = $control->manager->get_setting( 'travelism_pro_theme_options[gallery_content_type]' )->value();
	return travelism_pro_is_gallery_section_enable( $control ) && ( 'trip' == $content_type );
}

/**
 * Check if gallery section content type is category.
 *
 * @since Travelism Pro 1.0.0
 * @param WP_Customize_Control $control WP_Customize_Control instance.
 * @return bool Whether the control is active to the current preview.
 */
function travelism_pro_is_gallery_section_content_category_enable( $control ) {
	$content_type = $control->manager->get_setting( 'travelism_pro_theme_options[gallery_content_type]' )->value();
	return travelism_pro_is_gallery_section_enable( $control ) && ( 'category' == $content_type );
}

/**
 * Check if gallery section content type is trip types.
 *
 * @since Travelism Pro 1.0.0
 * @param WP_Customize_Control $control WP_Customize_Control instance.
 * @return bool Whether the control is active to the current preview.
 */
function travelism_pro_is_gallery_section_content_trip_types_enable( $control ) {
	$content_type = $control->manager->get_setting( 'travelism_pro_theme_options[gallery_content_type]' )->value();
	return travelism_pro_is_gallery_section_enable( $control ) && ( 'trip-types' == $content_type );
}

/**
 * Check if gallery section content type is destination.
 *
 * @since Travelism Pro 1.0.0
 * @param WP_Customize_Control $control WP_Customize_Control instance.
 * @return bool Whether the control is active to the current preview.
 */
function travelism_pro_is_gallery_section_content_destination_enable( $control ) {
	$content_type = $control->manager->get_setting( 'travelism_pro_theme_options[gallery_content_type]' )->value();
	return travelism_pro_is_gallery_section_enable( $control ) && ( 'destination' == $content_type );
}

/**
 * Check if gallery section content type is activity.
 *
 * @since Travelism Pro 1.0.0
 * @param WP_Customize_Control $control WP_Customize_Control instance.
 * @return bool Whether the control is active to the current preview.
 */
function travelism_pro_is_gallery_section_content_activity_enable( $control ) {
	$content_type = $control->manager->get_setting( 'travelism_pro_theme_options[gallery_content_type]' )->value();
	return travelism_pro_is_gallery_section_enable( $control ) && ( 'activity' == $content_type );
}

/*====================Testimonial section===================*/

/**
 * Check if happy_clients section is enabled.
 *
 * @since Travelism Pro 1.0.0
 * @param WP_Customize_Control $control WP_Customize_Control instance.
 * @return bool Whether the control is active to the current preview.
 */
function travelism_pro_is_happy_clients_section_enable( $control ) {
	return ( $control->manager->get_setting( 'travelism_pro_theme_options[happy_clients_section_enable]' )->value() );
}

/**
 * Check if happy_clients section content type is post.
 *
 * @since Travelism Pro 1.0.0
 * @param WP_Customize_Control $control WP_Customize_Control instance.
 * @return bool Whether the control is active to the current preview.
 */
function travelism_pro_is_happy_clients_section_content_post_enable( $control ) {
	$content_type = $control->manager->get_setting( 'travelism_pro_theme_options[happy_clients_content_type]' )->value();
	return travelism_pro_is_happy_clients_section_enable( $control ) && ( 'post' == $content_type );
}

/**
 * Check if happy_clients section content type is page.
 *
 * @since Travelism Pro 1.0.0
 * @param WP_Customize_Control $control WP_Customize_Control instance.
 * @return bool Whether the control is active to the current preview.
 */
function travelism_pro_is_happy_clients_section_content_page_enable( $control ) {
	$content_type = $control->manager->get_setting( 'travelism_pro_theme_options[happy_clients_content_type]' )->value();
	return travelism_pro_is_happy_clients_section_enable( $control ) && ( 'page' == $content_type );
}

/**
 * Check if happy_clients section content type is category.
 *
 * @since Travelism Pro 1.0.0
 * @param WP_Customize_Control $control WP_Customize_Control instance.
 * @return bool Whether the control is active to the current preview.
 */
function travelism_pro_is_happy_clients_section_content_category_enable( $control ) {
	$content_type = $control->manager->get_setting( 'travelism_pro_theme_options[happy_clients_content_type]' )->value();
	return travelism_pro_is_happy_clients_section_enable( $control ) && ( 'category' == $content_type );
}

/*==================Logos===============*/

/**
 * Check if logos section is enabled.
 *
 * @since Travelism Pro 1.0.0
 * @param WP_Customize_Control $control WP_Customize_Control instance.
 * @return bool Whether the control is active to the current preview.
 */
function travelism_pro_is_logos_section_enable( $control ) {
	return ( $control->manager->get_setting( 'travelism_pro_theme_options[logos_section_enable]' )->value() );
}

/*==================Articles===============*/

/**
 * Check if articles section is enabled.
 *
 * @since Travelism Pro 1.0.0
 * @param WP_Customize_Control $control WP_Customize_Control instance.
 * @return bool Whether the control is active to the current preview.
 */
function travelism_pro_is_articles_section_enable( $control ) {
	return ( $control->manager->get_setting( 'travelism_pro_theme_options[articles_section_enable]' )->value() );
}

/**
 * Check if articles section content type is category.
 *
 * @since Travelism Pro 1.0.0
 * @param WP_Customize_Control $control WP_Customize_Control instance.
 * @return bool Whether the control is active to the current preview.
 */
function travelism_pro_is_articles_section_content_category_enable( $control ) {
	$content_type = $control->manager->get_setting( 'travelism_pro_theme_options[articles_content_type]' )->value();
	return travelism_pro_is_articles_section_enable( $control ) && ( 'category' == $content_type );
}

/**
 * Check if articles section content type is page.
 *
 * @since Travelism Pro 1.0.0
 * @param WP_Customize_Control $control WP_Customize_Control instance.
 * @return bool Whether the control is active to the current preview.
 */
function travelism_pro_is_articles_section_content_page_enable( $control ) {
	$content_type = $control->manager->get_setting( 'travelism_pro_theme_options[articles_content_type]' )->value();
	return travelism_pro_is_articles_section_enable( $control ) && ( 'page' == $content_type );
}

/**
 * Check if articles section content type is post.
 *
 * @since Travelism Pro 1.0.0
 * @param WP_Customize_Control $control WP_Customize_Control instance.
 * @return bool Whether the control is active to the current preview.
 */
function travelism_pro_is_articles_section_content_post_enable( $control ) {
	$content_type = $control->manager->get_setting( 'travelism_pro_theme_options[articles_content_type]' )->value();
	return travelism_pro_is_articles_section_enable( $control ) && ( 'post' == $content_type );
}

/*==================slider===============*/

/**
 * Check if blog_slider section is enabled.
 *
 * @since Travelism Pro 1.0.0
 * @param WP_Customize_Control $control WP_Customize_Control instance.
 * @return bool Whether the control is active to the current preview.
 */
function travelism_pro_is_blog_slider_section_enable( $control ) {
	return ( $control->manager->get_setting( 'travelism_pro_theme_options[blog_slider_section_enable]' )->value() );
}

/**
 * Check if blog_slider section content type is category.
 *
 * @since Travelism Pro 1.0.0
 * @param WP_Customize_Control $control WP_Customize_Control instance.
 * @return bool Whether the control is active to the current preview.
 */
function travelism_pro_is_blog_slider_section_content_category_enable( $control ) {
	$content_type = $control->manager->get_setting( 'travelism_pro_theme_options[blog_slider_content_type]' )->value();
	return travelism_pro_is_blog_slider_section_enable( $control ) && ( 'category' == $content_type );
}

/**
 * Check if blog_slider section content type is page.
 *
 * @since Travelism Pro 1.0.0
 * @param WP_Customize_Control $control WP_Customize_Control instance.
 * @return bool Whether the control is active to the current preview.
 */
function travelism_pro_is_blog_slider_section_content_page_enable( $control ) {
	$content_type = $control->manager->get_setting( 'travelism_pro_theme_options[blog_slider_content_type]' )->value();
	return travelism_pro_is_blog_slider_section_enable( $control ) && ( 'page' == $content_type );
}

/**
 * Check if blog_slider section content type is post.
 *
 * @since Travelism Pro 1.0.0
 * @param WP_Customize_Control $control WP_Customize_Control instance.
 * @return bool Whether the control is active to the current preview.
 */
function travelism_pro_is_blog_slider_section_content_post_enable( $control ) {
	$content_type = $control->manager->get_setting( 'travelism_pro_theme_options[blog_slider_content_type]' )->value();
	return travelism_pro_is_blog_slider_section_enable( $control ) && ( 'post' == $content_type );
}


/*==================blog_featured_post===============*/

/**
 * Check if blog_featured_post section is enabled.
 *
 * @since Travelism Pro 1.0.0
 * @param WP_Customize_Control $control WP_Customize_Control instance.
 * @return bool Whether the control is active to the current preview.
 */
function travelism_pro_is_blog_featured_post_section_enable( $control ) {
	return ( $control->manager->get_setting( 'travelism_pro_theme_options[blog_featured_post_section_enable]' )->value() );
}

/**
 * Check if blog_featured_post section content type is category.
 *
 * @since Travelism Pro 1.0.0
 * @param WP_Customize_Control $control WP_Customize_Control instance.
 * @return bool Whether the control is active to the current preview.
 */
function travelism_pro_is_blog_featured_post_section_content_category_enable( $control ) {
	$content_type = $control->manager->get_setting( 'travelism_pro_theme_options[blog_featured_post_content_type]' )->value();
	return travelism_pro_is_blog_featured_post_section_enable( $control ) && ( 'category' == $content_type );
}

/**
 * Check if blog_featured_post section content type is page.
 *
 * @since Travelism Pro 1.0.0
 * @param WP_Customize_Control $control WP_Customize_Control instance.
 * @return bool Whether the control is active to the current preview.
 */
function travelism_pro_is_blog_featured_post_section_content_page_enable( $control ) {
	$content_type = $control->manager->get_setting( 'travelism_pro_theme_options[blog_featured_post_content_type]' )->value();
	return travelism_pro_is_blog_featured_post_section_enable( $control ) && ( 'page' == $content_type );
}

/**
 * Check if blog_featured_post section content type is post.
 *
 * @since Travelism Pro 1.0.0
 * @param WP_Customize_Control $control WP_Customize_Control instance.
 * @return bool Whether the control is active to the current preview.
 */
function travelism_pro_is_blog_featured_post_section_content_post_enable( $control ) {
	$content_type = $control->manager->get_setting( 'travelism_pro_theme_options[blog_featured_post_content_type]' )->value();
	return travelism_pro_is_blog_featured_post_section_enable( $control ) && ( 'post' == $content_type );
}

/*====================CTA======================*/

/**
 * Check if blog_cta section is enabled.
 *
 * @since Travelism Pro 1.0.0
 * @param WP_Customize_Control $control WP_Customize_Control instance.
 * @return bool Whether the control is active to the current preview.
 */
function travelism_pro_is_blog_cta_section_enable( $control ) {
	return ( $control->manager->get_setting( 'travelism_pro_theme_options[blog_cta_section_enable]' )->value() );
}

/**
 * Check if blog_cta section content type is post.
 *
 * @since Travelism Pro 1.0.0
 * @param WP_Customize_Control $control WP_Customize_Control instance.
 * @return bool Whether the control is active to the current preview.
 */
function travelism_pro_is_blog_cta_section_content_post_enable( $control ) {
	$content_type = $control->manager->get_setting( 'travelism_pro_theme_options[blog_cta_content_type]' )->value();
	return travelism_pro_is_blog_cta_section_enable( $control ) && ( 'post' == $content_type );
}

/**
 * Check if blog_cta section content type is page.
 *
 * @since Travelism Pro 1.0.0
 * @param WP_Customize_Control $control WP_Customize_Control instance.
 * @return bool Whether the control is active to the current preview.
 */
function travelism_pro_is_blog_cta_section_content_page_enable( $control ) {
	$content_type = $control->manager->get_setting( 'travelism_pro_theme_options[blog_cta_content_type]' )->value();
	return travelism_pro_is_blog_cta_section_enable( $control ) && ( 'page' == $content_type );
}

/**
 * Check if blog_cta section content type is custom.
 *
 * @since Travelism Pro 1.0.0
 * @param WP_Customize_Control $control WP_Customize_Control instance.
 * @return bool Whether the control is active to the current preview.
 */
function travelism_pro_is_blog_cta_section_content_custom_enable( $control ) {
	$content_type = $control->manager->get_setting( 'travelism_pro_theme_options[blog_cta_content_type]' )->value();
	return travelism_pro_is_blog_cta_section_enable( $control ) && ( 'custom' == $content_type );
}

/*==================Popular Posts===============*/

/**
 * Check if blog_popular_post section is enabled.
 *
 * @since Travelism Pro 1.0.0
 * @param WP_Customize_Control $control WP_Customize_Control instance.
 * @return bool Whether the control is active to the current preview.
 */
function travelism_pro_is_blog_popular_post_section_enable( $control ) {
	return ( $control->manager->get_setting( 'travelism_pro_theme_options[blog_popular_post_section_enable]' )->value() );
}

/**
 * Check if blog_popular_post section content type is category.
 *
 * @since Travelism Pro 1.0.0
 * @param WP_Customize_Control $control WP_Customize_Control instance.
 * @return bool Whether the control is active to the current preview.
 */
function travelism_pro_is_blog_popular_post_section_content_category_enable( $control ) {
	$content_type = $control->manager->get_setting( 'travelism_pro_theme_options[blog_popular_post_content_type]' )->value();
	return travelism_pro_is_blog_popular_post_section_enable( $control ) && ( 'category' == $content_type );
}

/**
 * Check if blog_popular_post section content type is page.
 *
 * @since Travelism Pro 1.0.0
 * @param WP_Customize_Control $control WP_Customize_Control instance.
 * @return bool Whether the control is active to the current preview.
 */
function travelism_pro_is_blog_popular_post_section_content_page_enable( $control ) {
	$content_type = $control->manager->get_setting( 'travelism_pro_theme_options[blog_popular_post_content_type]' )->value();
	return travelism_pro_is_blog_popular_post_section_enable( $control ) && ( 'page' == $content_type );
}

/**
 * Check if blog_popular_post section content type is post.
 *
 * @since Travelism Pro 1.0.0
 * @param WP_Customize_Control $control WP_Customize_Control instance.
 * @return bool Whether the control is active to the current preview.
 */
function travelism_pro_is_blog_popular_post_section_content_post_enable( $control ) {
	$content_type = $control->manager->get_setting( 'travelism_pro_theme_options[blog_popular_post_content_type]' )->value();
	return travelism_pro_is_blog_popular_post_section_enable( $control ) && ( 'post' == $content_type );
}

/*==================Most Read Post===============*/

/**
 * Check if most_read_post section is enabled.
 *
 * @since Travelism Pro 1.0.0
 * @param WP_Customize_Control $control WP_Customize_Control instance.
 * @return bool Whether the control is active to the current preview.
 */
function travelism_pro_is_most_read_post_section_enable( $control ) {
	return ( $control->manager->get_setting( 'travelism_pro_theme_options[most_read_post_section_enable]' )->value() );
}

/**
 * Check if most_read_post section content type is category.
 *
 * @since Travelism Pro 1.0.0
 * @param WP_Customize_Control $control WP_Customize_Control instance.
 * @return bool Whether the control is active to the current preview.
 */
function travelism_pro_is_most_read_post_section_content_category_enable( $control ) {
	$content_type = $control->manager->get_setting( 'travelism_pro_theme_options[most_read_post_content_type]' )->value();
	return travelism_pro_is_most_read_post_section_enable( $control ) && ( 'category' == $content_type );
}

/**
 * Check if most_read_post section content type is page.
 *
 * @since Travelism Pro 1.0.0
 * @param WP_Customize_Control $control WP_Customize_Control instance.
 * @return bool Whether the control is active to the current preview.
 */
function travelism_pro_is_most_read_post_section_content_page_enable( $control ) {
	$content_type = $control->manager->get_setting( 'travelism_pro_theme_options[most_read_post_content_type]' )->value();
	return travelism_pro_is_most_read_post_section_enable( $control ) && ( 'page' == $content_type );
}

/**
 * Check if most_read_post section content type is post.
 *
 * @since Travelism Pro 1.0.0
 * @param WP_Customize_Control $control WP_Customize_Control instance.
 * @return bool Whether the control is active to the current preview.
 */
function travelism_pro_is_most_read_post_section_content_post_enable( $control ) {
	$content_type = $control->manager->get_setting( 'travelism_pro_theme_options[most_read_post_content_type]' )->value();
	return travelism_pro_is_most_read_post_section_enable( $control ) && ( 'post' == $content_type );
}

/**
 * Check if subscribe_now section is enabled.
 *
 * @since Travelism Pro 1.0.0
 * @param WP_Customize_Control $control WP_Customize_Control instance.
 * @return bool Whether the control is active to the current preview.
 */
function travelism_pro_is_subscribe_now_section_enable( $control ) {
	return ( $control->manager->get_setting( 'travelism_pro_theme_options[subscribe_now_section_enable]' )->value() );
}

/*==================Recent Posts===============*/

/**
 * Check if recent_post section is enabled.
 *
 * @since Travelism Pro 1.0.0
 * @param WP_Customize_Control $control WP_Customize_Control instance.
 * @return bool Whether the control is active to the current preview.
 */
function travelism_pro_is_recent_post_section_enable( $control ) {
	return ( $control->manager->get_setting( 'travelism_pro_theme_options[recent_post_section_enable]' )->value() );
}

/**
 * Check if recent_post section content type is category.
 *
 * @since Travelism Pro 1.0.0
 * @param WP_Customize_Control $control WP_Customize_Control instance.
 * @return bool Whether the control is active to the current preview.
 */
function travelism_pro_is_recent_post_section_content_category_enable( $control ) {
	$content_type = $control->manager->get_setting( 'travelism_pro_theme_options[recent_post_content_type]' )->value();
	return travelism_pro_is_recent_post_section_enable( $control ) && ( 'category' == $content_type );
}

/**
 * Check if recent_post section content type is page.
 *
 * @since Travelism Pro 1.0.0
 * @param WP_Customize_Control $control WP_Customize_Control instance.
 * @return bool Whether the control is active to the current preview.
 */
function travelism_pro_is_recent_post_section_content_page_enable( $control ) {
	$content_type = $control->manager->get_setting( 'travelism_pro_theme_options[recent_post_content_type]' )->value();
	return travelism_pro_is_recent_post_section_enable( $control ) && ( 'page' == $content_type );
}

/**
 * Check if recent_post section content type is post.
 *
 * @since Travelism Pro 1.0.0
 * @param WP_Customize_Control $control WP_Customize_Control instance.
 * @return bool Whether the control is active to the current preview.
 */
function travelism_pro_is_recent_post_section_content_post_enable( $control ) {
	$content_type = $control->manager->get_setting( 'travelism_pro_theme_options[recent_post_content_type]' )->value();
	return travelism_pro_is_recent_post_section_enable( $control ) && ( 'post' == $content_type );
}

/*==================Service===============*/

/**
 * Check if business_service section is enabled.
 *
 * @since Travelism Pro 1.0.0
 * @param WP_Customize_Control $control WP_Customize_Control instance.
 * @return bool Whether the control is active to the current preview.
 */
function travelism_pro_is_business_service_section_enable( $control ) {
	return ( $control->manager->get_setting( 'travelism_pro_theme_options[business_service_section_enable]' )->value() );
}

/**
 * Check if business_service section content type is category.
 *
 * @since Travelism Pro 1.0.0
 * @param WP_Customize_Control $control WP_Customize_Control instance.
 * @return bool Whether the control is active to the current preview.
 */
function travelism_pro_is_business_service_section_content_category_enable( $control ) {
	$content_type = $control->manager->get_setting( 'travelism_pro_theme_options[business_service_content_type]' )->value();
	return travelism_pro_is_business_service_section_enable( $control ) && ( 'category' == $content_type );
}

/**
 * Check if business_service section content type is page.
 *
 * @since Travelism Pro 1.0.0
 * @param WP_Customize_Control $control WP_Customize_Control instance.
 * @return bool Whether the control is active to the current preview.
 */
function travelism_pro_is_business_service_section_content_page_enable( $control ) {
	$content_type = $control->manager->get_setting( 'travelism_pro_theme_options[business_service_content_type]' )->value();
	return travelism_pro_is_business_service_section_enable( $control ) && ( 'page' == $content_type );
}

/**
 * Check if business_service section content type is post.
 *
 * @since Travelism Pro 1.0.0
 * @param WP_Customize_Control $control WP_Customize_Control instance.
 * @return bool Whether the control is active to the current preview.
 */
function travelism_pro_is_business_service_section_content_post_enable( $control ) {
	$content_type = $control->manager->get_setting( 'travelism_pro_theme_options[business_service_content_type]' )->value();
	return travelism_pro_is_business_service_section_enable( $control ) && ( 'post' == $content_type );
}

/*====================about================*/

/**
 * Check if business_about section is enabled.
 *
 * @since Travelism Pro 1.0.0
 * @param WP_Customize_Control $control WP_Customize_Control instance.
 * @return bool Whether the control is active to the current preview.
 */
function travelism_pro_is_business_about_section_enable( $control ) {
	return ( $control->manager->get_setting( 'travelism_pro_theme_options[business_about_section_enable]' )->value() );
}

/**
 * Check if business_about section content type is post.
 *
 * @since Travelism Pro 1.0.0
 * @param WP_Customize_Control $control WP_Customize_Control instance.
 * @return bool Whether the control is active to the current preview.
 */
function travelism_pro_is_business_about_section_content_post_enable( $control ) {
	$content_type = $control->manager->get_setting( 'travelism_pro_theme_options[business_about_content_type]' )->value();
	return travelism_pro_is_business_about_section_enable( $control ) && ( 'post' == $content_type );
}

/**
 * Check if business_about section content type is page.
 *
 * @since Travelism Pro 1.0.0
 * @param WP_Customize_Control $control WP_Customize_Control instance.
 * @return bool Whether the control is active to the current preview.
 */
function travelism_pro_is_business_about_section_content_page_enable( $control ) {
	$content_type = $control->manager->get_setting( 'travelism_pro_theme_options[business_about_content_type]' )->value();
	return travelism_pro_is_business_about_section_enable( $control ) && ( 'page' == $content_type );
}

/**
 * Check if business_about section content type is custom.
 *
 * @since Travelism Pro 1.0.0
 * @param WP_Customize_Control $control WP_Customize_Control instance.
 * @return bool Whether the control is active to the current preview.
 */
function travelism_pro_is_business_about_section_content_custom_enable( $control ) {
	$content_type = $control->manager->get_setting( 'travelism_pro_theme_options[business_about_content_type]' )->value();
	return travelism_pro_is_business_about_section_enable( $control ) && ( 'custom' == $content_type );
}

/*===============Team====================*/

/**
 * Check if business_team section is enabled.
 *
 * @since Travelism Pro 1.0.0
 * @param WP_Customize_Control $control WP_Customize_Control instance.
 * @return bool Whether the control is active to the current preview.
 */
function travelism_pro_is_business_team_section_enable( $control ) {
	return ( $control->manager->get_setting( 'travelism_pro_theme_options[business_team_section_enable]' )->value() );
}

/**
 * Check if business_team section content type is category.
 *
 * @since Travelism Pro 1.0.0
 * @param WP_Customize_Control $control WP_Customize_Control instance.
 * @return bool Whether the control is active to the current preview.
 */
function travelism_pro_is_business_team_section_content_category_enable( $control ) {
	$content_type = $control->manager->get_setting( 'travelism_pro_theme_options[business_team_content_type]' )->value();
	return travelism_pro_is_business_team_section_enable( $control ) && ( 'category' == $content_type );
}

/**
 * Check if business_team section content type is page.
 *
 * @since Travelism Pro 1.0.0
 * @param WP_Customize_Control $control WP_Customize_Control instance.
 * @return bool Whether the control is active to the current preview.
 */
function travelism_pro_is_business_team_section_content_page_enable( $control ) {
	$content_type = $control->manager->get_setting( 'travelism_pro_theme_options[business_team_content_type]' )->value();
	return travelism_pro_is_business_team_section_enable( $control ) && ( 'page' == $content_type );
}

/**
 * Check if business_team section content type is post.
 *
 * @since Travelism Pro 1.0.0
 * @param WP_Customize_Control $control WP_Customize_Control instance.
 * @return bool Whether the control is active to the current preview.
 */
function travelism_pro_is_business_team_section_content_post_enable( $control ) {
	$content_type = $control->manager->get_setting( 'travelism_pro_theme_options[business_team_content_type]' )->value();
	return travelism_pro_is_business_team_section_enable( $control ) && ( 'post' == $content_type );
}

/*===================Counter====================*/

/**
 * Check if business_counter section is enabled.
 *
 * @since Travelism Pro 1.0.0
 * @param WP_Customize_Control $control WP_Customize_Control instance.
 * @return bool Whether the control is active to the current preview.
 */
function travelism_pro_is_business_counter_section_enable( $control ) {
	return ( $control->manager->get_setting( 'travelism_pro_theme_options[business_counter_section_enable]' )->value() );
}

/*===================Recent Product====================*/

/**
 * Check if shop_recent_products section is enabled.
 *
 * @since Travelism Pro 1.0.0
 * @param WP_Customize_Control $control WP_Customize_Control instance.
 * @return bool Whether the control is active to the current preview.
 */
function travelism_pro_is_shop_recent_products_section_enable( $control ) {
	return ( $control->manager->get_setting( 'travelism_pro_theme_options[shop_recent_products_section_enable]' )->value() );
}

function travelism_pro_is_shop_recent_products_section_content_product_enable( $control ) {
	$content_type = $control->manager->get_setting( 'travelism_pro_theme_options[shop_recent_products_content_type]' )->value();
	return travelism_pro_is_shop_recent_products_section_enable( $control ) && ( 'product' == $content_type );
}

function travelism_pro_is_shop_recent_products_section_content_product_category_enable( $control ) {
	$content_type = $control->manager->get_setting( 'travelism_pro_theme_options[shop_recent_products_content_type]' )->value();
	return travelism_pro_is_shop_recent_products_section_enable( $control ) && ( 'product-category' == $content_type );
}

/*=================Trending Product================*/

function travelism_pro_is_trending_products_section_enable( $control ) {
	return ( $control->manager->get_setting( 'travelism_pro_theme_options[trending_products_section_enable]' )->value() );
}

/**
 * Check if trending_product section content type is post.
 *
 * @since musicsong Pro 1.0.0
 * @param WP_Customize_Control $control WP_Customize_Control instance.
 * @return bool Whether the control is active to the current preview.
 */

function travelism_pro_is_trending_products_section_content_category_enable_1( $control ) {
	$content_type = $control->manager->get_setting( 'travelism_pro_theme_options[trending_content_type_1]' )->value();
	return travelism_pro_is_trending_products_section_enable( $control ) && ( 'product_cat' == $content_type );
}

function travelism_pro_is_trending_products_section_content_category_enable_2( $control ) {
	$content_type = $control->manager->get_setting( 'travelism_pro_theme_options[trending_content_type_2]' )->value();
	return travelism_pro_is_trending_products_section_enable( $control ) && ( 'product_cat' == $content_type );
}

function travelism_pro_is_trending_products_section_content_category_enable_3( $control ) {
	$content_type = $control->manager->get_setting( 'travelism_pro_theme_options[trending_content_type_3]' )->value();
	return travelism_pro_is_trending_products_section_enable( $control ) && ( 'product_cat' == $content_type );
}

function travelism_pro_is_trending_products_section_content_product_enable_1( $control ) {
		$content_type = $control->manager->get_setting( 'travelism_pro_theme_options[trending_content_type_1]' )->value();
	return travelism_pro_is_trending_products_section_enable( $control ) && ( 'product' == $content_type );
}

function travelism_pro_is_trending_products_section_content_product_enable_2( $control ) {
	$content_type = $control->manager->get_setting( 'travelism_pro_theme_options[trending_content_type_2]' )->value();
	return travelism_pro_is_trending_products_section_enable( $control ) && ( 'product' == $content_type );
}

function travelism_pro_is_trending_products_section_content_product_enable_3( $control ) {
	$content_type = $control->manager->get_setting( 'travelism_pro_theme_options[trending_content_type_3]' )->value();
	return travelism_pro_is_trending_products_section_enable( $control ) && ( 'product' == $content_type );
}

/*=================Featured Product================*/
//featured section
function travelism_pro_is_featured_products_section_enable( $control ) {
	return ( $control->manager->get_setting( 'travelism_pro_theme_options[featured_products_section_enable]' )->value() ) && class_exists( 'WooCommerce' );
}

//pro layout 
function travelism_pro_is_default_layout( $control ) {
	$design = $control->manager->get_setting( 'travelism_pro_theme_options[home_layout]' )->value();
	return ( 'default-design' == $design );
}

//Second layout 
function travelism_pro_is_second_layout( $control ) {
	$design = $control->manager->get_setting( 'travelism_pro_theme_options[home_layout]' )->value();
	return ( 'second-design' == $design );
}

//Third layout 
function travelism_pro_is_third_layout( $control ) {
	$design = $control->manager->get_setting( 'travelism_pro_theme_options[home_layout]' )->value();
	return ( 'third-design' == $design );
}

//Fourth layout 
function travelism_pro_is_fourth_layout( $control ) {
	$design = $control->manager->get_setting( 'travelism_pro_theme_options[home_layout]' )->value();
	return ( 'fourth-design' == $design );
}