<?php
/**
 * Customizer default options
 *
 * @package Theme Palace
 * @subpackage Travelism Pro
 * @since Travelism Pro 1.0.0
 * @return array An array of default values
 */

function travelism_pro_get_default_theme_options() {
	$theme_data = wp_get_theme();
	$travelism_pro_default_options = array(
		// Color Options
		'header_title_color'			=> '#000',
		'header_tagline_color'			=> '#fff',
		'header_txt_logo_extra'			=> 'show-all',
		'colorscheme_hue'				=> '#ff6633',
		'colorscheme'					=> 'default',
		'theme_version'					=> 'dark-version',
		'home_layout'					=> 'default-design',
		
		// typography Options
		'theme_typography' 				=> 'default',
		'body_theme_typography' 		=> 'default',

		//body typography
		'body_font_family'			=> 'Muli',
		'body_font_weight'			=> 300,
		'body_font_size'			=> 16,
		'body_font_style'			=> 'normal',
		'body_text_transform'		=> 'none',

		//h1 typography
		'heading_h1_font_family'		=> 'Raleway',
		'heading_h1_font_weight'		=> 300,
		'heading_h1_text_transform'		=> 'none',
		'heading_h1_font_style'			=> 'normal',

		//h2 typography
		'heading_h2_font_family'		=> 'Raleway',
		'heading_h2_font_weight'		=> 700,
		'heading_h2_text_transform'		=> 'none',
		'heading_h2_font_style'			=> 'normal',

		//h3 typography
		'heading_h3_font_family'		=> 'Raleway',
		'heading_h3_font_weight'		=> 700,
		'heading_h3_text_transform'		=> 'none',
		'heading_h3_font_style'			=> 'normal',

		//h4 typography
		'heading_h4_font_family'		=> 'Raleway',
		'heading_h4_font_weight'		=> 700,
		'heading_h4_text_transform'		=> 'none',
		'heading_h4_font_style'			=> 'normal',

		//h5 typography
		'heading_h5_font_family'		=> 'Raleway',
		'heading_h5_font_weight'		=> 700,
		'heading_h5_text_transform'		=> 'none',
		'heading_h5_font_style'			=> 'normal',

		//h6 typography
		'heading_h6_font_family'		=> 'Raleway',
		'heading_h6_font_weight'		=> 700,
		'heading_h6_text_transform'		=> 'none',
		'heading_h6_font_style'			=> 'normal',

		//p typography
		'heading_p_font_family'			=> 'Muli',
		'heading_p_font_weight'			=> 400,
		'heading_p_text_transform'		=> 'none',
		'heading_p_font_style'			=> 'normal',

		//button
		'button_background_color'		=> '#e5f8fc',
		'button_text_color'		=> '#00afe9',
		
		// loader
		'loader_enable'         		=> false,
		'loader_icon'         			=> 'default',

		// breadcrumb
		'breadcrumb_enable'				=> true,
		'breadcrumb_separator'			=> '/',

		'banner_image_enable'			=> true,
		
		// layout 
		'site_layout'         			=> 'wide-layout',
		'sidebar_position'         		=> 'right-sidebar',
		'post_sidebar_position' 		=> 'right-sidebar',
		'page_sidebar_position' 		=> 'right-sidebar',
		'menu_sticky'					=> true,
		'cart_icon'						=> true,
		'contact_number'				=> esc_html__( '+1 25484 5225', 'travelism-pro' ),
		'menu_btn_label'				=> esc_html__( 'BOOK A TOUR', 'travelism-pro' ),
		'menu_button_enable'				=> true,

		// excerpt options
		'long_excerpt_length'           => 25,
		
		// pagination options
		'pagination_enable'         	=> true,
		'pagination_type'         		=> 'default',

		// footer options
		'copyright_text'           		=> sprintf( esc_html_x( 'Copyright &copy; %1$s %2$s', '1: Year, 2: Site Title with home URL', 'travelism-pro' ), '[the-year]', '[site-link]' ),
		'footer_copyright_enable'       => true,
		'footer_social_menu'        	=> true,
		'scroll_top_visible'        	=> true,
		'footer_image_enable'        	=> true,

		// reset options
		'reset_options'      			=> false,
		
		// homepage options
		'enable_frontpage_content' 		=> false,

		// all sortable sortable
		'all_sortable' 						=> 'hero_banner,blog_slider,blog_featured_post,business_service,shop_recent_products,business_about,trending_products,blog_cta,business_team,business_counter,blog_popular_post,most_read_post,northface_jacket,featured,video,wildlife,gallery,happy_clients,logos,featured_products,subscribe_now,articles,recent_post',

		// default sortable sortable
		'default_sortable' 						=> 'hero_banner,northface_jacket,featured,video,wildlife,gallery,happy_clients,logos,articles',

		// second sections sortable
		'second_sortable' 						=> 'blog_slider,blog_featured_post,blog_cta,blog_popular_post,most_read_post,subscribe_now,recent_post',

		// third sections sortable
		'third_sortable' 						=> 'blog_slider,business_service,business_about,blog_cta,business_team,business_counter,happy_clients,logos,subscribe_now,articles',

		// fourth sections sortable
		'fourth_sortable' 						=> 'blog_slider,blog_featured_post,business_service,shop_recent_products,business_about,trending_products,blog_cta,happy_clients,logos,featured_products,subscribe_now,articles',

		// blog/archive options
		'your_latest_posts_title' 		=> esc_html__( 'Blogs', 'travelism-pro' ),
		'single_post_hide_banner'		=> false,
		'hide_category'					=> false,
		'hide_banner'					=> false,		
		'hide_archive_post_image'		=> false,		
		'hide_archive_title'			=> false,		
		'hide_archive_content'			=> false,		
		'blog_column'					=> 'col-2',


		// single post theme options
		'single_post_hide_date' 		=> false,
		'single_post_hide_author'		=> false,
		'single_post_hide_category'		=> false,
		'single_post_hide_tags'			=> false,
		'single_post_hide_content'		=> false,
		'single_post_hide_image'		=> false,

		/* Front Page */

		// hero_banner
		'hero_banner_section_enable'		=> true,
		'hero_banner_content_type'			=> 'page',
		'hero_banner_title'					=> esc_html__( 'Discover new destinations!', 'travelism-pro' ),
		'hero_banner_sub_title'				=> esc_html__( 'ALL YOU NEED IS TRAVELISM', 'travelism-pro' ),
		'hero_banner_description'			=> esc_html__( 'Even if you don’t plan on taking up journalism when you get back home, the act of note-taking will give you a much greater travel experience! Picking up your notebook and spending a few minutes now and then, jotting down what is happenning around you, will make you more aware. Suddenly, you realize what the surroundings offer vastly more than your first thought.', 'travelism-pro' ),
		'hero_banner_btn_title'				=> esc_html__( 'EXPLORE DESTINATIONS', 'travelism-pro' ),
		'hero_banner_excerpt_length'		=> 35,

		//northface_jacket jacket
		'northface_jacket_section_enable'		=> true,
		'northface_jacket_content_type'			=> 'product-category',
		'northface_jacket_count'				=> 3,
		'northface_jacket_excerpt_length'		=> 30,
		'northface_jacket_title'				=> esc_html__( 'JACKET-AP', 'travelism-pro' ),
		'northface_jacket_sub_title'			=> esc_html__( 'THE NORTH FACE', 'travelism-pro' ),

		// featured
		'featured_section_enable'		=> true,
		'featured_content_type'			=> 'category',
		'featured_count'				=> 4,
		'featured_title'				=> esc_html__( 'Choose your next adventure!', 'travelism-pro' ),
		'featured_sub_title'			=> esc_html__('FEATURED','travelism-pro'),
		'featured_btn_label'			=> esc_html__( 'Explore', 'travelism-pro' ),
		'featured_posts_autoplay'		=> false,

		// video
		'video_section_enable'		=> true,
		'video_content_type'		=> 'category',
		'video_count'				=> 3,
		'video_excerpt_length'		=> 25,
		'video_title'				=> esc_html__( 'Watch And Discover', 'travelism-pro' ),
		'video_sub_title'			=> esc_html__('VIDEO SHOWCASE','travelism-pro'),
		'video_btn_label'			=> esc_html__( 'VIEW THIS TOUR', 'travelism-pro' ),

		// wildlife
		'wildlife_section_enable'		=> true,
		'wildlife_content_type'			=> 'page',
		'wildlife_excerpt_length'		=> 50,
		'wildlife_sub_title'			=> esc_html__('WILDLIFE','travelism-pro'),
		'wildlife_btn_label'			=> esc_html__( 'Explore More', 'travelism-pro' ),

		// gallery
		'gallery_section_enable'		=> true,
		'gallery_content_type'			=> 'category',
		'gallery_count'					=> 4,
		'gallery_title'					=> esc_html__( 'Make your own memories', 'travelism-pro' ),
		'gallery_sub_title'				=> esc_html__('OUR GALLERY','travelism-pro'),
		'gallery_btn_label'				=> esc_html__( 'View All', 'travelism-pro' ),
		'gallery_posts_autoplay'		=> false,

		// happy_clients
		'happy_clients_section_enable'		=> true,
		'happy_clients_auto_play'			=> false,
		'happy_clients_content_type'		=> 'category',
		'happy_clients_count'				=> 4,
		'happy_clients_excerpt_length'		=> 30,
		'happy_clients_section_title'		=> esc_html__( 'Our Happy Clients', 'travelism-pro' ),
		'happy_clients_section_sub_title'	=> esc_html__( 'THANK YOU!', 'travelism-pro' ),

		//logos
		'logos_section_enable'		=> true,
		'logos_count'				=> 4,
		'logos_col_layout'			=> 'col-4',

		// articles
		'articles_section_enable'	=> true,
		'articles_content_type'		=> 'category',
		'articles_count'			=> 3,
		'articles_excerpt_length'	=> 15,
		'articles_title'			=> esc_html__( 'LATEST ARTICLES', 'travelism-pro' ),
		'articles_sub_title'		=> esc_html__( 'Blog', 'travelism-pro' ),

		// Slider
		'blog_slider_section_enable'		=> true,
		'blog_slider_autoplay'			=> false,
		'blog_slider_arrow'				=> false,
		'blog_slider_content_type'		=> 'category',
		'blog_slider_count'				=> 3,
		'blog_slider_excerpt_length'		=> 15,
		'blog_slider_btn_label'			=> esc_html__( 'Learn More', 'travelism-pro' ),

		// blog_featured_post
		'blog_featured_post_section_enable'	=> true,
		'blog_featured_post_content_type'		=> 'category',
		'blog_featured_post_count'				=> 3,
		'blog_featured_post_col_layout'			=> 'col-3',

		// blog_cta
		'blog_cta_section_enable'		=> true,
		'blog_cta_content_type'			=> 'page',
		'blog_cta_title'				=> esc_html__( 'We Are Awesome Agency', 'travelism-pro' ),
		'blog_cta_description'			=> esc_html__( 'Duis aute irure dolor in reprehenderit in voluptate velit esse cillum dolore eu fugiat nulla pariatur. Excepteur sint occaecat cupidatat non proident deserunt.', 'travelism-pro' ),
		'blog_cta_excerpt_length'		=> 25,

		// blog_popular_post
		'blog_popular_post_section_enable'	=> true,
		'blog_popular_post_content_type'		=> 'category',
		'blog_popular_post_count'			=> 4,
		'blog_popular_post_excerpt_length'	=> 20,
		'blog_popular_post_title'			=> esc_html__( 'Popular Post', 'travelism-pro' ),
		'blog_popular_post_btn'				=> esc_html__( 'Learn More', 'travelism-pro' ),

		// most_read_post
		'most_read_post_section_enable'		=> true,
		'most_read_post_content_type'		=> 'category',
		'most_read_post_count'				=> 4,
		'most_read_post_title'				=> esc_html__( 'You May Have Missed', 'travelism-pro' ),

		// subscribe_now
		'subscribe_now_section_enable'	=> true,
		'subscribe_now_title'			=> esc_html__( 'Travel with us!', 'travelism-pro' ),
		'subscribe_now_btn_title'		=> esc_html__( 'Subscribe Now', 'travelism-pro' ),

		// recent_post
		'recent_post_section_enable'	=> true,
		'recent_post_content_type'		=> 'category',
		'recent_post_count'				=> 3,
		'recent_post_excerpt_length'	=> 30,
		'recent_post_title'				=> esc_html__( 'Recent Post', 'travelism-pro' ),
		'recent_post_btn'				=> esc_html__( 'Learn More', 'travelism-pro' ),

		// business_service
		'business_service_section_enable'	=> true,
		'business_service_content_type'		=> 'category',
		'business_service_count'			=> 3,
		'business_service_excerpt_length'	=> 20,
		'business_service_title'			=> esc_html__( 'What We Provide', 'travelism-pro' ),
		'business_service_sub_title'		=> esc_html__( 'WHO WE ARE', 'travelism-pro' ),
		'business_service_btn'				=> esc_html__( 'Read More', 'travelism-pro' ),

		// business_about
		'business_about_section_enable'			=> true,
		'business_about_content_type'			=> 'page',
		'business_about_sub_title'				=> esc_html__( 'CREATIVE VISION', 'travelism-pro' ),
		'business_about_title'					=> esc_html__( 'We Help To Grow Your Business', 'travelism-pro' ),
		'business_about_description'				=> esc_html__( 'Between the many mouths to feed, entry to myriad attractions and school holiday price hikes, traveling with kids can quickly add up. Follow these top tips to make your hard-earned cash go further as you and your brood explore the world...', 'travelism-pro' ),
		'business_about_btn_title'				=> esc_html__( 'MORE ABOUT US', 'travelism-pro' ),
		'business_about_excerpt_length'			=> 50,

		// business_team
		'business_team_section_enable'		=> true,
		'business_team_content_type'		=> 'category',
		'business_team_count'				=> 3,
		'business_team_sub_title'			=> esc_html('OUR TEAM', 'travelism-pro'),
		'business_team_title'				=> esc_html('Who We Have', 'travelism-pro'),
		'business_team_column'				=> '3',

		//business_counter
		'business_counter_section_enable'		=> true,
		'business_counter_count'					=> 4,
		'business_counter_column'				=> 'col-4',

		//recent products
		'shop_recent_products_section_enable'		=> false,
		'shop_recent_products_content_type'			=> 'product-category',
		'shop_recent_products_count'				=> 4,
		'shop_recent_products_title'				=> esc_html__( 'Recent Products', 'travelism-pro' ),
		'shop_recent_products_sub_title'			=> esc_html__( 'ON SALE', 'travelism-pro' ),

		//trending_products 
		'trending_products_section_enable'				=> true,
		'trending_products_count'						=> 3,

		//featured section
		'featured_products_section_enable'		=> false,
	);

	$output = apply_filters( 'travelism_pro_default_theme_options', $travelism_pro_default_options );

	// Sort array in ascending order, according to the key:
	if ( ! empty( $output ) ) {
		ksort( $output );
	}

	return $output;
}