<?php
/**
 * Articles Section options
 *
 * @package Theme Palace
 * @subpackage Travelism Pro
 * @since Travelism Pro 1.0.0
 */

// Add Articles section
$wp_customize->add_section( 'travelism_articles_section', array(
	'title'             => esc_html__( 'Articles Section','travelism-pro' ),
	'description'       => esc_html__( 'Articles Section options.', 'travelism-pro' ),
	'panel'             => 'travelism_pro_front_page_panel',
	'active_callback'   => function( $control ) {
        return ( 
        	travelism_pro_is_default_layout( $control )  
        	||
        	travelism_pro_is_third_layout( $control )    
        	||
        	travelism_pro_is_fourth_layout( $control )  
        );
    },
) );

// Articles content enable control and setting
$wp_customize->add_setting( 'travelism_pro_theme_options[articles_section_enable]', array(
	'default'			=> 	$options['articles_section_enable'],
	'sanitize_callback' => 'travelism_pro_sanitize_switch_control',
) );

$wp_customize->add_control( new Travelism_Pro_Switch_Control( $wp_customize, 'travelism_pro_theme_options[articles_section_enable]', array(
	'label'             => esc_html__( 'Articles Section Enable', 'travelism-pro' ),
	'section'           => 'travelism_articles_section',
	'on_off_label' 		=> travelism_pro_switch_options(),
) ) );

if ( isset( $wp_customize->selective_refresh ) ) {
    $wp_customize->selective_refresh->add_partial( 'travelism_pro_theme_options[articles_section_enable]', array(
		'selector'            => '#travelism_articles_section .tooltiptext',
		'settings'            => 'travelism_pro_theme_options[articles_section_enable]',
    ) );
}

// Articles btn label setting and control
$wp_customize->add_setting( 'travelism_pro_theme_options[articles_sub_title]', array(
	'sanitize_callback' => 'sanitize_text_field',
	'default'			=> $options['articles_sub_title'],
	'transport'			=> 'postMessage',
) );

$wp_customize->add_control( 'travelism_pro_theme_options[articles_sub_title]', array(
	'label'           	=> esc_html__( 'Articles Sub Title', 'travelism-pro' ),
	'section'        	=> 'travelism_articles_section',
	'active_callback' 	=> 'travelism_pro_is_articles_section_enable',
	'type'				=> 'text',
) );

// Abort if selective refresh is not available.
if ( isset( $wp_customize->selective_refresh ) ) {
    $wp_customize->selective_refresh->add_partial( 'travelism_pro_theme_options[articles_sub_title]', array(
		'selector'            => '#travelism_articles_section .section-subtitle',
		'settings'            => 'travelism_pro_theme_options[articles_sub_title]',
		'container_inclusive' => false,
		'fallback_refresh'    => true,
		'render_callback'     => 'travelism_pro_articles_sub_title_partial',
    ) );
}

// Articles btn label setting and control
$wp_customize->add_setting( 'travelism_pro_theme_options[articles_title]', array(
	'sanitize_callback' => 'sanitize_text_field',
	'default'			=> $options['articles_title'],
	'transport'			=> 'postMessage',
) );

$wp_customize->add_control( 'travelism_pro_theme_options[articles_title]', array(
	'label'           	=> esc_html__( 'Articles Title', 'travelism-pro' ),
	'section'        	=> 'travelism_articles_section',
	'active_callback' 	=> 'travelism_pro_is_articles_section_enable',
	'type'				=> 'text',
) );

// Abort if selective refresh is not available.
if ( isset( $wp_customize->selective_refresh ) ) {
    $wp_customize->selective_refresh->add_partial( 'travelism_pro_theme_options[articles_title]', array(
		'selector'            => '#travelism_articles_section .section-title',
		'settings'            => 'travelism_pro_theme_options[articles_title]',
		'container_inclusive' => false,
		'fallback_refresh'    => true,
		'render_callback'     => 'travelism_pro_articles_title_partial',
    ) );
}

// content type control and setting
$wp_customize->add_setting( 'travelism_pro_theme_options[articles_count]', array(
	'default'          	=> $options['articles_count'],
	'sanitize_callback' => 'travelism_pro_sanitize_number_range',
	'validate_callback' => 'travelism_pro_validate_articles_count',
) );

$wp_customize->add_control( 'travelism_pro_theme_options[articles_count]', array(
	'label'             => esc_html__( 'Number of Posts', 'travelism-pro' ),
	'description'       => esc_html__( 'Note: Min 3 & Max 50. Please input the valid number and save. Then refresh the page to see the change.', 'travelism-pro' ),
	'section'           => 'travelism_articles_section',
	'active_callback'   => 'travelism_pro_is_articles_section_enable',
	'type'				=> 'number',
	'input_attrs'		=> array(
		'min'	=> 3,
		'max'	=> 50,
		'style' => 'width: 100px;'
		),
) );

// long Excerpt length setting and control.
$wp_customize->add_setting( 'travelism_pro_theme_options[articles_excerpt_length]', array(
	'sanitize_callback' => 'travelism_pro_sanitize_number_range',
	'validate_callback' => 'travelism_pro_validate_long_excerpt',
	'default'			=> $options['articles_excerpt_length'],
) );

$wp_customize->add_control( 'travelism_pro_theme_options[articles_excerpt_length]', array(
	'label'       		=> esc_html__( 'Article Excerpt Length', 'travelism-pro' ),
	'description' 		=> esc_html__( 'Total description words to be displayed in articles posts.', 'travelism-pro' ),
	'section'     		=> 'travelism_articles_section',
	'active_callback' 	=> 'travelism_pro_is_articles_section_enable',
	'type'        		=> 'number',
	'input_attrs' 		=> array(
		'style'       => 'width: 80px;',
		'max'         => 100,
		'min'         => 1,
	),
) );

// Articles content type control and setting
$wp_customize->add_setting( 'travelism_pro_theme_options[articles_content_type]', array(
	'default'          	=> $options['articles_content_type'],
	'sanitize_callback' => 'travelism_pro_sanitize_select',
) );

$wp_customize->add_control( 'travelism_pro_theme_options[articles_content_type]', array(
	'label'             => esc_html__( 'Content Type', 'travelism-pro' ),
	'section'           => 'travelism_articles_section',
	'type'				=> 'select',
	'active_callback' 	=> 'travelism_pro_is_articles_section_enable',
	'choices'			=> array(
		'page'      => esc_html__( 'Page', 'travelism-pro' ),
		'post'      => esc_html__( 'Post', 'travelism-pro' ),
		'category'  => esc_html__( 'Category', 'travelism-pro' ),
		),
) );

for ( $i = 1; $i <= $options['articles_count']; $i++ ) :
	// articles pages drop down chooser control and setting
	$wp_customize->add_setting( 'travelism_pro_theme_options[articles_content_page_' . $i . ']', array(
		'sanitize_callback' => 'travelism_pro_sanitize_page',
	) );

	$wp_customize->add_control( new Travelism_Pro_Dropdown_Chooser( $wp_customize, 'travelism_pro_theme_options[articles_content_page_' . $i . ']', array(
		'label'             => sprintf( esc_html__( 'Select Page %d', 'travelism-pro' ), $i ),
		'section'           => 'travelism_articles_section',
		'choices'			=> travelism_pro_page_choices(),
		'active_callback'	=> 'travelism_pro_is_articles_section_content_page_enable',
	) ) );

	// articles posts drop down chooser control and setting
	$wp_customize->add_setting( 'travelism_pro_theme_options[articles_content_post_' . $i . ']', array(
		'sanitize_callback' => 'travelism_pro_sanitize_page',
	) );

	$wp_customize->add_control( new Travelism_Pro_Dropdown_Chooser( $wp_customize, 'travelism_pro_theme_options[articles_content_post_' . $i . ']', array(
		'label'             => sprintf( esc_html__( 'Select Post %d', 'travelism-pro' ), $i ),
		'section'           => 'travelism_articles_section',
		'choices'			=> travelism_pro_post_choices(),
		'active_callback'	=> 'travelism_pro_is_articles_section_content_post_enable',
	) ) );

endfor;

// Add dropdown category setting and control.
$wp_customize->add_setting(  'travelism_pro_theme_options[articles_content_category]', array(
	'sanitize_callback' => 'travelism_pro_sanitize_single_category',
) ) ;

$wp_customize->add_control( new Travelism_Pro_Dropdown_Taxonomies_Control( $wp_customize,'travelism_pro_theme_options[articles_content_category]', array(
	'label'             => esc_html__( 'Select Category', 'travelism-pro' ),
	'description'      	=> esc_html__( 'Note: Latest selected no of posts will be shown from selected category', 'travelism-pro' ),
	'section'           => 'travelism_articles_section',
	'type'              => 'dropdown-taxonomies',
	'active_callback'	=> 'travelism_pro_is_articles_section_content_category_enable'
) ) );