<?php
/**
 * CTA Section options
 *
 * @package Theme Palace
 * @subpackage Travelism Pro
 * @since Travelism Pro 1.0.0
 */

// Add CTA section
$wp_customize->add_section( 'travelism_blog_cta_section', array(
	'title'             => esc_html__( 'CTA Section','travelism-pro' ),
	'description'       => esc_html__( 'CTA Section options.', 'travelism-pro' ),
	'panel'             => 'travelism_pro_front_page_panel',
	'active_callback'   => function( $control ) {
        return ( 
        	travelism_pro_is_second_layout( $control )  
        	||
        	travelism_pro_is_third_layout( $control )  
        	||
        	travelism_pro_is_fourth_layout( $control )  
        );
    },
) );

// CTA content enable control and setting
$wp_customize->add_setting( 'travelism_pro_theme_options[blog_cta_section_enable]', array(
	'default'			=> 	$options['blog_cta_section_enable'],
	'sanitize_callback' => 'travelism_pro_sanitize_switch_control',
) );

$wp_customize->add_control( new Travelism_Pro_Switch_Control( $wp_customize, 'travelism_pro_theme_options[blog_cta_section_enable]', array(
	'label'             => esc_html__( 'CTA Section Enable', 'travelism-pro' ),
	'section'           => 'travelism_blog_cta_section',
	'on_off_label' 		=> travelism_pro_switch_options(),
) ) );

if ( isset( $wp_customize->selective_refresh ) ) {
    $wp_customize->selective_refresh->add_partial( 'travelism_pro_theme_options[blog_cta_section_enable]', array(
		'selector'            => '#travelism_blog_cta_section .tooltiptext',
		'settings'            => 'travelism_pro_theme_options[blog_cta_section_enable]',
    ) );
}

$wp_customize->add_setting( 'travelism_pro_theme_options[blog_cta_bg_image]', array(
	'sanitize_callback' => 'travelism_pro_sanitize_image'
) );

$wp_customize->add_control( new WP_Customize_Image_Control( $wp_customize, 'travelism_pro_theme_options[blog_cta_bg_image]',
		array(
		'label'       		=> esc_html__( 'Background Image', 'travelism-pro' ),
		'section'     		=> 'travelism_blog_cta_section',
		'active_callback'	=> 'travelism_pro_is_blog_cta_section_enable',
) ) );

// long Excerpt length setting and control.
$wp_customize->add_setting( 'travelism_pro_theme_options[blog_cta_excerpt_length]', array(
	'sanitize_callback' => 'travelism_pro_sanitize_number_range',
	'validate_callback' => 'travelism_pro_validate_long_excerpt',
	'default'			=> $options['blog_cta_excerpt_length'],
) );

$wp_customize->add_control( 'travelism_pro_theme_options[blog_cta_excerpt_length]', array(
	'label'       		=> esc_html__( 'CTA Excerpt Length', 'travelism-pro' ),
	'description' 		=> esc_html__( 'Total description words to be displayed in blog_cta posts.', 'travelism-pro' ),
	'section'     		=> 'travelism_blog_cta_section',
	'active_callback' 	=> 'travelism_pro_is_blog_cta_section_enable',
	'type'        		=> 'number',
	'input_attrs' 		=> array(
		'style'       => 'width: 80px;',
		'max'         => 100,
		'min'         => 1,
	),
) );

// CTA content type control and setting
$wp_customize->add_setting( 'travelism_pro_theme_options[blog_cta_content_type]', array(
	'default'          	=> $options['blog_cta_content_type'],
	'sanitize_callback' => 'travelism_pro_sanitize_select',
) );

$wp_customize->add_control( 'travelism_pro_theme_options[blog_cta_content_type]', array(
	'label'             => esc_html__( 'Content Type', 'travelism-pro' ),
	'section'           => 'travelism_blog_cta_section',
	'type'				=> 'select',
	'active_callback' 	=> 'travelism_pro_is_blog_cta_section_enable',
	'choices'			=> array( 
		'page' 		=> esc_html__( 'Page', 'travelism-pro' ),
		'post' 		=> esc_html__( 'Post', 'travelism-pro' ),
		'custom' 	=> esc_html__( 'Custom', 'travelism-pro' ),
	),
) );

// blog_cta pages drop down chooser control and setting
$wp_customize->add_setting( 'travelism_pro_theme_options[blog_cta_content_page]', array(
	'sanitize_callback' => 'travelism_pro_sanitize_page',
) );

$wp_customize->add_control( new Travelism_Pro_Dropdown_Chooser( $wp_customize, 'travelism_pro_theme_options[blog_cta_content_page]', array(
	'label'             => esc_html__( 'Select Page', 'travelism-pro' ),
	'section'           => 'travelism_blog_cta_section',
	'choices'			=> travelism_pro_page_choices(),
	'active_callback'	=> 'travelism_pro_is_blog_cta_section_content_page_enable',
) ) );

// blog_cta posts drop down chooser control and setting
$wp_customize->add_setting( 'travelism_pro_theme_options[blog_cta_content_post]', array(
	'sanitize_callback' => 'travelism_pro_sanitize_page',
) );

$wp_customize->add_control( new Travelism_Pro_Dropdown_Chooser( $wp_customize, 'travelism_pro_theme_options[blog_cta_content_post]', array(
	'label'             => esc_html__( 'Select Post', 'travelism-pro' ),
	'section'           => 'travelism_blog_cta_section',
	'choices'			=> travelism_pro_post_choices(),
	'active_callback'	=> 'travelism_pro_is_blog_cta_section_content_post_enable',
) ) );

// blog_cta title setting and control
$wp_customize->add_setting( 'travelism_pro_theme_options[blog_cta_title]', array(
	'sanitize_callback' => 'sanitize_text_field',
	'default'			=> $options['blog_cta_title'],
) );

$wp_customize->add_control( 'travelism_pro_theme_options[blog_cta_title]', array(
	'label'           	=> esc_html__( 'Title', 'travelism-pro' ),
	'section'        	=> 'travelism_blog_cta_section',
	'active_callback' 	=> 'travelism_pro_is_blog_cta_section_content_custom_enable',
	'type'				=> 'text',
) );

// blog_cta description setting and control
$wp_customize->add_setting( 'travelism_pro_theme_options[blog_cta_description]', array(
	'sanitize_callback' => 'wp_kses_post',
	'default'			=> $options['blog_cta_description'],
) );

$wp_customize->add_control( 'travelism_pro_theme_options[blog_cta_description]', array(
	'label'           	=> esc_html__( 'Description', 'travelism-pro' ),
	'section'        	=> 'travelism_blog_cta_section',
	'active_callback' 	=> 'travelism_pro_is_blog_cta_section_content_custom_enable',
	'type'				=> 'textarea',
) );

$wp_customize->add_setting( 'travelism_pro_theme_options[blog_cta_video_url]', array(
'sanitize_callback' => 'esc_url_raw',
	) );

$wp_customize->add_control( 'travelism_pro_theme_options[blog_cta_video_url]', array(
	'label'           	=> esc_html__( 'Video URL', 'travelism-pro' ),
	'section'        	=> 'travelism_blog_cta_section',
	'active_callback' 	=> 'travelism_pro_is_blog_cta_section_enable',
	'type'				=> 'url',
) );