<?php
/**
 * Featured Posts Section options
 *
 * @package Theme Palace
 * @subpackage Travelism Pro
 * @since Travelism Pro 1.0.0
 */

// Add Featured Posts section
$wp_customize->add_section( 'travelism_blog_featured_post_section', array(
	'title'             => esc_html__( 'Featured Posts Section','travelism-pro' ),
	'description'       => esc_html__( 'Featured Posts Section options.', 'travelism-pro' ),
	'panel'             => 'travelism_pro_front_page_panel',
	'active_callback'   => function( $control ) {
        return ( 
        	travelism_pro_is_second_layout( $control )
        	||  
        	travelism_pro_is_fourth_layout( $control )  
        );
    },
) );

// Featured Posts content enable control and setting
$wp_customize->add_setting( 'travelism_pro_theme_options[blog_featured_post_section_enable]', array(
	'default'			=> 	$options['blog_featured_post_section_enable'],
	'sanitize_callback' => 'travelism_pro_sanitize_switch_control',
) );

$wp_customize->add_control( new Travelism_Pro_Switch_Control( $wp_customize, 'travelism_pro_theme_options[blog_featured_post_section_enable]', array(
	'label'             => esc_html__( 'Featured Posts Section Enable', 'travelism-pro' ),
	'section'           => 'travelism_blog_featured_post_section',
	'on_off_label' 		=> travelism_pro_switch_options(),
) ) );

if ( isset( $wp_customize->selective_refresh ) ) {
    $wp_customize->selective_refresh->add_partial( 'travelism_pro_theme_options[blog_featured_post_section_enable]', array(
		'selector'            => '#travelism_blog_featured_post_section .tooltiptext',
		'settings'            => 'travelism_pro_theme_options[blog_featured_post_section_enable]',
    ) );
}

// Event social icons number control and setting
$wp_customize->add_setting( 'travelism_pro_theme_options[blog_featured_post_count]', array(
	'default'          	=> $options['blog_featured_post_count'],
	'sanitize_callback' => 'travelism_pro_sanitize_number_range',
	'validate_callback' => 'travelism_pro_validate_blog_featured_post_count',
) );

$wp_customize->add_control( 'travelism_pro_theme_options[blog_featured_post_count]', array(
	'label'             => esc_html__( 'Number of Posts', 'travelism-pro' ),
	'description'       => esc_html__( 'Note: Min 1 & Max 50. Please input the valid number and save. Then refresh the page to see the change.', 'travelism-pro' ),
	'section'           => 'travelism_blog_featured_post_section',
	'active_callback'   => 'travelism_pro_is_blog_featured_post_section_enable',
	'type'				=> 'number',
	'input_attrs'		=> array(
		'min'	=> 1,
		'max'	=> 50,
		'style' => 'width: 100px;'
		),
) );

// Featured Posts content type control and setting
$wp_customize->add_setting( 'travelism_pro_theme_options[blog_featured_post_col_layout]', array(
	'default'          	=> $options['blog_featured_post_col_layout'],
	'sanitize_callback' => 'travelism_pro_sanitize_select',
) );

$wp_customize->add_control( 'travelism_pro_theme_options[blog_featured_post_col_layout]', array(
	'label'             => esc_html__( 'Content Type', 'travelism-pro' ),
	'section'           => 'travelism_blog_featured_post_section',
	'type'				=> 'select',
	'active_callback' 	=> 'travelism_pro_is_blog_featured_post_section_enable',
	'choices'			=> array( 
		'col-2'      => esc_html__( 'Two Column', 'travelism-pro' ),
		'col-3'      => esc_html__( 'Three Column', 'travelism-pro' ),
		'col-4'  	 => esc_html__( 'Four Column', 'travelism-pro' ),
		),
) );

// Featured Posts content type control and setting
$wp_customize->add_setting( 'travelism_pro_theme_options[blog_featured_post_content_type]', array(
	'default'          	=> $options['blog_featured_post_content_type'],
	'sanitize_callback' => 'travelism_pro_sanitize_select',
) );

$wp_customize->add_control( 'travelism_pro_theme_options[blog_featured_post_content_type]', array(
	'label'             => esc_html__( 'Content Type', 'travelism-pro' ),
	'section'           => 'travelism_blog_featured_post_section',
	'type'				=> 'select',
	'active_callback' 	=> 'travelism_pro_is_blog_featured_post_section_enable',
	'choices'			=> array( 
		'page'      => esc_html__( 'Page', 'travelism-pro' ),
		'post'      => esc_html__( 'Post', 'travelism-pro' ),
		'category'  => esc_html__( 'Category', 'travelism-pro' ),
		),
) );

for ( $i = 1; $i <= $options['blog_featured_post_count']; $i++ ) :

	// blog_featured_post pages drop down chooser control and setting
	$wp_customize->add_setting( 'travelism_pro_theme_options[blog_featured_post_content_page_' . $i . ']', array(
		'sanitize_callback' => 'travelism_pro_sanitize_page',
	) );

	$wp_customize->add_control( new Travelism_Pro_Dropdown_Chooser( $wp_customize, 'travelism_pro_theme_options[blog_featured_post_content_page_' . $i . ']', array(
		'label'             => sprintf( esc_html__( 'Select Page %d', 'travelism-pro' ), $i ),
		'section'           => 'travelism_blog_featured_post_section',
		'choices'			=> travelism_pro_page_choices(),
		'active_callback'	=> 'travelism_pro_is_blog_featured_post_section_content_page_enable',
	) ) );

	// blog_featured_post posts drop down chooser control and setting
	$wp_customize->add_setting( 'travelism_pro_theme_options[blog_featured_post_content_post_' . $i . ']', array(
		'sanitize_callback' => 'travelism_pro_sanitize_page',
	) );

	$wp_customize->add_control( new Travelism_Pro_Dropdown_Chooser( $wp_customize, 'travelism_pro_theme_options[blog_featured_post_content_post_' . $i . ']', array(
		'label'             => sprintf( esc_html__( 'Select Post %d', 'travelism-pro' ), $i ),
		'section'           => 'travelism_blog_featured_post_section',
		'choices'			=> travelism_pro_post_choices(),
		'active_callback'	=> 'travelism_pro_is_blog_featured_post_section_content_post_enable',
	) ) );

endfor;

// Add dropdown category setting and control.
$wp_customize->add_setting(  'travelism_pro_theme_options[blog_featured_post_content_category]', array(
	'sanitize_callback' => 'travelism_pro_sanitize_single_category',
) ) ;

$wp_customize->add_control( new Travelism_Pro_Dropdown_Taxonomies_Control( $wp_customize,'travelism_pro_theme_options[blog_featured_post_content_category]', array(
	'label'             => esc_html__( 'Select Category', 'travelism-pro' ),
	'description'      	=> esc_html__( 'Note: Latest selected no of posts will be shown from selected category', 'travelism-pro' ),
	'section'           => 'travelism_blog_featured_post_section',
	'type'              => 'dropdown-taxonomies',
	'active_callback'	=> 'travelism_pro_is_blog_featured_post_section_content_category_enable'
) ) );