<?php
/**
 * Slider Section options
 *
 * @package Theme Palace
 * @subpackage Travelism Pro
 * @since Travelism Pro 1.0.0
 */

// Add Slider section
$wp_customize->add_section( 'travelism_blog_slider_section', array(
	'title'             => esc_html__( 'Main Slider Section','travelism-pro' ),
	'description'       => esc_html__( 'Slider Section options.', 'travelism-pro' ),
	'panel'             => 'travelism_pro_front_page_panel',
	'active_callback'   => function( $control ) {
        return ( 
        	travelism_pro_is_second_layout( $control )
        	|| 
        	travelism_pro_is_third_layout( $control )
        	|| 
        	travelism_pro_is_fourth_layout( $control )  
        );
    },
) );

// Slider content enable control and setting
$wp_customize->add_setting( 'travelism_pro_theme_options[blog_slider_section_enable]', array(
	'default'			=> 	$options['blog_slider_section_enable'],
	'sanitize_callback' => 'travelism_pro_sanitize_switch_control',
) );

$wp_customize->add_control( new Travelism_Pro_Switch_Control( $wp_customize, 'travelism_pro_theme_options[blog_slider_section_enable]', array(
	'label'             => esc_html__( 'Slider Section Enable', 'travelism-pro' ),
	'section'           => 'travelism_blog_slider_section',
	'on_off_label' 		=> travelism_pro_switch_options(),
) ) );

if ( isset( $wp_customize->selective_refresh ) ) {
    $wp_customize->selective_refresh->add_partial( 'travelism_pro_theme_options[blog_slider_section_enable]', array(
		'selector'            => '#travelism_blog_slider_section .tooltiptext',
		'settings'            => 'travelism_pro_theme_options[blog_slider_section_enable]',
    ) );
}

// Slider content enable control and setting
$wp_customize->add_setting( 'travelism_pro_theme_options[blog_slider_autoplay]', array(
	'default'			=> 	$options['blog_slider_autoplay'],
	'sanitize_callback' => 'travelism_pro_sanitize_switch_control',
) );

$wp_customize->add_control( new Travelism_Pro_Switch_Control( $wp_customize, 'travelism_pro_theme_options[blog_slider_autoplay]', array(
	'label'             => esc_html__( 'Auto Play Enable', 'travelism-pro' ),
	'section'           => 'travelism_blog_slider_section',
	'on_off_label' 		=> travelism_pro_switch_options(),
	'active_callback' 	=> 'travelism_pro_is_blog_slider_section_enable',
) ) );

// Slider content enable control and setting
$wp_customize->add_setting( 'travelism_pro_theme_options[blog_slider_arrow]', array(
	'default'			=> 	$options['blog_slider_arrow'],
	'sanitize_callback' => 'travelism_pro_sanitize_switch_control',
) );

$wp_customize->add_control( new Travelism_Pro_Switch_Control( $wp_customize, 'travelism_pro_theme_options[blog_slider_arrow]', array(
	'label'             => esc_html__( 'Slider Arrow', 'travelism-pro' ),
	'section'           => 'travelism_blog_slider_section',
	'on_off_label' 		=> travelism_pro_switch_options(),
	'active_callback' 	=> 'travelism_pro_is_blog_slider_section_enable',
) ) );

// Slider btn label setting and control
$wp_customize->add_setting( 'travelism_pro_theme_options[blog_slider_btn_label]', array(
	'sanitize_callback' => 'sanitize_text_field',
	'default'			=> $options['blog_slider_btn_label'],
	'transport'			=> 'postMessage',
) );

$wp_customize->add_control( 'travelism_pro_theme_options[blog_slider_btn_label]', array(
	'label'           	=> esc_html__( 'Slider Button Label', 'travelism-pro' ),
	'section'        	=> 'travelism_blog_slider_section',
	'active_callback' 	=> 'travelism_pro_is_blog_slider_section_enable',
	'type'				=> 'text',
) );

// Abort if selective refresh is not available.
if ( isset( $wp_customize->selective_refresh ) ) {
    $wp_customize->selective_refresh->add_partial( 'travelism_pro_theme_options[blog_slider_btn_label]', array(
		'selector'            => '#travelism_blog_slider_section .btn-primary',
		'settings'            => 'travelism_pro_theme_options[blog_slider_btn_label]',
		'container_inclusive' => false,
		'fallback_refresh'    => true,
		'render_callback'     => 'travelism_pro_blog_slider_btn_label_partial',
    ) );
}

// Event social icons number control and setting
$wp_customize->add_setting( 'travelism_pro_theme_options[blog_slider_count]', array(
	'default'          	=> $options['blog_slider_count'],
	'sanitize_callback' => 'travelism_pro_sanitize_number_range',
	'validate_callback' => 'travelism_pro_validate_blog_slider_count',
) );

$wp_customize->add_control( 'travelism_pro_theme_options[blog_slider_count]', array(
	'label'             => esc_html__( 'Number of Slides', 'travelism-pro' ),
	'description'       => esc_html__( 'Note: Min 1 & Max 50. Please input the valid number and save. Then refresh the page to see the change.', 'travelism-pro' ),
	'section'           => 'travelism_blog_slider_section',
	'active_callback'   => 'travelism_pro_is_blog_slider_section_enable',
	'type'				=> 'number',
	'input_attrs'		=> array(
		'min'	=> 1,
		'max'	=> 50,
		'style' => 'width: 100px;'
		),
) );

// long Excerpt length setting and control.
$wp_customize->add_setting( 'travelism_pro_theme_options[blog_slider_excerpt_length]', array(
	'sanitize_callback' => 'travelism_pro_sanitize_number_range',
	'validate_callback' => 'travelism_pro_validate_long_excerpt',
	'default'			=> $options['blog_slider_excerpt_length'],
) );

$wp_customize->add_control( 'travelism_pro_theme_options[blog_slider_excerpt_length]', array(
	'label'       		=> esc_html__( 'Slider Excerpt Length', 'travelism-pro' ),
	'description' 		=> esc_html__( 'Total description words to be displayed in slider posts.', 'travelism-pro' ),
	'section'     		=> 'travelism_blog_slider_section',
	'active_callback' 	=> 'travelism_pro_is_blog_slider_section_enable',
	'type'        		=> 'number',
	'input_attrs' 		=> array(
		'style'       => 'width: 80px;',
		'max'         => 100,
		'min'         => 1,
	),
) );

// Slider content type control and setting
$wp_customize->add_setting( 'travelism_pro_theme_options[blog_slider_content_type]', array(
	'default'          	=> $options['blog_slider_content_type'],
	'sanitize_callback' => 'travelism_pro_sanitize_select',
) );

$wp_customize->add_control( 'travelism_pro_theme_options[blog_slider_content_type]', array(
	'label'             => esc_html__( 'Content Type', 'travelism-pro' ),
	'section'           => 'travelism_blog_slider_section',
	'type'				=> 'select',
	'active_callback' 	=> 'travelism_pro_is_blog_slider_section_enable',
	'choices'			=> array( 
		'page'      => esc_html__( 'Page', 'travelism-pro' ),
		'post'      => esc_html__( 'Post', 'travelism-pro' ),
		'category'  => esc_html__( 'Category', 'travelism-pro' ),
		),
) );

for ( $i = 1; $i <= $options['blog_slider_count']; $i++ ) :

	// Slider btn label setting and control
	$wp_customize->add_setting( 'travelism_pro_theme_options[blog_slider_subtitle_' . $i . ']', array(
		'sanitize_callback' => 'sanitize_text_field',
		) );

	$wp_customize->add_control( 'travelism_pro_theme_options[blog_slider_subtitle_' . $i . ']', array(
		'label'             => sprintf( esc_html__( 'Subtitle %d', 'travelism-pro' ), $i ),
		'section'        	=> 'travelism_blog_slider_section',
		'active_callback' 	=> 'travelism_pro_is_blog_slider_section_enable',
		'type'				=> 'text',
	) );

	// slider pages drop down chooser control and setting
	$wp_customize->add_setting( 'travelism_pro_theme_options[blog_slider_content_page_' . $i . ']', array(
		'sanitize_callback' => 'travelism_pro_sanitize_page',
	) );

	$wp_customize->add_control( new Travelism_Pro_Dropdown_Chooser( $wp_customize, 'travelism_pro_theme_options[blog_slider_content_page_' . $i . ']', array(
		'label'             => sprintf( esc_html__( 'Select Page %d', 'travelism-pro' ), $i ),
		'section'           => 'travelism_blog_slider_section',
		'choices'			=> travelism_pro_page_choices(),
		'active_callback'	=> 'travelism_pro_is_blog_slider_section_content_page_enable',
	) ) );

	// slider posts drop down chooser control and setting
	$wp_customize->add_setting( 'travelism_pro_theme_options[blog_slider_content_post_' . $i . ']', array(
		'sanitize_callback' => 'travelism_pro_sanitize_page',
	) );

	$wp_customize->add_control( new Travelism_Pro_Dropdown_Chooser( $wp_customize, 'travelism_pro_theme_options[blog_slider_content_post_' . $i . ']', array(
		'label'             => sprintf( esc_html__( 'Select Post %d', 'travelism-pro' ), $i ),
		'section'           => 'travelism_blog_slider_section',
		'choices'			=> travelism_pro_post_choices(),
		'active_callback'	=> 'travelism_pro_is_blog_slider_section_content_post_enable',
	) ) );


endfor;

// Add dropdown category setting and control.
$wp_customize->add_setting(  'travelism_pro_theme_options[blog_slider_content_category]', array(
	'sanitize_callback' => 'travelism_pro_sanitize_single_category',
) ) ;

$wp_customize->add_control( new Travelism_Pro_Dropdown_Taxonomies_Control( $wp_customize,'travelism_pro_theme_options[blog_slider_content_category]', array(
	'label'             => esc_html__( 'Select Category', 'travelism-pro' ),
	'description'      	=> esc_html__( 'Note: Latest selected no of posts will be shown from selected category', 'travelism-pro' ),
	'section'           => 'travelism_blog_slider_section',
	'type'              => 'dropdown-taxonomies',
	'active_callback'	=> 'travelism_pro_is_blog_slider_section_content_category_enable'
) ) );