<?php
/**
 * About Section options
 *
 * @package Theme Palace
 * @subpackage Travelism Pro
 * @since Travelism Pro 1.0.0
 */

// Add About section
$wp_customize->add_section( 'travelism_business_about_section', array(
	'title'             => esc_html__( 'About Us Section','travelism-pro' ),
	'description'       => esc_html__( 'About Us Section options.', 'travelism-pro' ),
	'panel'             => 'travelism_pro_front_page_panel',
	'active_callback'   => function( $control ) {
        return ( 
            travelism_pro_is_third_layout( $control )
            ||  
            travelism_pro_is_fourth_layout( $control )  
        );
    },
) );

// About content enable control and setting
$wp_customize->add_setting( 'travelism_pro_theme_options[business_about_section_enable]', array(
	'default'			=> 	$options['business_about_section_enable'],
	'sanitize_callback' => 'travelism_pro_sanitize_switch_control',
) );

$wp_customize->add_control( new Travelism_Pro_Switch_Control( $wp_customize, 'travelism_pro_theme_options[business_about_section_enable]', array(
	'label'             => esc_html__( 'About Section Enable', 'travelism-pro' ),
	'section'           => 'travelism_business_about_section',
	'on_off_label' 		=> travelism_pro_switch_options(),
) ) );

if ( isset( $wp_customize->selective_refresh ) ) {
    $wp_customize->selective_refresh->add_partial( 'travelism_pro_theme_options[business_about_section_enable]', array(
		'selector'            => '#travelism_business_about_section .tooltiptext',
		'settings'            => 'travelism_pro_theme_options[business_about_section_enable]',
    ) );
}

// long Excerpt length setting and control.
$wp_customize->add_setting( 'travelism_pro_theme_options[business_about_excerpt_length]', array(
	'sanitize_callback' => 'travelism_pro_sanitize_number_range',
	'validate_callback' => 'travelism_pro_validate_long_excerpt',
	'default'			=> $options['business_about_excerpt_length'],
) );

$wp_customize->add_control( 'travelism_pro_theme_options[business_about_excerpt_length]', array(
	'label'       		=> esc_html__( 'About Excerpt Length', 'travelism-pro' ),
	'description' 		=> esc_html__( 'Total description words to be displayed in business_about posts.', 'travelism-pro' ),
	'section'     		=> 'travelism_business_about_section',
	'active_callback' 	=> 'travelism_pro_is_business_about_section_enable',
	'type'        		=> 'number',
	'input_attrs' 		=> array(
		'style'       => 'width: 80px;',
		'max'         => 100,
		'min'         => 1,
	),
) );

// About content type control and setting
$wp_customize->add_setting( 'travelism_pro_theme_options[business_about_content_type]', array(
	'default'          	=> $options['business_about_content_type'],
	'sanitize_callback' => 'travelism_pro_sanitize_select',
) );

$wp_customize->add_control( 'travelism_pro_theme_options[business_about_content_type]', array(
	'label'             => esc_html__( 'Content Type', 'travelism-pro' ),
	'section'           => 'travelism_business_about_section',
	'type'				=> 'select',
	'active_callback' 	=> 'travelism_pro_is_business_about_section_enable',
	'choices'			=> array( 
		'page' 		=> esc_html__( 'Page', 'travelism-pro' ),
		'post' 		=> esc_html__( 'Post', 'travelism-pro' ),
		'custom' 	=> esc_html__( 'Custom', 'travelism-pro' ),
	),
) );

// about sub title setting and control
$wp_customize->add_setting( 'travelism_pro_theme_options[business_about_sub_title]', array(
	'sanitize_callback' => 'sanitize_text_field',
	'default'			=> $options['business_about_sub_title'],
	'transport'			=> 'postMessage',
) );

$wp_customize->add_control( 'travelism_pro_theme_options[business_about_sub_title]', array(
	'label'           	=> esc_html__( 'Sub Title', 'travelism-pro' ),
	'section'        	=> 'travelism_business_about_section',
	'active_callback' 	=> 'travelism_pro_is_business_about_section_enable',
	'type'				=> 'text',
) );

// Abort if selective refresh is not available.
if ( isset( $wp_customize->selective_refresh ) ) {
    $wp_customize->selective_refresh->add_partial( 'travelism_pro_theme_options[business_about_sub_title]', array(
		'selector'            => '#travelism_business_about_section .section-subtitle',
		'settings'            => 'travelism_pro_theme_options[business_about_sub_title]',
		'container_inclusive' => false,
		'fallback_refresh'    => true,
		'render_callback'     => 'travelism_pro_business_about_sub_title_partial',
    ) );
}

// about pages drop down chooser control and setting
$wp_customize->add_setting( 'travelism_pro_theme_options[business_about_content_page]', array(
	'sanitize_callback' => 'travelism_pro_sanitize_page',
) );

$wp_customize->add_control( new Travelism_Pro_Dropdown_Chooser( $wp_customize, 'travelism_pro_theme_options[business_about_content_page]', array(
	'label'             => esc_html__( 'Select Page', 'travelism-pro' ),
	'section'           => 'travelism_business_about_section',
	'choices'			=> travelism_pro_page_choices(),
	'active_callback'	=> 'travelism_pro_is_business_about_section_content_page_enable',
) ) );

// about posts drop down chooser control and setting
$wp_customize->add_setting( 'travelism_pro_theme_options[business_about_content_post]', array(
	'sanitize_callback' => 'travelism_pro_sanitize_page',
) );

$wp_customize->add_control( new Travelism_Pro_Dropdown_Chooser( $wp_customize, 'travelism_pro_theme_options[business_about_content_post]', array(
	'label'             => esc_html__( 'Select Post', 'travelism-pro' ),
	'section'           => 'travelism_business_about_section',
	'choices'			=> travelism_pro_post_choices(),
	'active_callback'	=> 'travelism_pro_is_business_about_section_content_post_enable',
) ) );

// about title setting and control
$wp_customize->add_setting( 'travelism_pro_theme_options[business_about_title]', array(
	'sanitize_callback' => 'sanitize_text_field',
	'default'			=> $options['business_about_title'],
) );

$wp_customize->add_control( 'travelism_pro_theme_options[business_about_title]', array(
	'label'           	=> esc_html__( 'Title', 'travelism-pro' ),
	'section'        	=> 'travelism_business_about_section',
	'active_callback' 	=> 'travelism_pro_is_business_about_section_content_custom_enable',
	'type'				=> 'text',
) );

// about description setting and control
$wp_customize->add_setting( 'travelism_pro_theme_options[business_about_description]', array(
	'sanitize_callback' => 'wp_kses_post',
	'default'			=> $options['business_about_description'],
) );

$wp_customize->add_control( 'travelism_pro_theme_options[business_about_description]', array(
	'label'           	=> esc_html__( 'Description', 'travelism-pro' ),
	'section'        	=> 'travelism_business_about_section',
	'active_callback' 	=> 'travelism_pro_is_business_about_section_content_custom_enable',
	'type'				=> 'textarea',
) );

// about btn title setting and control
$wp_customize->add_setting( 'travelism_pro_theme_options[business_about_btn_title]', array(
	'sanitize_callback' => 'sanitize_text_field',
	'default'			=> $options['business_about_btn_title'],
	'transport'			=> 'postMessage',
) );

$wp_customize->add_control( 'travelism_pro_theme_options[business_about_btn_title]', array(
	'label'           	=> esc_html__( 'Button Label', 'travelism-pro' ),
	'section'        	=> 'travelism_business_about_section',
	'active_callback' 	=> 'travelism_pro_is_business_about_section_enable',
	'type'				=> 'text',
) );

// Abort if selective refresh is not available.
if ( isset( $wp_customize->selective_refresh ) ) {
    $wp_customize->selective_refresh->add_partial( 'travelism_pro_theme_options[business_about_btn_title]', array(
		'selector'            => '#travelism_business_about_section .btn',
		'settings'            => 'travelism_pro_theme_options[business_about_btn_title]',
		'container_inclusive' => false,
		'fallback_refresh'    => true,
		'render_callback'     => 'travelism_pro_business_about_btn_title_partial',
    ) );
}

// about btn link setting and control
$wp_customize->add_setting( 'travelism_pro_theme_options[business_about_btn_link]', array(
	'sanitize_callback' => 'esc_url_raw',
) );

$wp_customize->add_control( 'travelism_pro_theme_options[business_about_btn_link]', array(
	'label'           	=> esc_html__( 'Button Link', 'travelism-pro' ),
	'section'        	=> 'travelism_business_about_section',
	'active_callback' 	=> 'travelism_pro_is_business_about_section_content_custom_enable',
	'type'				=> 'url',
) );

// about image setting and control.
$wp_customize->add_setting( 'travelism_pro_theme_options[business_about_image]', array(
	'sanitize_callback' => 'travelism_pro_sanitize_image'
) );

$wp_customize->add_control( new WP_Customize_Image_Control( $wp_customize, 'travelism_pro_theme_options[business_about_image]',
		array(
		'label'       		=> esc_html__( 'About Image', 'travelism-pro' ),
		'section'     		=> 'travelism_business_about_section',
		'active_callback'	=> 'travelism_pro_is_business_about_section_content_custom_enable',
) ) );