<?php
/**
 * Counter Section options
 *
 * @package Theme Palace
 * @subpackage Travelism Pro
 * @since Travelism Pro 1.0.0
 */

// Add Counter section
$wp_customize->add_section( 'travelism_business_counter_section', array(
	'title'             => esc_html__( 'Counter Section','travelism-pro' ),
	'description'       => esc_html__( 'Counter Section options.', 'travelism-pro' ),
	'panel'             => 'travelism_pro_front_page_panel',
	'active_callback'   => function( $control ) {
        return ( 
        	travelism_pro_is_third_layout( $control )  
        );
    },
) );

// Counter content enable control and setting
$wp_customize->add_setting( 'travelism_pro_theme_options[business_counter_section_enable]', array(
	'default'			=> 	$options['business_counter_section_enable'],
	'sanitize_callback' => 'travelism_pro_sanitize_switch_control',
) );

$wp_customize->add_control( new Travelism_Pro_Switch_Control( $wp_customize, 'travelism_pro_theme_options[business_counter_section_enable]', array(
	'label'             => esc_html__( 'Counter Section Enable', 'travelism-pro' ),
	'section'           => 'travelism_business_counter_section',
	'on_off_label' 		=> travelism_pro_switch_options(),
) ) );

if ( isset( $wp_customize->selective_refresh ) ) {
    $wp_customize->selective_refresh->add_partial( 'travelism_pro_theme_options[business_counter_section_enable]', array(
		'selector'            => '#travelism_business_counter_section .tooltiptext',
		'settings'            => 'travelism_pro_theme_options[business_counter_section_enable]',
    ) );
}

// counter image setting and control.
$wp_customize->add_setting( 'travelism_pro_theme_options[business_counter_image]', array(
	'sanitize_callback' => 'travelism_pro_sanitize_image'
) );

$wp_customize->add_control( new WP_Customize_Image_Control( $wp_customize, 'travelism_pro_theme_options[business_counter_image]',
		array(
		'label'       		=> esc_html__( 'Counter BG Image', 'travelism-pro' ),
		'section'     		=> 'travelism_business_counter_section',
		'active_callback'	=> 'travelism_pro_is_business_counter_section_enable',
) ) );

// counter number control and setting
$wp_customize->add_setting( 'travelism_pro_theme_options[business_counter_count]', array(
	'default'          	=> $options['business_counter_count'],
	'sanitize_callback' => 'travelism_pro_sanitize_number_range',
	'validate_callback' => 'travelism_pro_validate_business_counter_count',
) );

$wp_customize->add_control( 'travelism_pro_theme_options[business_counter_count]', array(
	'label'             => esc_html__( 'Number of Posts', 'travelism-pro' ),
	'description'       => esc_html__( 'Note: Min 1 & Max 50. Please input the valid number and save. Then refresh the page to see the change.', 'travelism-pro' ),
	'section'           => 'travelism_business_counter_section',
	'active_callback'   => 'travelism_pro_is_business_counter_section_enable',
	'type'				=> 'number',
	'input_attrs'		=> array(
		'min'	=> 1,
		'max'	=> 50,
		'style' => 'width: 100px;'
		),
) );

// Counter content type control and setting
$wp_customize->add_setting( 'travelism_pro_theme_options[business_counter_column]', array(
	'default'          	=> $options['business_counter_column'],
	'sanitize_callback' => 'travelism_pro_sanitize_select',
) );

$wp_customize->add_control( 'travelism_pro_theme_options[business_counter_column]', array(
	'label'             => esc_html__( 'Column Layout', 'travelism-pro' ),
	'section'           => 'travelism_business_counter_section',
	'type'				=> 'select',
	'active_callback' 	=> 'travelism_pro_is_business_counter_section_enable',
	'choices'			=> array(
		'col-3'      => esc_html__( 'Three Column', 'travelism-pro' ),
		'col-4'      => esc_html__( 'Four Column', 'travelism-pro' ),
		),
) );

for ( $i = 1; $i <= $options['business_counter_count']; $i++ ) :

// counter note control and setting
	$wp_customize->add_setting( 'travelism_pro_theme_options[business_counter_icon_' . $i . ']', array(
		'sanitize_callback' => 'sanitize_text_field',
	) );

	$wp_customize->add_control( new Travelism_Pro_Icon_Picker( $wp_customize, 'travelism_pro_theme_options[business_counter_icon_' . $i . ']', array(
		'label'             => sprintf( esc_html__( 'Select Icon %d', 'travelism-pro' ), $i ),
		'section'           => 'travelism_business_counter_section',
		'active_callback'	=> 'travelism_pro_is_business_counter_section_enable',
	) ) );

	// counter title setting and control
	$wp_customize->add_setting( 'travelism_pro_theme_options[business_counter_value_' . $i . ']', array(
		'sanitize_callback' => 'sanitize_text_field',
	) );

	$wp_customize->add_control( 'travelism_pro_theme_options[business_counter_value_' . $i . ']', array(
		'label'           	=> sprintf( esc_html__( 'Value %d', 'travelism-pro' ), $i ),
		'section'        	=> 'travelism_business_counter_section',
		'active_callback' 	=> 'travelism_pro_is_business_counter_section_enable',
		'type'				=> 'text',
	) );

	// counter position setting and control
	$wp_customize->add_setting( 'travelism_pro_theme_options[business_counter_label_' . $i . ']', array(
		'sanitize_callback' => 'sanitize_text_field',
	) );

	$wp_customize->add_control( 'travelism_pro_theme_options[business_counter_label_' . $i . ']', array(
		'label'           	=> sprintf( esc_html__( 'Label %d', 'travelism-pro' ), $i ),
		'section'        	=> 'travelism_business_counter_section',
		'active_callback' 	=> 'travelism_pro_is_business_counter_section_enable',
		'type'				=> 'text',
	) );

	// counter hr setting and control
	$wp_customize->add_setting( 'travelism_pro_theme_options[business_counter_hr_'. $i .']', array(
		'sanitize_callback' => 'sanitize_text_field'
	) );

	$wp_customize->add_control( new Travelism_Pro_Customize_Horizontal_Line( $wp_customize, 'travelism_pro_theme_options[business_counter_hr_'. $i .']',
		array(
			'section'         => 'travelism_business_counter_section',
			'active_callback' => 'travelism_pro_is_business_counter_section_enable',
			'type'			  => 'hr'
	) ) );
endfor;