<?php
/**
 * Team Section options
 *
 * @package Theme Palace
 * @subpackage Travelism Pro
 * @since Travelism Pro 1.0.0
 */

// Add Team section
$wp_customize->add_section( 'travelism_business_team_section', array(
	'title'             => esc_html__( 'Teams Section','travelism-pro' ),
	'description'       => esc_html__( 'Teams Section options.', 'travelism-pro' ),
	'panel'             => 'travelism_pro_front_page_panel',
	'active_callback'   => function( $control ) {
        return ( 
        	travelism_pro_is_third_layout( $control )  
        );
    },
) );

// Team content enable control and setting
$wp_customize->add_setting( 'travelism_pro_theme_options[business_team_section_enable]', array(
	'default'			=> 	$options['business_team_section_enable'],
	'sanitize_callback' => 'travelism_pro_sanitize_switch_control',
) );

$wp_customize->add_control( new Travelism_Pro_Switch_Control( $wp_customize, 'travelism_pro_theme_options[business_team_section_enable]', array(
	'label'             => esc_html__( 'Team Section Enable', 'travelism-pro' ),
	'section'           => 'travelism_business_team_section',
	'on_off_label' 		=> travelism_pro_switch_options(),
) ) );

if ( isset( $wp_customize->selective_refresh ) ) {
    $wp_customize->selective_refresh->add_partial( 'travelism_pro_theme_options[business_team_section_enable]', array(
		'selector'            => '#travelism_business_team_section .tooltiptext',
		'settings'            => 'travelism_pro_theme_options[business_team_section_enable]',
    ) );
}

// team sub title
$wp_customize->add_setting( 'travelism_pro_theme_options[business_team_sub_title]', array(
	'default'          	=> $options['business_team_sub_title'],
	'sanitize_callback' => 'sanitize_textarea_field',
	'transport'			=> 'postMessage',
) );

$wp_customize->add_control( 'travelism_pro_theme_options[business_team_sub_title]', array(
	'label'             => esc_html__( 'Sub Title', 'travelism-pro' ),
	'section'           => 'travelism_business_team_section',
	'active_callback'	=> 'travelism_pro_is_business_team_section_enable',
	'type'				=> 'text',
) );

// Abort if selective refresh is not available.
if ( isset( $wp_customize->selective_refresh ) ) {
    $wp_customize->selective_refresh->add_partial( 'travelism_pro_theme_options[business_team_sub_title]', array(
		'selector'            => '#travelism_business_team_section .section-subtitle',
		'settings'            => 'travelism_pro_theme_options[business_team_sub_title]',
		'container_inclusive' => false,
		'fallback_refresh'    => true,
		'render_callback'     => 'travelism_pro_business_team_sub_title_partial',
    ) );
}

// team title setting and control
$wp_customize->add_setting( 'travelism_pro_theme_options[business_team_title]', array(
	'sanitize_callback' => 'sanitize_text_field',
	'default'			=> $options['business_team_title'],
	'transport'			=> 'postMessage',
) );

$wp_customize->add_control( 'travelism_pro_theme_options[business_team_title]', array(
	'label'           	=> esc_html__( 'Title', 'travelism-pro' ),
	'section'        	=> 'travelism_business_team_section',
	'active_callback' 	=> 'travelism_pro_is_business_team_section_enable',
	'type'				=> 'text',
) );

// Abort if selective refresh is not available.
if ( isset( $wp_customize->selective_refresh ) ) {
    $wp_customize->selective_refresh->add_partial( 'travelism_pro_theme_options[business_team_title]', array(
		'selector'            => '#travelism_business_team_section .section-title',
		'settings'            => 'travelism_pro_theme_options[business_team_title]',
		'container_inclusive' => false,
		'fallback_refresh'    => true,
		'render_callback'     => 'travelism_pro_business_team_title_partial',
    ) );
}

// team content type control and setting
$wp_customize->add_setting( 'travelism_pro_theme_options[business_team_column]', array(
	'default'          	=> $options['business_team_column'],
	'sanitize_callback' => 'travelism_pro_sanitize_select',
) );

$wp_customize->add_control( 'travelism_pro_theme_options[business_team_column]', array(
	'label'             => esc_html__( 'Column Layout', 'travelism-pro' ),
	'section'           => 'travelism_business_team_section',
	'type'				=> 'select',
	'active_callback' 	=> 'travelism_pro_is_business_team_section_enable',
	'choices'			=> array(
		'3'		=> esc_html__( 'Three Column', 'travelism-pro' ),
		'4'		=> esc_html__( 'Four Column', 'travelism-pro' ),
	),
) );

// Team content type control and setting
$wp_customize->add_setting( 'travelism_pro_theme_options[business_team_content_type]', array(
	'default'          	=> $options['business_team_content_type'],
	'sanitize_callback' => 'travelism_pro_sanitize_select',
) );

$wp_customize->add_control( 'travelism_pro_theme_options[business_team_content_type]', array(
	'label'             => esc_html__( 'Content Type', 'travelism-pro' ),
	'section'           => 'travelism_business_team_section',
	'type'				=> 'select',
	'active_callback' 	=> 'travelism_pro_is_business_team_section_enable',
	'choices'			=> array( 
		'page' 		=> esc_html__( 'Page', 'travelism-pro' ),
		'post' 		=> esc_html__( 'Post', 'travelism-pro' ),
		'category' 	=> esc_html__( 'Category', 'travelism-pro' ),
	),
) );

// Event social icons number control and setting
$wp_customize->add_setting( 'travelism_pro_theme_options[business_team_count]', array(
	'default'          	=> $options['business_team_count'],
	'sanitize_callback' => 'travelism_pro_sanitize_number_range',
	'validate_callback' => 'travelism_pro_validate_business_team_count',
) );

$wp_customize->add_control( 'travelism_pro_theme_options[business_team_count]', array(
	'label'             => esc_html__( 'Number of Teams', 'travelism-pro' ),
	'description'       => esc_html__( 'Note: Min 1 & Max 50. Please input the valid number and save. Then refresh the page to see the change.', 'travelism-pro' ),
	'section'           => 'travelism_business_team_section',
	'active_callback'   => 'travelism_pro_is_business_team_section_enable',
	'type'				=> 'number',
	'input_attrs'		=> array(
		'min'	=> 1,
		'max'	=> 50,
		'style' => 'width: 100px;'
		),
) );

// Add dropdown category setting and control.
$wp_customize->add_setting(  'travelism_pro_theme_options[business_team_content_category]', array(
	'sanitize_callback' => 'travelism_pro_sanitize_single_category',
) ) ;

$wp_customize->add_control( new Travelism_Pro_Dropdown_Taxonomies_Control( $wp_customize,'travelism_pro_theme_options[business_team_content_category]', array(
	'label'             => esc_html__( 'Select Category', 'travelism-pro' ),
	'description'      	=> esc_html__( 'Note: Latest selected no of posts will be shown from selected category', 'travelism-pro' ),
	'section'           => 'travelism_business_team_section',
	'type'              => 'dropdown-taxonomies',
	'active_callback'	=> 'travelism_pro_is_business_team_section_content_category_enable'
) ) );

for ( $i = 1; $i <= $options['business_team_count']; $i++ ) :

	// team pages drop down chooser control and setting
	$wp_customize->add_setting( 'travelism_pro_theme_options[business_team_content_page_' . $i . ']', array(
		'sanitize_callback' => 'travelism_pro_sanitize_page',
	) );

	$wp_customize->add_control( new Travelism_Pro_Dropdown_Chooser( $wp_customize, 'travelism_pro_theme_options[business_team_content_page_' . $i . ']', array(
		'label'             => sprintf( esc_html__( 'Select Page %d', 'travelism-pro' ), $i ),
		'section'           => 'travelism_business_team_section',
		'choices'			=> travelism_pro_page_choices(),
		'active_callback'	=> 'travelism_pro_is_business_team_section_content_page_enable',
	) ) );

	// team posts drop down chooser control and setting
	$wp_customize->add_setting( 'travelism_pro_theme_options[business_team_content_post_' . $i . ']', array(
		'sanitize_callback' => 'travelism_pro_sanitize_page',
	) );

	$wp_customize->add_control( new Travelism_Pro_Dropdown_Chooser( $wp_customize, 'travelism_pro_theme_options[business_team_content_post_' . $i . ']', array(
		'label'             => sprintf( esc_html__( 'Select Post %d', 'travelism-pro' ), $i ),
		'section'           => 'travelism_business_team_section',
		'choices'			=> travelism_pro_post_choices(),
		'active_callback'	=> 'travelism_pro_is_business_team_section_content_post_enable',
	) ) );

	// team custom content
	$wp_customize->add_setting( 'travelism_pro_theme_options[business_team_position_' . $i . ']', array(
		'sanitize_callback' => 'wp_kses_post',
	) );

	$wp_customize->add_control( 'travelism_pro_theme_options[business_team_position_' . $i . ']', array(
		'label'             => sprintf( esc_html__( 'Position %d', 'travelism-pro' ), $i ),
		'section'           => 'travelism_business_team_section',
		'active_callback'	=> 'travelism_pro_is_business_team_section_enable',
	) );

	// team social
	$wp_customize->add_setting( 'travelism_pro_theme_options[business_team_social_' . $i. ']', array(
		'sanitize_callback' => 'esc_url_raw',
	) );

	$wp_customize->add_control( new Travelism_Pro_Multi_Input_Custom_Control( $wp_customize, 'travelism_pro_theme_options[business_team_social_' . $i. ']', array(
		'label'             => esc_html__( 'Social ', 'travelism-pro' ),
		'button_text'       => esc_html__( 'Add social.', 'travelism-pro' ),
		'section'           => 'travelism_business_team_section',
		'active_callback' 	=> 'travelism_pro_is_business_team_section_enable',
	) ) );

	// team hr setting and control
	$wp_customize->add_setting( 'travelism_pro_theme_options[business_team_hr_'. $i .']', array(
		'sanitize_callback' => 'sanitize_text_field'
	) );

	$wp_customize->add_control( new Travelism_Pro_Customize_Horizontal_Line( $wp_customize, 'travelism_pro_theme_options[business_team_hr_'. $i .']',
		array(
			'section'         => 'travelism_business_team_section',
			'active_callback' => 'travelism_pro_is_business_team_section_enable',
			'type'			  => 'hr'
	) ) );

endfor;