<?php
/**
 * Featured Section options
 *
 * @package Theme Palace
 * @subpackage Travelism Pro
 * @since Travelism Pro 1.0.0
 */

// Add Featured section
$wp_customize->add_section( 'travelism_featured_section', array(
	'title'             => esc_html__( 'Featured Section','travelism-pro' ),
	'description'       => esc_html__( 'Featured Section options.', 'travelism-pro' ),
	'panel'             => 'travelism_pro_front_page_panel',
	'active_callback'   => function( $control ) {
        return ( 
        	travelism_pro_is_default_layout( $control )  
        );
    },

) );

// Featured content enable control and setting
$wp_customize->add_setting( 'travelism_pro_theme_options[featured_section_enable]', array(
	'default'			=> 	$options['featured_section_enable'],
	'sanitize_callback' => 'travelism_pro_sanitize_switch_control',
) );

$wp_customize->add_control( new Travelism_Pro_Switch_Control( $wp_customize, 'travelism_pro_theme_options[featured_section_enable]', array(
	'label'             => esc_html__( 'Featured Section Enable', 'travelism-pro' ),
	'section'           => 'travelism_featured_section',
	'on_off_label' 		=> travelism_pro_switch_options(),
) ) );

if ( isset( $wp_customize->selective_refresh ) ) {
    $wp_customize->selective_refresh->add_partial( 'travelism_pro_theme_options[featured_section_enable]', array(
		'selector'            => '#travelism_featured_section .tooltiptext',
		'settings'            => 'travelism_pro_theme_options[featured_section_enable]',
    ) );
}

// popular destination sub title setting and control
$wp_customize->add_setting( 'travelism_pro_theme_options[featured_sub_title]', array(
	'default'			=> $options['featured_sub_title'],
	'sanitize_callback' => 'sanitize_text_field',
	'transport'			=> 'postMessage',
) );

$wp_customize->add_control( 'travelism_pro_theme_options[featured_sub_title]', array(
	'label'           	=> esc_html__( 'Sub Title', 'travelism-pro' ),
	'section'        	=> 'travelism_featured_section',
	'active_callback' 	=> 'travelism_pro_is_featured_section_enable',
	'type'				=> 'text',
) );

// Abort if selective refresh is not available.
if ( isset( $wp_customize->selective_refresh ) ) {
    $wp_customize->selective_refresh->add_partial( 'travelism_pro_theme_options[featured_sub_title]', array(
		'selector'            => '#travelism_featured_section .section-subtitle',
		'settings'            => 'travelism_pro_theme_options[featured_sub_title]',
		'container_inclusive' => false,
		'fallback_refresh'    => true,
		'render_callback'     => 'travelism_pro_featured_sub_title_partial',
    ) );
}

// popular destination title setting and control
$wp_customize->add_setting( 'travelism_pro_theme_options[featured_title]', array(
	'default'			=> $options['featured_title'],
	'sanitize_callback' => 'sanitize_text_field',
	'transport'			=> 'postMessage',
) );

$wp_customize->add_control( 'travelism_pro_theme_options[featured_title]', array(
	'label'           	=> esc_html__( 'Title', 'travelism-pro' ),
	'section'        	=> 'travelism_featured_section',
	'active_callback' 	=> 'travelism_pro_is_featured_section_enable',
	'type'				=> 'text',
) );

// Abort if selective refresh is not available.
if ( isset( $wp_customize->selective_refresh ) ) {
    $wp_customize->selective_refresh->add_partial( 'travelism_pro_theme_options[featured_title]', array(
		'selector'            => '#travelism_featured_section .section-title',
		'settings'            => 'travelism_pro_theme_options[featured_title]',
		'container_inclusive' => false,
		'fallback_refresh'    => true,
		'render_callback'     => 'travelism_pro_featured_title_partial',
    ) );
}

//Featured post count number control and setting
$wp_customize->add_setting( 'travelism_pro_theme_options[featured_count]', array(
	'default'          	=> $options['featured_count'],
	'sanitize_callback' => 'travelism_pro_sanitize_number_range',
	'validate_callback' => 'travelism_pro_validate_featured_count',
) );

$wp_customize->add_control( 'travelism_pro_theme_options[featured_count]', array(
	'label'             => esc_html__( 'Number of Posts', 'travelism-pro' ),
	'description'       => esc_html__( 'Note: Min 3 & Max 50. Please input the valid number and save. Then refresh the page to see the change.', 'travelism-pro' ),
	'section'           => 'travelism_featured_section',
	'active_callback'   => 'travelism_pro_is_featured_section_enable',
	'type'				=> 'number',
	'input_attrs'		=> array(
		'min'	=> 3,
		'max'	=> 50,
		'style' => 'width: 100px;'
		),
) );

// Popular deatination btn label setting and control
$wp_customize->add_setting( 'travelism_pro_theme_options[featured_btn_label]', array(
	'sanitize_callback' => 'sanitize_text_field',
	'default'			=> $options['featured_btn_label'],
) );

$wp_customize->add_control( 'travelism_pro_theme_options[featured_btn_label]', array(
	'label'           	=> esc_html__( 'Featured Button Label', 'travelism-pro' ),
	'section'        	=> 'travelism_featured_section',
	'active_callback' 	=> 'travelism_pro_is_featured_section_enable',
	'type'				=> 'text',
) );


// Featured content enable control and setting
$wp_customize->add_setting( 'travelism_pro_theme_options[featured_posts_autoplay]', array(
	'default'			=> 	$options['featured_posts_autoplay'],
	'sanitize_callback' => 'travelism_pro_sanitize_switch_control',
) );

$wp_customize->add_control( new Travelism_Pro_Switch_Control( $wp_customize, 'travelism_pro_theme_options[featured_posts_autoplay]', array(
	'label'             => esc_html__( 'Autoplay Enable', 'travelism-pro' ),
	'section'           => 'travelism_featured_section',
	'on_off_label' 		=> travelism_pro_switch_options(),
	'active_callback' 	=> 'travelism_pro_is_featured_section_enable',
) ) );

// Featured content type control and setting
$wp_customize->add_setting( 'travelism_pro_theme_options[featured_content_type]', array(
	'default'          	=> $options['featured_content_type'],
	'sanitize_callback' => 'travelism_pro_sanitize_select',
) );

$wp_customize->add_control( 'travelism_pro_theme_options[featured_content_type]', array(
	'label'             => esc_html__( 'Content Type', 'travelism-pro' ),
	'section'           => 'travelism_featured_section',
	'type'				=> 'select',
	'active_callback' 	=> 'travelism_pro_is_featured_section_enable',
	'choices'			=> travelism_pro_featured_content_type(),
) );

for ( $i=1; $i <= $options['featured_count']; $i++ ) { 
	// Popular deatination pages drop down chooser control and setting
	$wp_customize->add_setting( 'travelism_pro_theme_options[featured_content_page_' . $i . ']', array(
		'sanitize_callback' => 'travelism_pro_sanitize_page',
	) );

	$wp_customize->add_control( new Travelism_Pro_Dropdown_Chooser( $wp_customize, 'travelism_pro_theme_options[featured_content_page_' . $i . ']', array(
		'label'             => sprintf ( esc_html__( 'Select Page %d', 'travelism-pro' ), $i ),
		'section'           => 'travelism_featured_section',
		'choices'			=> travelism_pro_page_choices(),
		'active_callback'	=> 'travelism_pro_is_featured_section_content_page_enable',
	) ) );

	// Popular deatination posts drop down chooser control and setting
	$wp_customize->add_setting( 'travelism_pro_theme_options[featured_content_post_' . $i . ']', array(
		'sanitize_callback' => 'travelism_pro_sanitize_page',
	) );

	$wp_customize->add_control( new Travelism_Pro_Dropdown_Chooser( $wp_customize, 'travelism_pro_theme_options[featured_content_post_' . $i . ']', array(
		'label'             => sprintf ( esc_html__( 'Select posts %d', 'travelism-pro' ), $i ),
		'section'           => 'travelism_featured_section',
		'choices'			=> travelism_pro_post_choices(),
		'active_callback'	=> 'travelism_pro_is_featured_section_content_post_enable',
	) ) );

	// featured trips drop down chooser control and setting
	$wp_customize->add_setting( 'travelism_pro_theme_options[featured_content_trip_' . $i . ']', array(
		'sanitize_callback' => 'travelism_pro_sanitize_page',
	) );

	$wp_customize->add_control( new Travelism_Pro_Dropdown_Chooser( $wp_customize, 'travelism_pro_theme_options[featured_content_trip_' . $i . ']', array(
		'label'             => sprintf ( esc_html__( 'Select Trip %d', 'travelism-pro' ), $i ),
		'section'           => 'travelism_featured_section',
		'choices'			=> travelism_pro_trip_choices(),
		'active_callback'	=> 'travelism_pro_is_featured_section_content_trip_enable',
	) ) );
}

// Add dropdown category setting and control.
$wp_customize->add_setting(  'travelism_pro_theme_options[featured_content_category]', array(
	'sanitize_callback' => 'travelism_pro_sanitize_single_category',
) ) ;

$wp_customize->add_control( new Travelism_Pro_Dropdown_Taxonomies_Control( $wp_customize,'travelism_pro_theme_options[featured_content_category]', array(
	'label'             => esc_html__( 'Select Category', 'travelism-pro' ),
	'description'      	=> esc_html__( 'Note: Latest selected no of posts will be shown from selected category', 'travelism-pro' ),
	'section'           => 'travelism_featured_section',
	'type'              => 'dropdown-taxonomies',
	'active_callback'	=> 'travelism_pro_is_featured_section_content_category_enable'
) ) );

// Add dropdown category setting and control.
$wp_customize->add_setting(  'travelism_pro_theme_options[featured_content_trip_types]', array(
	'sanitize_callback' => 'absint',
) ) ;

$wp_customize->add_control( new Travelism_Pro_Dropdown_Taxonomies_Control( $wp_customize,'travelism_pro_theme_options[featured_content_trip_types]', array(
	'label'             => esc_html__( 'Select Trip Types', 'travelism-pro' ),
	'section'           => 'travelism_featured_section',
	'taxonomy'			=> 'itinerary_types',
	'type'              => 'dropdown-taxonomies',
	'active_callback'	=> 'travelism_pro_is_featured_section_content_trip_types_enable'
) ) );

// Add dropdown category setting and control.
$wp_customize->add_setting(  'travelism_pro_theme_options[featured_content_activity]', array(
	'sanitize_callback' => 'absint',
) ) ;

$wp_customize->add_control( new Travelism_Pro_Dropdown_Taxonomies_Control( $wp_customize,'travelism_pro_theme_options[featured_content_activity]', array(
	'label'             => esc_html__( 'Select Activities', 'travelism-pro' ),
	'section'           => 'travelism_featured_section',
	'taxonomy'			=> 'activity',
	'type'              => 'dropdown-taxonomies',
	'active_callback'	=> 'travelism_pro_is_featured_section_content_activity_enable'
) ) );

// Add dropdown category setting and control.
$wp_customize->add_setting(  'travelism_pro_theme_options[featured_content_destination]', array(
	'sanitize_callback' => 'absint',
) ) ;

$wp_customize->add_control( new Travelism_Pro_Dropdown_Taxonomies_Control( $wp_customize,'travelism_pro_theme_options[featured_content_destination]', array(
	'label'             => esc_html__( 'Select Destinations', 'travelism-pro' ),
	'section'           => 'travelism_featured_section',
	'taxonomy'			=> 'travel_locations',
	'type'              => 'dropdown-taxonomies',
	'active_callback'	=> 'travelism_pro_is_featured_section_content_destination_enable'
) ) );


