<?php
/**
 * Happy Clients Section options
 *
 * @package Theme Palace
 * @subpackage Travelism Pro
 * @since Travelism Pro 1.0.0
 */

// Add Happy Clients section
$wp_customize->add_section( 'travelism_happy_clients_section', array(
	'title'             => esc_html__( 'Happy Clients Section','travelism-pro' ),
	'description'       => esc_html__( 'Happy Clients Section options.', 'travelism-pro' ),
	'panel'             => 'travelism_pro_front_page_panel',
	'active_callback'   => function( $control ) {
        return ( 
        	travelism_pro_is_default_layout( $control ) 
        	|| 
        	travelism_pro_is_third_layout( $control ) 
        	|| 
        	travelism_pro_is_fourth_layout( $control )  
        );
    },
) );

// Happy Clients content enable control and setting
$wp_customize->add_setting( 'travelism_pro_theme_options[happy_clients_section_enable]', array(
	'default'			=> 	$options['happy_clients_section_enable'],
	'sanitize_callback' => 'travelism_pro_sanitize_switch_control',
) );

$wp_customize->add_control( new Travelism_Pro_Switch_Control( $wp_customize, 'travelism_pro_theme_options[happy_clients_section_enable]', array(
	'label'             => esc_html__( 'Happy Clients Section Enable', 'travelism-pro' ),
	'section'           => 'travelism_happy_clients_section',
	'on_off_label' 		=> travelism_pro_switch_options(),
) ) );

if ( isset( $wp_customize->selective_refresh ) ) {
    $wp_customize->selective_refresh->add_partial( 'travelism_pro_theme_options[happy_clients_section_enable]', array(
		'selector'            => '#travelism_happy_clients_section .tooltiptext',
		'settings'            => 'travelism_pro_theme_options[happy_clients_section_enable]',
    ) );
}

// Happy Clients auto play enable control and setting
$wp_customize->add_setting( 'travelism_pro_theme_options[happy_clients_auto_play]', array(
	'default'			=> 	$options['happy_clients_auto_play'],
	'sanitize_callback' => 'travelism_pro_sanitize_switch_control',
) );

$wp_customize->add_control( new Travelism_Pro_Switch_Control( $wp_customize, 'travelism_pro_theme_options[happy_clients_auto_play]', array(
	'label'             => esc_html__( 'Auto Play Enable', 'travelism-pro' ),
	'section'           => 'travelism_happy_clients_section',
	'on_off_label' 		=> travelism_pro_switch_options(),
) ) );

$wp_customize->add_setting( 'travelism_pro_theme_options[happy_clients_section_sub_title]', array(
	'default'          	=> $options['happy_clients_section_sub_title'],
	'sanitize_callback' => 'sanitize_text_field',
	'transport'			=> 'postMessage',
) );

$wp_customize->add_control( 'travelism_pro_theme_options[happy_clients_section_sub_title]', array(
	'label'             => esc_html__( 'Section Sub Title', 'travelism-pro' ),
	'section'           => 'travelism_happy_clients_section',
	'type'				=> 'text',
	'active_callback' 	=> 'travelism_pro_is_happy_clients_section_enable',
) );

if ( isset( $wp_customize->selective_refresh ) ) {
    $wp_customize->selective_refresh->add_partial( 'travelism_pro_theme_options[happy_clients_section_sub_title]', array(
		'selector'            => '#travelism_happy_clients_section .section-subtitle',
		'settings'            => 'travelism_pro_theme_options[happy_clients_section_sub_title]',
		'container_inclusive' => false,
		'fallback_refresh'    => true,
		'render_callback'     => 'travelism_happy_clients_section_sub_title_partial',
    ) );
}

$wp_customize->add_setting( 'travelism_pro_theme_options[happy_clients_section_title]', array(
	'default'          	=> $options['happy_clients_section_title'],
	'sanitize_callback' => 'sanitize_text_field',
	'transport'			=> 'postMessage',
) );

$wp_customize->add_control( 'travelism_pro_theme_options[happy_clients_section_title]', array(
	'label'             => esc_html__( 'Section Title', 'travelism-pro' ),
	'section'           => 'travelism_happy_clients_section',
	'type'				=> 'text',
	'active_callback' 	=> 'travelism_pro_is_happy_clients_section_enable',
) );

if ( isset( $wp_customize->selective_refresh ) ) {
    $wp_customize->selective_refresh->add_partial( 'travelism_pro_theme_options[happy_clients_section_title]', array(
		'selector'            => '#travelism_happy_clients_section .section-title',
		'settings'            => 'travelism_pro_theme_options[happy_clients_section_title]',
		'container_inclusive' => false,
		'fallback_refresh'    => true,
		'render_callback'     => 'travelism_happy_clients_section_title_partial',
    ) );
}

// Event social icons number control and setting
$wp_customize->add_setting( 'travelism_pro_theme_options[happy_clients_count]', array(
	'default'          	=> $options['happy_clients_count'],
	'sanitize_callback' => 'travelism_pro_sanitize_number_range',
	'validate_callback' => 'travelism_pro_validate_happy_clients_count',
) );

$wp_customize->add_control( 'travelism_pro_theme_options[happy_clients_count]', array(
	'label'             => esc_html__( 'Number of Happy Clients', 'travelism-pro' ),
	'description'       => esc_html__( 'Note: Min 3 & Max 50. Please input the valid number and save. Then refresh the page to see the change.', 'travelism-pro' ),
	'section'           => 'travelism_happy_clients_section',
	'active_callback'   => 'travelism_pro_is_happy_clients_section_enable',
	'type'				=> 'number',
	'input_attrs'		=> array(
		'min'	=> 3,
		'max'	=> 50,
		'style' => 'width: 100px;'
		),
) );

// long Excerpt length setting and control.
$wp_customize->add_setting( 'travelism_pro_theme_options[happy_clients_excerpt_length]', array(
	'sanitize_callback' => 'travelism_pro_sanitize_number_range',
	'validate_callback' => 'travelism_pro_validate_long_excerpt',
	'default'			=> $options['happy_clients_excerpt_length'],
) );

$wp_customize->add_control( 'travelism_pro_theme_options[happy_clients_excerpt_length]', array(
	'label'       		=> esc_html__( 'Happy Clients Excerpt Length', 'travelism-pro' ),
	'description' 		=> esc_html__( 'Total description words to be displayed in happy_clients posts.', 'travelism-pro' ),
	'section'     		=> 'travelism_happy_clients_section',
	'active_callback' 	=> 'travelism_pro_is_happy_clients_section_enable',
	'type'        		=> 'number',
	'input_attrs' 		=> array(
		'style'       => 'width: 80px;',
		'max'         => 100,
		'min'         => 1,
	),
) );

// Happy Clients content type control and setting
$wp_customize->add_setting( 'travelism_pro_theme_options[happy_clients_content_type]', array(
	'default'          	=> $options['happy_clients_content_type'],
	'sanitize_callback' => 'travelism_pro_sanitize_select',
) );

$wp_customize->add_control( 'travelism_pro_theme_options[happy_clients_content_type]', array(
	'label'             => esc_html__( 'Content Type', 'travelism-pro' ),
	'section'           => 'travelism_happy_clients_section',
	'type'				=> 'select',
	'active_callback' 	=> 'travelism_pro_is_happy_clients_section_enable',
	'choices'			=> array( 
		'page' 		=> esc_html__( 'Page', 'travelism-pro' ),
		'post' 		=> esc_html__( 'Post', 'travelism-pro' ),
		'category' 	=> esc_html__( 'Category', 'travelism-pro' ),
	),
) );

// Add dropdown category setting and control.
$wp_customize->add_setting(  'travelism_pro_theme_options[happy_clients_content_category]', array(
	'sanitize_callback' => 'travelism_pro_sanitize_single_category',
) ) ;

$wp_customize->add_control( new Travelism_Pro_Dropdown_Taxonomies_Control( $wp_customize,'travelism_pro_theme_options[happy_clients_content_category]', array(
	'label'             => esc_html__( 'Select Category', 'travelism-pro' ),
	'description'      	=> esc_html__( 'Note: Latest selected no of posts will be shown from selected category', 'travelism-pro' ),
	'section'           => 'travelism_happy_clients_section',
	'type'              => 'dropdown-taxonomies',
	'active_callback'	=> 'travelism_pro_is_happy_clients_section_content_category_enable'
) ) );

for ( $i = 1; $i <= $options['happy_clients_count']; $i++ ) :
	// happy_clients pages drop down chooser control and setting
	$wp_customize->add_setting( 'travelism_pro_theme_options[happy_clients_content_page_' . $i . ']', array(
		'sanitize_callback' => 'travelism_pro_sanitize_page',
	) );

	$wp_customize->add_control( new Travelism_Pro_Dropdown_Chooser( $wp_customize, 'travelism_pro_theme_options[happy_clients_content_page_' . $i . ']', array(
		'label'             => sprintf( esc_html__( 'Select Page %d', 'travelism-pro' ), $i ),
		'section'           => 'travelism_happy_clients_section',
		'choices'			=> travelism_pro_page_choices(),
		'active_callback'	=> 'travelism_pro_is_happy_clients_section_content_page_enable',
	) ) );

	// happy_clients posts drop down chooser control and setting
	$wp_customize->add_setting( 'travelism_pro_theme_options[happy_clients_content_post_' . $i . ']', array(
		'sanitize_callback' => 'travelism_pro_sanitize_page',
	) );

	$wp_customize->add_control( new Travelism_Pro_Dropdown_Chooser( $wp_customize, 'travelism_pro_theme_options[happy_clients_content_post_' . $i . ']', array(
		'label'             => sprintf( esc_html__( 'Select Post %d', 'travelism-pro' ), $i ),
		'section'           => 'travelism_happy_clients_section',
		'choices'			=> travelism_pro_post_choices(),
		'active_callback'	=> 'travelism_pro_is_happy_clients_section_content_post_enable',
	) ) );

	$wp_customize->add_setting( 'travelism_pro_theme_options[happy_clients_client_position_' . $i . ']', array(
		'sanitize_callback' => 'sanitize_text_field',
	) );

	$wp_customize->add_control( 'travelism_pro_theme_options[happy_clients_client_position_' . $i . ']', array(
		'label'           	=> sprintf( esc_html__( 'Client Position %d', 'travelism-pro' ), $i ),
		'section'        	=> 'travelism_happy_clients_section',
		'active_callback' 	=> 'travelism_pro_is_happy_clients_section_enable',
		'type'				=> 'text',
	) );

	// happy_clients hr setting and control
	$wp_customize->add_setting( 'travelism_pro_theme_options[happy_clients_hr_'. $i .']', array(
		'sanitize_callback' => 'sanitize_text_field'
	) );

	$wp_customize->add_control( new Travelism_Pro_Customize_Horizontal_Line( $wp_customize, 'travelism_pro_theme_options[happy_clients_hr_'. $i .']',
		array(
			'section'         => 'travelism_happy_clients_section',
			'active_callback' => 'travelism_pro_is_happy_clients_section_enable',
			'type'			  => 'hr'
	) ) );
endfor;