<?php
/**
 * Hero Banner Section options
 *
 * @package Theme Palace
 * @subpackage Travelism Pro
 * @since Travelism Pro 1.0.0
 */

// Add Hero Banner section
$wp_customize->add_section( 'travelism_hero_banner_section', array(
	'title'             => esc_html__( 'Hero Banner Section','travelism-pro' ),
	'description'       => esc_html__( 'Hero Banner Section options.', 'travelism-pro' ),
	'panel'             => 'travelism_pro_front_page_panel',
	'active_callback'   => function( $control ) {
        return ( 
        	travelism_pro_is_default_layout( $control )  
        );
    },
) );

// Hero Banner content enable control and setting
$wp_customize->add_setting( 'travelism_pro_theme_options[hero_banner_section_enable]', array(
	'default'			=> 	$options['hero_banner_section_enable'],
	'sanitize_callback' => 'travelism_pro_sanitize_switch_control',
) );

$wp_customize->add_control( new Travelism_Pro_Switch_Control( $wp_customize, 'travelism_pro_theme_options[hero_banner_section_enable]', array(
	'label'             => esc_html__( 'Hero Banner Section Enable', 'travelism-pro' ),
	'section'           => 'travelism_hero_banner_section',
	'on_off_label' 		=> travelism_pro_switch_options(),
) ) );

if ( isset( $wp_customize->selective_refresh ) ) {
    $wp_customize->selective_refresh->add_partial( 'travelism_pro_theme_options[hero_banner_section_enable]', array(
		'selector'            => '#travelism_hero_banner_section .tooltiptext',
		'settings'            => 'travelism_pro_theme_options[hero_banner_section_enable]',
    ) );
}

$wp_customize->add_setting( 'travelism_pro_theme_options[hero_banner_bg_image]', array(
	'sanitize_callback' => 'travelism_pro_sanitize_image'
) );

$wp_customize->add_control( new WP_Customize_Image_Control( $wp_customize, 'travelism_pro_theme_options[hero_banner_bg_image]',
		array(
		'label'       		=> esc_html__( 'Background Image', 'travelism-pro' ),
		'section'     		=> 'travelism_hero_banner_section',
		'active_callback'	=> 'travelism_pro_is_hero_banner_section_enable',
) ) );

// long Excerpt length setting and control.
$wp_customize->add_setting( 'travelism_pro_theme_options[hero_banner_excerpt_length]', array(
	'sanitize_callback' => 'travelism_pro_sanitize_number_range',
	'validate_callback' => 'travelism_pro_validate_long_excerpt',
	'default'			=> $options['hero_banner_excerpt_length'],
) );

$wp_customize->add_control( 'travelism_pro_theme_options[hero_banner_excerpt_length]', array(
	'label'       		=> esc_html__( 'Hero Banner Excerpt Length', 'travelism-pro' ),
	'description' 		=> esc_html__( 'Total description words to be displayed in hero_banner posts.', 'travelism-pro' ),
	'section'     		=> 'travelism_hero_banner_section',
	'active_callback' 	=> 'travelism_pro_is_hero_banner_section_enable',
	'type'        		=> 'number',
	'input_attrs' 		=> array(
		'style'       => 'width: 80px;',
		'max'         => 100,
		'min'         => 1,
	),
) );

// Hero Banner content type control and setting
$wp_customize->add_setting( 'travelism_pro_theme_options[hero_banner_content_type]', array(
	'default'          	=> $options['hero_banner_content_type'],
	'sanitize_callback' => 'travelism_pro_sanitize_select',
) );

$wp_customize->add_control( 'travelism_pro_theme_options[hero_banner_content_type]', array(
	'label'             => esc_html__( 'Content Type', 'travelism-pro' ),
	'section'           => 'travelism_hero_banner_section',
	'type'				=> 'select',
	'active_callback' 	=> 'travelism_pro_is_hero_banner_section_enable',
	'choices'			=> array( 
		'page' 		=> esc_html__( 'Page', 'travelism-pro' ),
		'post' 		=> esc_html__( 'Post', 'travelism-pro' ),
		'custom' 	=> esc_html__( 'Custom', 'travelism-pro' ),
	),
) );

// hero_banner sub title setting and control
$wp_customize->add_setting( 'travelism_pro_theme_options[hero_banner_sub_title]', array(
	'sanitize_callback' => 'sanitize_text_field',
	'default'			=> $options['hero_banner_sub_title'],
	'transport'			=> 'postMessage',
) );

$wp_customize->add_control( 'travelism_pro_theme_options[hero_banner_sub_title]', array(
	'label'           	=> esc_html__( 'Sub Title', 'travelism-pro' ),
	'section'        	=> 'travelism_hero_banner_section',
	'active_callback' 	=> 'travelism_pro_is_hero_banner_section_enable',
	'type'				=> 'text',
) );

// Abort if selective refresh is not available.
if ( isset( $wp_customize->selective_refresh ) ) {
    $wp_customize->selective_refresh->add_partial( 'travelism_pro_theme_options[hero_banner_sub_title]', array(
		'selector'            => '#travelism_hero_banner_section .section-subtitle',
		'settings'            => 'travelism_pro_theme_options[hero_banner_sub_title]',
		'container_inclusive' => false,
		'fallback_refresh'    => true,
		'render_callback'     => 'travelism_pro_hero_banner_sub_title_partial',
    ) );
}

// hero_banner pages drop down chooser control and setting
$wp_customize->add_setting( 'travelism_pro_theme_options[hero_banner_content_page]', array(
	'sanitize_callback' => 'travelism_pro_sanitize_page',
) );

$wp_customize->add_control( new Travelism_Pro_Dropdown_Chooser( $wp_customize, 'travelism_pro_theme_options[hero_banner_content_page]', array(
	'label'             => esc_html__( 'Select Page', 'travelism-pro' ),
	'section'           => 'travelism_hero_banner_section',
	'choices'			=> travelism_pro_page_choices(),
	'active_callback'	=> 'travelism_pro_is_hero_banner_section_content_page_enable',
) ) );

// hero_banner posts drop down chooser control and setting
$wp_customize->add_setting( 'travelism_pro_theme_options[hero_banner_content_post]', array(
	'sanitize_callback' => 'travelism_pro_sanitize_page',
) );

$wp_customize->add_control( new Travelism_Pro_Dropdown_Chooser( $wp_customize, 'travelism_pro_theme_options[hero_banner_content_post]', array(
	'label'             => esc_html__( 'Select Post', 'travelism-pro' ),
	'section'           => 'travelism_hero_banner_section',
	'choices'			=> travelism_pro_post_choices(),
	'active_callback'	=> 'travelism_pro_is_hero_banner_section_content_post_enable',
) ) );

// hero_banner title setting and control
$wp_customize->add_setting( 'travelism_pro_theme_options[hero_banner_title]', array(
	'sanitize_callback' => 'sanitize_text_field',
	'default'			=> $options['hero_banner_title'],
) );

$wp_customize->add_control( 'travelism_pro_theme_options[hero_banner_title]', array(
	'label'           	=> esc_html__( 'Title', 'travelism-pro' ),
	'section'        	=> 'travelism_hero_banner_section',
	'active_callback' 	=> 'travelism_pro_is_hero_banner_section_content_custom_enable',
	'type'				=> 'text',
) );

// hero_banner description setting and control
$wp_customize->add_setting( 'travelism_pro_theme_options[hero_banner_description]', array(
	'sanitize_callback' => 'wp_kses_post',
	'default'			=> $options['hero_banner_description'],
) );

$wp_customize->add_control( 'travelism_pro_theme_options[hero_banner_description]', array(
	'label'           	=> esc_html__( 'Description', 'travelism-pro' ),
	'section'        	=> 'travelism_hero_banner_section',
	'active_callback' 	=> 'travelism_pro_is_hero_banner_section_content_custom_enable',
	'type'				=> 'textarea',
) );

// hero_banner btn title setting and control
$wp_customize->add_setting( 'travelism_pro_theme_options[hero_banner_btn_title]', array(
	'sanitize_callback' => 'sanitize_text_field',
	'default'			=> $options['hero_banner_btn_title'],
	'transport'			=> 'postMessage',
) );

$wp_customize->add_control( 'travelism_pro_theme_options[hero_banner_btn_title]', array(
	'label'           	=> esc_html__( 'Button Label', 'travelism-pro' ),
	'section'        	=> 'travelism_hero_banner_section',
	'active_callback' 	=> 'travelism_pro_is_hero_banner_section_enable',
	'type'				=> 'text',
) );

// Abort if selective refresh is not available.
if ( isset( $wp_customize->selective_refresh ) ) {
    $wp_customize->selective_refresh->add_partial( 'travelism_pro_theme_options[hero_banner_btn_title]', array(
		'selector'            => '#travelism_hero_banner_section .btn',
		'settings'            => 'travelism_pro_theme_options[hero_banner_btn_title]',
		'container_inclusive' => false,
		'fallback_refresh'    => true,
		'render_callback'     => 'travelism_pro_hero_banner_btn_title_partial',
    ) );
}

// hero_banner btn link setting and control
$wp_customize->add_setting( 'travelism_pro_theme_options[hero_banner_btn_link]', array(
	'sanitize_callback' => 'esc_url_raw',
) );

$wp_customize->add_control( 'travelism_pro_theme_options[hero_banner_btn_link]', array(
	'label'           	=> esc_html__( 'Button Link', 'travelism-pro' ),
	'section'        	=> 'travelism_hero_banner_section',
	'active_callback' 	=> 'travelism_pro_is_hero_banner_section_content_custom_enable',
	'type'				=> 'url',
) );

// hero_banner image setting and control.
$wp_customize->add_setting( 'travelism_pro_theme_options[hero_banner_image]', array(
	'sanitize_callback' => 'travelism_pro_sanitize_image'
) );

$wp_customize->add_control( new WP_Customize_Image_Control( $wp_customize, 'travelism_pro_theme_options[hero_banner_image]',
		array(
		'label'       		=> esc_html__( 'Hero Banner Image', 'travelism-pro' ),
		'description' 		=> sprintf( esc_html__( 'Recommended size: %1$dpx x %2$dpx ', 'travelism-pro' ), 705, 900 ),
		'section'     		=> 'travelism_hero_banner_section',
		'active_callback'	=> 'travelism_pro_is_hero_banner_section_content_custom_enable',
) ) );

// hero_banner image setting and control.
$wp_customize->add_setting( 'travelism_pro_theme_options[hero_banner_content_bg_image]', array(
	'sanitize_callback' => 'travelism_pro_sanitize_image',
) );

$wp_customize->add_control( new WP_Customize_Image_Control( $wp_customize, 'travelism_pro_theme_options[hero_banner_content_bg_image]',
		array(
		'label'       		=> esc_html__( 'Content BG Image', 'travelism-pro' ),
		'description' 		=> sprintf( esc_html__( 'Recommended size: %1$dpx x %2$dpx ', 'travelism-pro' ), 705, 900 ),
		'section'     		=> 'travelism_hero_banner_section',
		'active_callback'	=> 'travelism_pro_is_hero_banner_section_enable',
) ) );