<?php
/**
 * Logos Section options
 *
 * @package Theme Palace
 * @sub_package Travelism Pro
 * @since Travelism Pro 1.0.0
 */

// Add Logos section
$wp_customize->add_section( 'travelism_logos_section', array(
	'title'             => esc_html__( 'Clients / Partners Logos Section','travelism-pro' ),
	'description'       => esc_html__( 'Clients / Partners Logos Section options.', 'travelism-pro' ),
	'panel'             => 'travelism_pro_front_page_panel',
	'active_callback'   => function( $control ) {
        return ( 
        	travelism_pro_is_default_layout( $control )  
        	||
        	travelism_pro_is_third_layout( $control )   
        	||
        	travelism_pro_is_fourth_layout( $control )  
        );
    },
) );

// Logos content enable control and setting
$wp_customize->add_setting( 'travelism_pro_theme_options[logos_section_enable]', array(
	'default'			=> 	$options['logos_section_enable'],
	'sanitize_callback' => 'travelism_pro_sanitize_switch_control',
) );

$wp_customize->add_control( new Travelism_Pro_Switch_Control( $wp_customize, 'travelism_pro_theme_options[logos_section_enable]', array(
	'label'             => esc_html__( 'Logos Section Enable', 'travelism-pro' ),
	'section'           => 'travelism_logos_section',
	'on_off_label' 		=> travelism_pro_switch_options(),
) ) );

if ( isset( $wp_customize->selective_refresh ) ) {
    $wp_customize->selective_refresh->add_partial( 'travelism_pro_theme_options[logos_section_enable]', array(
		'selector'            => '#travelism_logos_section .tooltiptext',
		'settings'            => 'travelism_pro_theme_options[logos_section_enable]',
    ) );
}

// Event social icons number control and setting
$wp_customize->add_setting( 'travelism_pro_theme_options[logos_count]', array(
	'default'          	=> $options['logos_count'],
	'sanitize_callback' => 'travelism_pro_sanitize_number_range',
	'validate_callback' => 'travelism_pro_validate_logos_count',
) );

$wp_customize->add_control( 'travelism_pro_theme_options[logos_count]', array(
	'label'             => esc_html__( 'Number of Posts', 'travelism-pro' ),
	'description'       => esc_html__( 'Note: Min 1 & Max 30. Please input the valid number and save. Then refresh the page to see the change.', 'travelism-pro' ),
	'section'           => 'travelism_logos_section',
	'active_callback'   => 'travelism_pro_is_logos_section_enable',
	'type'				=> 'number',
	'input_attrs'		=> array(
		'min'	=> 1,
		'max'	=> 30,
		'style' => 'width: 100px;'
		),
) );

// Logos content type control and setting
$wp_customize->add_setting( 'travelism_pro_theme_options[logos_col_layout]', array(
	'default'          	=> $options['logos_col_layout'],
	'sanitize_callback' => 'travelism_pro_sanitize_select',
) );

$wp_customize->add_control( 'travelism_pro_theme_options[logos_col_layout]', array(
	'label'             => esc_html__( 'Column Layout', 'travelism-pro' ),
	'section'           => 'travelism_logos_section',
	'type'				=> 'select',
	'active_callback' 	=> 'travelism_pro_is_logos_section_enable',
	'choices'			=> array(
		'col-3'     => esc_html__( 'Three Coloumn', 'travelism-pro' ),
		'col-4'     => esc_html__( 'Four Coloumn', 'travelism-pro' ),
		'col-5'  	=> esc_html__( 'Five Coloumn', 'travelism-pro' ),
		'col-6'  	=> esc_html__( 'Six Coloumn', 'travelism-pro' ),
		),
) );

for ( $i = 1; $i <= $options['logos_count']; $i++ ) :

	// Logos image setting and control.
	$wp_customize->add_setting( 'travelism_pro_theme_options[logos_image_' . $i . ']', array(
		'sanitize_callback' => 'travelism_pro_sanitize_image',
	) );

	$wp_customize->add_control( new WP_Customize_Image_Control( $wp_customize, 'travelism_pro_theme_options[logos_image_' . $i . ']',
			array(
			'label'       		=> sprintf( esc_html__( 'Image %d', 'travelism-pro' ), $i),
			'section'     		=> 'travelism_logos_section',
			'active_callback'	=> 'travelism_pro_is_logos_section_enable',
	) ) );

	// Logos url setting and control
	$wp_customize->add_setting( 'travelism_pro_theme_options[logos_url_' . $i . ']', array(
		'sanitize_callback' => 'esc_url_raw',
	) );

	$wp_customize->add_control( 'travelism_pro_theme_options[logos_url_' . $i . ']', array(
		'label'           	=> sprintf( esc_html__( 'Logos Url %d', 'travelism-pro' ), $i),
		'section'        	=> 'travelism_logos_section',
		'active_callback' 	=> 'travelism_pro_is_logos_section_enable',
		'type'				=> 'url',
	) );

endfor;