<?php
/**
 * Northface Jacket Section options
 *
 * @package Theme Palace
 * @subpackage Travelism Pro
 * @since Travelism Pro 1.0.0
 */
if ( !class_exists('WooCommerce') ) {
    return;
}

// Add northface_jacket section
$wp_customize->add_section( 'travelism_northface_jacket_section', array(
    'title'             => esc_html__( 'Northface Jacket Section','travelism-pro' ),
    'description'       => esc_html__( 'Note: To activate this section you need to install WooCommerce Plugin.', 'travelism-pro' ),
    'panel'             => 'travelism_pro_front_page_panel',
    'active_callback'   => function( $control ) {
        return ( 
            travelism_pro_is_default_layout( $control )  
        );
    },
) );

// northface_jacket content enable control and setting
$wp_customize->add_setting( 'travelism_pro_theme_options[northface_jacket_section_enable]', array(
    'default'           =>  $options['northface_jacket_section_enable'],
    'sanitize_callback' => 'travelism_pro_sanitize_switch_control',
) );

$wp_customize->add_control( new Travelism_Pro_Switch_Control( $wp_customize, 'travelism_pro_theme_options[northface_jacket_section_enable]', array(
    'label'             => esc_html__( 'Popular product Section Enable', 'travelism-pro' ),
    'section'           => 'travelism_northface_jacket_section',
    'on_off_label'      => travelism_pro_switch_options(),
) ) );

if ( isset( $wp_customize->selective_refresh ) ) {
    $wp_customize->selective_refresh->add_partial( 'travelism_pro_theme_options[northface_jacket_section_enable]', array(
        'selector'            => '#travelism_northface_jacket_section .tooltiptext',
        'settings'            => 'travelism_pro_theme_options[northface_jacket_section_enable]',
    ) );
}

// northface_jacket title setting and control
$wp_customize->add_setting( 'travelism_pro_theme_options[northface_jacket_title]', array(
    'sanitize_callback' => 'sanitize_text_field',
    'default'           => $options['northface_jacket_title'],
    'transport'         => 'postMessage',
) );

$wp_customize->add_control( 'travelism_pro_theme_options[northface_jacket_title]', array(
    'label'             => esc_html__( 'Title', 'travelism-pro' ),
    'section'           => 'travelism_northface_jacket_section',
    'active_callback'   => 'travelism_pro_is_northface_jacket_section_enable',
    'type'              => 'text',
) );

// Abort if selective refresh is not available.
if ( isset( $wp_customize->selective_refresh ) ) {
    $wp_customize->selective_refresh->add_partial( 'travelism_pro_theme_options[northface_jacket_title]', array(
        'selector'            => '#travelism_northface_jacket_section .section-title',
        'settings'            => 'travelism_pro_theme_options[northface_jacket_title]',
        'container_inclusive' => false,
        'fallback_refresh'    => true,
        'render_callback'     => 'travelism_pro_northface_jacket_title_partial',
    ) );
}

// northface_jacket title setting and control
$wp_customize->add_setting( 'travelism_pro_theme_options[northface_jacket_sub_title]', array(
    'sanitize_callback' => 'sanitize_text_field',
    'default'           => $options['northface_jacket_sub_title'],
    'transport'         => 'postMessage',
) );

$wp_customize->add_control( 'travelism_pro_theme_options[northface_jacket_sub_title]', array(
    'label'             => esc_html__( 'Sub Title', 'travelism-pro' ),
    'section'           => 'travelism_northface_jacket_section',
    'active_callback'   => 'travelism_pro_is_northface_jacket_section_enable',
    'type'              => 'text',
) );

// Abort if selective refresh is not available.
if ( isset( $wp_customize->selective_refresh ) ) {
    $wp_customize->selective_refresh->add_partial( 'travelism_pro_theme_options[northface_jacket_sub_title]', array(
        'selector'            => '#travelism_northface_jacket_section .section-subtitle',
        'settings'            => 'travelism_pro_theme_options[northface_jacket_sub_title]',
        'container_inclusive' => false,
        'fallback_refresh'    => true,
        'render_callback'     => 'travelism_pro_northface_jacket_sub_title_partial',
    ) );
}

// hero_banner image setting and control.
$wp_customize->add_setting( 'travelism_pro_theme_options[northface_jacket_bg_image]', array(
    'sanitize_callback' => 'travelism_pro_sanitize_image',
) );

$wp_customize->add_control( new WP_Customize_Image_Control( $wp_customize, 'travelism_pro_theme_options[northface_jacket_bg_image]',
        array(
        'label'             => esc_html__( 'Background Image', 'travelism-pro' ),
        'section'           => 'travelism_northface_jacket_section',
        'active_callback'   => 'travelism_pro_is_northface_jacket_section_enable',
) ) );

$wp_customize->add_setting( 'travelism_pro_theme_options[northface_jacket_count]', array(
    'default'           => $options['northface_jacket_count'],
    'sanitize_callback' => 'travelism_pro_sanitize_number_range',
    'validate_callback' => 'travelism_pro_validate_northface_jacket_count',
) );

$wp_customize->add_control( 'travelism_pro_theme_options[northface_jacket_count]', array(
    'label'             => esc_html__( 'Number of Product', 'travelism-pro' ),
    'description'       => esc_html__( 'Note: Min 1 & Max 50. Please input the valid number and save. Then refresh the page to see the change.', 'travelism-pro' ),
    'section'           => 'travelism_northface_jacket_section',
    'active_callback'   => 'travelism_pro_is_northface_jacket_section_enable',
    'type'              => 'number',
    'input_attrs'       => array(
        'min'   => 1,
        'max'   => 50,
        'style' => 'width: 100px;'
        ),
) );

// long Excerpt length setting and control.
$wp_customize->add_setting( 'travelism_pro_theme_options[northface_jacket_excerpt_length]', array(
	'sanitize_callback' => 'travelism_pro_sanitize_number_range',
	'validate_callback' => 'travelism_pro_validate_long_excerpt',
	'default'			=> $options['northface_jacket_excerpt_length'],
) );

$wp_customize->add_control( 'travelism_pro_theme_options[northface_jacket_excerpt_length]', array(
	'label'       		=> esc_html__( 'Post Excerpt Length', 'travelism-pro' ),
	'description' 		=> esc_html__( 'Total description words to be displayed in northface_jacket posts.', 'travelism-pro' ),
	'section'     		=> 'travelism_northface_jacket_section',
	'active_callback' 	=> 'travelism_pro_is_northface_jacket_section_enable',
	'type'        		=> 'number',
	'input_attrs' 		=> array(
		'style'       => 'width: 80px;',
		'max'         => 100,
		'min'         => 1,
	),
) );

$wp_customize->add_setting( 'travelism_pro_theme_options[northface_jacket_content_type]', array(
    'default'           => $options['northface_jacket_content_type'],
    'sanitize_callback' => 'travelism_pro_sanitize_select',
) );

$wp_customize->add_control( 'travelism_pro_theme_options[northface_jacket_content_type]', array(
    'label'             => esc_html__( 'Content Type', 'travelism-pro' ),
    'section'           => 'travelism_northface_jacket_section',
    'type'              => 'select',
    'active_callback'   => 'travelism_pro_is_northface_jacket_section_enable',
    'choices'           => array(
        'product'           => esc_html__( 'Product', 'travelism-pro' ),
        'product-category'  => esc_html__( 'Product Category', 'travelism-pro' ),
        ),
) );

for( $i = 1 ; $i <= $options['northface_jacket_count'] ; $i++ ){

    $wp_customize->add_setting( 'travelism_pro_theme_options[northface_jacket_content_page_' . $i . ']', array(
        'sanitize_callback' => 'travelism_pro_sanitize_page',
    ) );

    $wp_customize->add_control( new Travelism_Pro_Dropdown_Chooser( $wp_customize, 'travelism_pro_theme_options[northface_jacket_content_page_' . $i . ']', array(
        'label'             => sprintf( esc_html__( 'Select Product %d', 'travelism-pro' ), $i ),
        'section'           => 'travelism_northface_jacket_section',
        'choices'           => travelism_pro_product_choices(),
        'active_callback'   => 'travelism_pro_is_northface_jacket_section_content_product_enable',
    ) ) );
}

$wp_customize->add_setting(  'travelism_pro_theme_options[northface_jacket_category]', array(
        'sanitize_callback' => 'absint',
    ) ) ;

$wp_customize->add_control( new Travelism_Pro_Dropdown_Taxonomies_Control( $wp_customize,'travelism_pro_theme_options[northface_jacket_category]', array(
    'label'             => esc_html__( 'Select Product Categories', 'travelism-pro' ),
    'description'       => esc_html__( 'Note: Press CTRL and select multiple category. Latest four posts will be shown from each selected category', 'travelism-pro' ),
    'section'           => 'travelism_northface_jacket_section',
    'taxonomy'          => 'product_cat',
    'type'              => 'dropdown-taxonomies',
    'active_callback'   => 'travelism_pro_is_northface_jacket_section_content_product_category_enable',
) ) );