<?php
/**
 * Recent Products Section options
 *
 * @package Theme Palace
 * @subpackage Travelism Pro
 * @since Travelism Pro 1.0.0
 */
if ( !class_exists('WooCommerce') ) {
    return;
}

// Add recent_products section
$wp_customize->add_section( 'travelism_shop_recent_products_section', array(
    'title'             => esc_html__( 'Recent Product','travelism-pro' ),
    'description'       => esc_html__( 'Note: To activate this section you need to install WooCommerce Plugin.', 'travelism-pro' ),
    'panel'             => 'travelism_pro_front_page_panel',
    'active_callback'   => function( $control ) {
        return ( 
            travelism_pro_is_fourth_layout( $control )
        );
    },
) );

// recent_products content enable control and setting
$wp_customize->add_setting( 'travelism_pro_theme_options[shop_recent_products_section_enable]', array(
    'default'           =>  $options['shop_recent_products_section_enable'],
    'sanitize_callback' => 'travelism_pro_sanitize_switch_control',
) );

$wp_customize->add_control( new Travelism_Pro_Switch_Control( $wp_customize, 'travelism_pro_theme_options[shop_recent_products_section_enable]', array(
    'label'             => esc_html__( 'Recent product Section Enable', 'travelism-pro' ),
    'section'           => 'travelism_shop_recent_products_section',
    'on_off_label'      => travelism_pro_switch_options(),
) ) );

if ( isset( $wp_customize->selective_refresh ) ) {
    $wp_customize->selective_refresh->add_partial( 'travelism_pro_theme_options[shop_recent_products_section_enable]', array(
        'selector'            => '#travelism_shop_recent_products_section .tooltiptext',
        'settings'            => 'travelism_pro_theme_options[shop_recent_products_section_enable]',
    ) );
}

// recent_products title setting and control
$wp_customize->add_setting( 'travelism_pro_theme_options[shop_recent_products_sub_title]', array(
    'sanitize_callback' => 'sanitize_text_field',
    'default'           => $options['shop_recent_products_sub_title'],       
    'transport'         => 'postMessage',
) );

$wp_customize->add_control( 'travelism_pro_theme_options[shop_recent_products_sub_title]', array(
    'label'             => esc_html__( 'Description', 'travelism-pro' ),
    'section'           => 'travelism_shop_recent_products_section',
    'active_callback'   => 'travelism_pro_is_shop_recent_products_section_enable',
    'type'              => 'text',
) );

// Abort if selective refresh is not available.
if ( isset( $wp_customize->selective_refresh ) ) {
    $wp_customize->selective_refresh->add_partial( 'travelism_pro_theme_options[shop_recent_products_sub_title]', array(
        'selector'            => '#travelism_shop_recent_products_section .section-subtitle',
        'settings'            => 'travelism_pro_theme_options[shop_recent_products_sub_title]',
        'container_inclusive' => false,
        'fallback_refresh'    => true,
        'render_callback'     => 'travelism_pro_shop_recent_products_sub_title_partial',
    ) );
}

// recent_products title setting and control
$wp_customize->add_setting( 'travelism_pro_theme_options[shop_recent_products_title]', array(
    'sanitize_callback' => 'sanitize_text_field',
    'default'           => $options['shop_recent_products_title'],
    'transport'         => 'postMessage',
) );

$wp_customize->add_control( 'travelism_pro_theme_options[shop_recent_products_title]', array(
    'label'             => esc_html__( 'Title', 'travelism-pro' ),
    'section'           => 'travelism_shop_recent_products_section',
    'active_callback'   => 'travelism_pro_is_shop_recent_products_section_enable',
    'type'              => 'text',
) );
// Abort if selective refresh is not available.
if ( isset( $wp_customize->selective_refresh ) ) {
    $wp_customize->selective_refresh->add_partial( 'travelism_pro_theme_options[shop_recent_products_title]', array(
        'selector'            => '#travelism_shop_recent_products_section .section-title',
        'settings'            => 'travelism_pro_theme_options[shop_recent_products_title]',
        'container_inclusive' => false,
        'fallback_refresh'    => true,
        'render_callback'     => 'travelism_pro_shop_recent_products_title_partial',
    ) );
}

$wp_customize->add_setting( 'travelism_pro_theme_options[shop_recent_products_count]', array(
    'default'           => $options['shop_recent_products_count'],
    'sanitize_callback' => 'travelism_pro_sanitize_number_range',
    'validate_callback' => 'travelism_pro_validate_shop_recent_products_count',
) );

$wp_customize->add_control( 'travelism_pro_theme_options[shop_recent_products_count]', array(
    'label'             => esc_html__( 'Number of Products', 'travelism-pro' ),
    'description'       => esc_html__( 'Note: Min 1 & Max 50. Please input the valid number and save. Then refresh the page to see the change.', 'travelism-pro' ),
    'section'           => 'travelism_shop_recent_products_section',
    'active_callback'   => 'travelism_pro_is_shop_recent_products_section_enable',
    'type'              => 'number',
    'input_attrs'       => array(
        'min'   => 1,
        'max'   => 50,
        'style' => 'width: 100px;'
        ),
) );

$wp_customize->add_setting( 'travelism_pro_theme_options[shop_recent_products_content_type]', array(
    'default'           => $options['shop_recent_products_content_type'],
    'sanitize_callback' => 'travelism_pro_sanitize_select',
) );

$wp_customize->add_control( 'travelism_pro_theme_options[shop_recent_products_content_type]', array(
    'label'             => esc_html__( 'Content Type', 'travelism-pro' ),
    'section'           => 'travelism_shop_recent_products_section',
    'type'              => 'select',
    'active_callback'   => 'travelism_pro_is_shop_recent_products_section_enable',
    'choices'           => array(
        'product'           => esc_html__( 'Product', 'travelism-pro' ),
        'product-category'  => esc_html__( 'Product Category', 'travelism-pro' ),
        ),
) );

for( $i = 1 ; $i <= $options['shop_recent_products_count'] ; $i++ ){

    $wp_customize->add_setting( 'travelism_pro_theme_options[shop_recent_products_content_page_' . $i . ']', array(
        'sanitize_callback' => 'travelism_pro_sanitize_page',
    ) );

    $wp_customize->add_control( new Travelism_Pro_Dropdown_Chooser( $wp_customize, 'travelism_pro_theme_options[shop_recent_products_content_page_' . $i . ']', array(
        'label'             => sprintf( esc_html__( 'Select Product %d', 'travelism-pro' ), $i ),
        'section'           => 'travelism_shop_recent_products_section',
        'choices'           => travelism_pro_product_choices(),
        'active_callback'   => 'travelism_pro_is_shop_recent_products_section_content_product_enable',
    ) ) );
}

$wp_customize->add_setting(  'travelism_pro_theme_options[shop_recent_products_category]', array(
        'sanitize_callback' => 'absint',
    ) ) ;

$wp_customize->add_control( new Travelism_Pro_Dropdown_Taxonomies_Control( $wp_customize,'travelism_pro_theme_options[shop_recent_products_category]', array(
    'label'             => esc_html__( 'Select Product Categories', 'travelism-pro' ),
    'description'       => esc_html__( 'Note: Select products category and latest products will be shown from selected category', 'travelism-pro' ),
    'section'           => 'travelism_shop_recent_products_section',
    'taxonomy'          => 'product_cat',
    'type'              => 'dropdown-taxonomies',
    'active_callback'   => 'travelism_pro_is_shop_recent_products_section_content_product_category_enable',
) ) );