<?php
/**
 * Subscribe Now Section options
 *
 * @package Theme Palace
 * @subpackage Travelism Pro
 * @since Travelism Pro 1.0.0
 */

// Add Subscribe Now section
$wp_customize->add_section( 'travelism_subscribe_now_section', array(
	'title'             => esc_html__( 'Subscribe Now Section','travelism-pro' ),
	'description'       => esc_html__( 'Note: To activate this section you need to install Jetpack Plugin and activate subscribe_now module.', 'travelism-pro' ),
	'panel'             => 'travelism_pro_front_page_panel',
	'active_callback'   => function( $control ) {
        return ( 
        	travelism_pro_is_second_layout( $control )  
        	||
        	travelism_pro_is_third_layout( $control )  
        	||
        	travelism_pro_is_fourth_layout( $control )  
        );
    },
) );

// Subscribe Now content enable control and setting
$wp_customize->add_setting( 'travelism_pro_theme_options[subscribe_now_section_enable]', array(
	'default'			=> 	$options['subscribe_now_section_enable'],
	'sanitize_callback' => 'travelism_pro_sanitize_switch_control',
) );

$wp_customize->add_control( new Travelism_Pro_Switch_Control( $wp_customize, 'travelism_pro_theme_options[subscribe_now_section_enable]', array(
	'label'             => esc_html__( 'Subscribe Now Section Enable', 'travelism-pro' ),
	'section'           => 'travelism_subscribe_now_section',
	'on_off_label' 		=> travelism_pro_switch_options(),
) ) );

if ( isset( $wp_customize->selective_refresh ) ) {
    $wp_customize->selective_refresh->add_partial( 'travelism_pro_theme_options[subscribe_now_section_enable]', array(
        'selector'            => '#travelism_subscribe_now_section .tooltiptext',
        'settings'            => 'travelism_pro_theme_options[subscribe_now_section_enable]',
    ) );
}

$wp_customize->add_setting( 'travelism_pro_theme_options[subscribe_now_bg_image]', array(
	'sanitize_callback' => 'travelism_pro_sanitize_image'
) );

$wp_customize->add_control( new WP_Customize_Image_Control( $wp_customize, 'travelism_pro_theme_options[subscribe_now_bg_image]',
		array(
		'label'       		=> esc_html__( 'Background Image', 'travelism-pro' ),
		'section'     		=> 'travelism_subscribe_now_section',
		'active_callback'	=> 'travelism_pro_is_subscribe_now_section_enable',
) ) );

// subscribe_now title setting and control
$wp_customize->add_setting( 'travelism_pro_theme_options[subscribe_now_title]', array(
	'sanitize_callback' => 'sanitize_text_field',
	'default'			=> $options['subscribe_now_title'],
	'transport'			=> 'postMessage',
) );

$wp_customize->add_control( 'travelism_pro_theme_options[subscribe_now_title]', array(
	'label'           	=> esc_html__( 'Title', 'travelism-pro' ),
	'section'        	=> 'travelism_subscribe_now_section',
	'active_callback' 	=> 'travelism_pro_is_subscribe_now_section_enable',
	'type'				=> 'text',
) );

// Abort if selective refresh is not available.
if ( isset( $wp_customize->selective_refresh ) ) {
    $wp_customize->selective_refresh->add_partial( 'travelism_pro_theme_options[subscribe_now_title]', array(
		'selector'            => '#travelism_subscribe_now_section h2.section-title',
		'settings'            => 'travelism_pro_theme_options[subscribe_now_title]',
		'container_inclusive' => false,
		'fallback_refresh'    => true,
		'render_callback'     => 'travelism_pro_subscribe_now_title_partial',
    ) );
}

// subscribe_now btn title setting and control
$wp_customize->add_setting( 'travelism_pro_theme_options[subscribe_now_btn_title]', array(
	'sanitize_callback' => 'sanitize_text_field',
	'default'			=> $options['subscribe_now_btn_title'],
) );

$wp_customize->add_control( 'travelism_pro_theme_options[subscribe_now_btn_title]', array(
	'label'           	=> esc_html__( 'Button Label', 'travelism-pro' ),
	'section'        	=> 'travelism_subscribe_now_section',
	'active_callback' 	=> 'travelism_pro_is_subscribe_now_section_enable',
	'type'				=> 'text',
) );