<?php
/**
 * Video Section options
 *
 * @package Theme Palace
 * @subpackage Travelism Pro
 * @since Travelism Pro 1.0.0
 */

// Add Video section
$wp_customize->add_section( 'travelism_video_section', array(
	'title'             => esc_html__( 'Video Section','travelism-pro' ),
	'description'       => esc_html__( 'Video Section options.', 'travelism-pro' ),
	'panel'             => 'travelism_pro_front_page_panel',
	'active_callback'   => function( $control ) {
        return ( 
        	travelism_pro_is_default_layout( $control )  
        );
    },

) );

// Video content enable control and setting
$wp_customize->add_setting( 'travelism_pro_theme_options[video_section_enable]', array(
	'default'			=> 	$options['video_section_enable'],
	'sanitize_callback' => 'travelism_pro_sanitize_switch_control',
) );

$wp_customize->add_control( new Travelism_Pro_Switch_Control( $wp_customize, 'travelism_pro_theme_options[video_section_enable]', array(
	'label'             => esc_html__( 'Video Section Enable', 'travelism-pro' ),
	'section'           => 'travelism_video_section',
	'on_off_label' 		=> travelism_pro_switch_options(),
) ) );

if ( isset( $wp_customize->selective_refresh ) ) {
    $wp_customize->selective_refresh->add_partial( 'travelism_pro_theme_options[video_section_enable]', array(
        'selector'            => '#travelism_video_section .tooltiptext',
        'settings'            => 'travelism_pro_theme_options[video_section_enable]',
    ) );
}

$wp_customize->add_setting( 'travelism_pro_theme_options[video_bg_image]', array(
	'sanitize_callback' => 'travelism_pro_sanitize_image'
) );

$wp_customize->add_control( new WP_Customize_Image_Control( $wp_customize, 'travelism_pro_theme_options[video_bg_image]',
		array(
		'label'       		=> esc_html__( 'Background Image', 'travelism-pro' ),
		'section'     		=> 'travelism_video_section',
		'active_callback'	=> 'travelism_pro_is_video_section_enable',
) ) );

$wp_customize->add_setting( 'travelism_pro_theme_options[video_url]', array(
'sanitize_callback' => 'esc_url_raw',
	) );

$wp_customize->add_control( 'travelism_pro_theme_options[video_url]', array(
	'label'           	=> esc_html__( 'Video URL', 'travelism-pro' ),
	'section'        	=> 'travelism_video_section',
	'active_callback' 	=> 'travelism_pro_is_video_section_enable',
	'type'				=> 'url',
) );

// popular destination sub title setting and control
$wp_customize->add_setting( 'travelism_pro_theme_options[video_sub_title]', array(
	'default'			=> $options['video_sub_title'],
	'sanitize_callback' => 'sanitize_text_field',
	'transport'			=> 'postMessage',
) );

$wp_customize->add_control( 'travelism_pro_theme_options[video_sub_title]', array(
	'label'           	=> esc_html__( 'Sub Title', 'travelism-pro' ),
	'section'        	=> 'travelism_video_section',
	'active_callback' 	=> 'travelism_pro_is_video_section_enable',
	'type'				=> 'text',
) );

// Abort if selective refresh is not available.
if ( isset( $wp_customize->selective_refresh ) ) {
    $wp_customize->selective_refresh->add_partial( 'travelism_pro_theme_options[video_sub_title]', array(
		'selector'            => '#travelism_video_section .section-subtitle',
		'settings'            => 'travelism_pro_theme_options[video_sub_title]',
		'container_inclusive' => false,
		'fallback_refresh'    => true,
		'render_callback'     => 'travelism_pro_video_sub_title_partial',
    ) );
}

// popular destination title setting and control
$wp_customize->add_setting( 'travelism_pro_theme_options[video_title]', array(
	'default'			=> $options['video_title'],
	'sanitize_callback' => 'sanitize_text_field',
	'transport'			=> 'postMessage',
) );

$wp_customize->add_control( 'travelism_pro_theme_options[video_title]', array(
	'label'           	=> esc_html__( 'Title', 'travelism-pro' ),
	'section'        	=> 'travelism_video_section',
	'active_callback' 	=> 'travelism_pro_is_video_section_enable',
	'type'				=> 'text',
) );

// Abort if selective refresh is not available.
if ( isset( $wp_customize->selective_refresh ) ) {
    $wp_customize->selective_refresh->add_partial( 'travelism_pro_theme_options[video_title]', array(
		'selector'            => '#travelism_video_section .section-title',
		'settings'            => 'travelism_pro_theme_options[video_title]',
		'container_inclusive' => false,
		'fallback_refresh'    => true,
		'render_callback'     => 'travelism_pro_video_title_partial',
    ) );
}

//Video post count number control and setting
$wp_customize->add_setting( 'travelism_pro_theme_options[video_count]', array(
	'default'          	=> $options['video_count'],
	'sanitize_callback' => 'travelism_pro_sanitize_number_range',
	'validate_callback' => 'travelism_pro_validate_video_count',
) );

$wp_customize->add_control( 'travelism_pro_theme_options[video_count]', array(
	'label'             => esc_html__( 'Number of Posts', 'travelism-pro' ),
	'description'       => esc_html__( 'Note: Min 3 & Max 50. Please input the valid number and save. Then refresh the page to see the change.', 'travelism-pro' ),
	'section'           => 'travelism_video_section',
	'active_callback'   => 'travelism_pro_is_video_section_enable',
	'type'				=> 'number',
	'input_attrs'		=> array(
		'min'	=> 3,
		'max'	=> 50,
		'style' => 'width: 100px;'
		),
) );

// long Excerpt length setting and control.
$wp_customize->add_setting( 'travelism_pro_theme_options[video_excerpt_length]', array(
	'sanitize_callback' => 'travelism_pro_sanitize_number_range',
	'validate_callback' => 'travelism_pro_validate_long_excerpt',
	'default'			=> $options['video_excerpt_length'],
) );

$wp_customize->add_control( 'travelism_pro_theme_options[video_excerpt_length]', array(
	'label'       		=> esc_html__( 'Video Post Excerpt Length', 'travelism-pro' ),
	'description' 		=> esc_html__( 'Total description words to be displayed in video posts.', 'travelism-pro' ),
	'section'     		=> 'travelism_video_section',
	'active_callback' 	=> 'travelism_pro_is_video_section_enable',
	'type'        		=> 'number',
	'input_attrs' 		=> array(
		'style'       => 'width: 80px;',
		'max'         => 100,
		'min'         => 1,
	),
) );

// Popular deatination btn label setting and control
$wp_customize->add_setting( 'travelism_pro_theme_options[video_btn_label]', array(
	'sanitize_callback' => 'sanitize_text_field',
	'default'			=> $options['video_btn_label'],
) );

$wp_customize->add_control( 'travelism_pro_theme_options[video_btn_label]', array(
	'label'           	=> esc_html__( 'Video Button Label', 'travelism-pro' ),
	'section'        	=> 'travelism_video_section',
	'active_callback' 	=> 'travelism_pro_is_video_section_enable',
	'type'				=> 'text',
) );

// Video content type control and setting
$wp_customize->add_setting( 'travelism_pro_theme_options[video_content_type]', array(
	'default'          	=> $options['video_content_type'],
	'sanitize_callback' => 'travelism_pro_sanitize_select',
) );

$wp_customize->add_control( 'travelism_pro_theme_options[video_content_type]', array(
	'label'             => esc_html__( 'Content Type', 'travelism-pro' ),
	'section'           => 'travelism_video_section',
	'type'				=> 'select',
	'active_callback' 	=> 'travelism_pro_is_video_section_enable',
	'choices'			=> travelism_pro_video_content_type(),
) );

for ( $i=1; $i <= $options['video_count']; $i++ ) { 
	// Popular deatination pages drop down chooser control and setting
	$wp_customize->add_setting( 'travelism_pro_theme_options[video_content_page_' . $i . ']', array(
		'sanitize_callback' => 'travelism_pro_sanitize_page',
	) );

	$wp_customize->add_control( new Travelism_Pro_Dropdown_Chooser( $wp_customize, 'travelism_pro_theme_options[video_content_page_' . $i . ']', array(
		'label'             => sprintf ( esc_html__( 'Select Page %d', 'travelism-pro' ), $i ),
		'section'           => 'travelism_video_section',
		'choices'			=> travelism_pro_page_choices(),
		'active_callback'	=> 'travelism_pro_is_video_section_content_page_enable',
	) ) );

	// Popular deatination posts drop down chooser control and setting
	$wp_customize->add_setting( 'travelism_pro_theme_options[video_content_post_' . $i . ']', array(
		'sanitize_callback' => 'travelism_pro_sanitize_page',
	) );

	$wp_customize->add_control( new Travelism_Pro_Dropdown_Chooser( $wp_customize, 'travelism_pro_theme_options[video_content_post_' . $i . ']', array(
		'label'             => sprintf ( esc_html__( 'Select posts %d', 'travelism-pro' ), $i ),
		'section'           => 'travelism_video_section',
		'choices'			=> travelism_pro_post_choices(),
		'active_callback'	=> 'travelism_pro_is_video_section_content_post_enable',
	) ) );

	// video trips drop down chooser control and setting
	$wp_customize->add_setting( 'travelism_pro_theme_options[video_content_trip_' . $i . ']', array(
		'sanitize_callback' => 'travelism_pro_sanitize_page',
	) );

	$wp_customize->add_control( new Travelism_Pro_Dropdown_Chooser( $wp_customize, 'travelism_pro_theme_options[video_content_trip_' . $i . ']', array(
		'label'             => sprintf ( esc_html__( 'Select Trip %d', 'travelism-pro' ), $i ),
		'section'           => 'travelism_video_section',
		'choices'			=> travelism_pro_trip_choices(),
		'active_callback'	=> 'travelism_pro_is_video_section_content_trip_enable',
	) ) );

	$wp_customize->add_setting( 'travelism_pro_theme_options[post_video_url_' . $i . ']', array(
		'sanitize_callback' => 'esc_url_raw',
		) );

	$wp_customize->add_control( 'travelism_pro_theme_options[post_video_url_' . $i . ']', array(
		'label'             => sprintf ( esc_html__( 'Video URL %d', 'travelism-pro' ), $i ),
		'section'        	=> 'travelism_video_section',
		'active_callback' 	=> 'travelism_pro_is_video_section_enable',
		'type'				=> 'url',
		) );
}

// Add dropdown category setting and control.
$wp_customize->add_setting(  'travelism_pro_theme_options[video_content_category]', array(
	'sanitize_callback' => 'travelism_pro_sanitize_single_category',
) ) ;

$wp_customize->add_control( new Travelism_Pro_Dropdown_Taxonomies_Control( $wp_customize,'travelism_pro_theme_options[video_content_category]', array(
	'label'             => esc_html__( 'Select Category', 'travelism-pro' ),
	'description'      	=> esc_html__( 'Note: Latest selected no of posts will be shown from selected category', 'travelism-pro' ),
	'section'           => 'travelism_video_section',
	'type'              => 'dropdown-taxonomies',
	'active_callback'	=> 'travelism_pro_is_video_section_content_category_enable'
) ) );

// Add dropdown category setting and control.
$wp_customize->add_setting(  'travelism_pro_theme_options[video_content_trip_types]', array(
	'sanitize_callback' => 'absint',
) ) ;

$wp_customize->add_control( new Travelism_Pro_Dropdown_Taxonomies_Control( $wp_customize,'travelism_pro_theme_options[video_content_trip_types]', array(
	'label'             => esc_html__( 'Select Trip Types', 'travelism-pro' ),
	'section'           => 'travelism_video_section',
	'taxonomy'			=> 'itinerary_types',
	'type'              => 'dropdown-taxonomies',
	'active_callback'	=> 'travelism_pro_is_video_section_content_trip_types_enable'
) ) );

// Add dropdown category setting and control.
$wp_customize->add_setting(  'travelism_pro_theme_options[video_content_activity]', array(
	'sanitize_callback' => 'absint',
) ) ;

$wp_customize->add_control( new Travelism_Pro_Dropdown_Taxonomies_Control( $wp_customize,'travelism_pro_theme_options[video_content_activity]', array(
	'label'             => esc_html__( 'Select Activities', 'travelism-pro' ),
	'section'           => 'travelism_video_section',
	'taxonomy'			=> 'activity',
	'type'              => 'dropdown-taxonomies',
	'active_callback'	=> 'travelism_pro_is_video_section_content_activity_enable'
) ) );

// Add dropdown category setting and control.
$wp_customize->add_setting(  'travelism_pro_theme_options[video_content_destination]', array(
	'sanitize_callback' => 'absint',
) ) ;

$wp_customize->add_control( new Travelism_Pro_Dropdown_Taxonomies_Control( $wp_customize,'travelism_pro_theme_options[video_content_destination]', array(
	'label'             => esc_html__( 'Select Destinations', 'travelism-pro' ),
	'section'           => 'travelism_video_section',
	'taxonomy'			=> 'travel_locations',
	'type'              => 'dropdown-taxonomies',
	'active_callback'	=> 'travelism_pro_is_video_section_content_destination_enable'
) ) );


