<?php
/**
 * Wildlife Section options
 *
 * @package Theme Palace
 * @subpackage Travelism Pro
 * @since Travelism Pro 1.0.0
 */

// Add Wildlife section
$wp_customize->add_section( 'travelism_wildlife_section', array(
	'title'             => esc_html__( 'Wildlife Section','travelism-pro' ),
	'description'       => esc_html__( 'Wildlife Section options.', 'travelism-pro' ),
	'panel'             => 'travelism_pro_front_page_panel',
	'active_callback'   => function( $control ) {
        return ( 
        	travelism_pro_is_default_layout( $control )  
        );
    },

) );

// Wildlife content enable control and setting
$wp_customize->add_setting( 'travelism_pro_theme_options[wildlife_section_enable]', array(
	'default'			=> 	$options['wildlife_section_enable'],
	'sanitize_callback' => 'travelism_pro_sanitize_switch_control',
) );

$wp_customize->add_control( new Travelism_Pro_Switch_Control( $wp_customize, 'travelism_pro_theme_options[wildlife_section_enable]', array(
	'label'             => esc_html__( 'Wildlife Section Enable', 'travelism-pro' ),
	'section'           => 'travelism_wildlife_section',
	'on_off_label' 		=> travelism_pro_switch_options(),
) ) );

if ( isset( $wp_customize->selective_refresh ) ) {
    $wp_customize->selective_refresh->add_partial( 'travelism_pro_theme_options[wildlife_section_enable]', array(
        'selector'            => '#travelism_wildlife_section .tooltiptext',
        'settings'            => 'travelism_pro_theme_options[wildlife_section_enable]',
    ) );
}

// popular destination sub title setting and control
$wp_customize->add_setting( 'travelism_pro_theme_options[wildlife_sub_title]', array(
	'default'			=> $options['wildlife_sub_title'],
	'sanitize_callback' => 'sanitize_text_field',
	'transport'			=> 'postMessage',
) );

$wp_customize->add_control( 'travelism_pro_theme_options[wildlife_sub_title]', array(
	'label'           	=> esc_html__( 'Sub Title', 'travelism-pro' ),
	'section'        	=> 'travelism_wildlife_section',
	'active_callback' 	=> 'travelism_pro_is_wildlife_section_enable',
	'type'				=> 'text',
) );

// Abort if selective refresh is not available.
if ( isset( $wp_customize->selective_refresh ) ) {
    $wp_customize->selective_refresh->add_partial( 'travelism_pro_theme_options[wildlife_sub_title]', array(
		'selector'            => '#travelism_wildlife_section .section-subtitle',
		'settings'            => 'travelism_pro_theme_options[wildlife_sub_title]',
		'container_inclusive' => false,
		'fallback_refresh'    => true,
		'render_callback'     => 'travelism_pro_wildlife_sub_title_partial',
    ) );
}

// long Excerpt length setting and control.
$wp_customize->add_setting( 'travelism_pro_theme_options[wildlife_excerpt_length]', array(
	'sanitize_callback' => 'travelism_pro_sanitize_number_range',
	'validate_callback' => 'travelism_pro_validate_long_excerpt',
	'default'			=> $options['wildlife_excerpt_length'],
) );

$wp_customize->add_control( 'travelism_pro_theme_options[wildlife_excerpt_length]', array(
	'label'       		=> esc_html__( 'Wildlife Post Excerpt Length', 'travelism-pro' ),
	'description' 		=> esc_html__( 'Total description words to be displayed in wildlife posts.', 'travelism-pro' ),
	'section'     		=> 'travelism_wildlife_section',
	'active_callback' 	=> 'travelism_pro_is_wildlife_section_enable',
	'type'        		=> 'number',
	'input_attrs' 		=> array(
		'style'       => 'width: 80px;',
		'max'         => 100,
		'min'         => 1,
	),
) );

// Popular deatination btn label setting and control
$wp_customize->add_setting( 'travelism_pro_theme_options[wildlife_btn_label]', array(
	'sanitize_callback' => 'sanitize_text_field',
	'default'			=> $options['wildlife_btn_label'],
	'transport'			=> 'postMessage',
) );

$wp_customize->add_control( 'travelism_pro_theme_options[wildlife_btn_label]', array(
	'label'           	=> esc_html__( 'Wildlife Button Label', 'travelism-pro' ),
	'section'        	=> 'travelism_wildlife_section',
	'active_callback' 	=> 'travelism_pro_is_wildlife_section_enable',
	'type'				=> 'text',
) );

// Abort if selective refresh is not available.
if ( isset( $wp_customize->selective_refresh ) ) {
    $wp_customize->selective_refresh->add_partial( 'travelism_pro_theme_options[wildlife_btn_label]', array(
		'selector'            => '#travelism_wildlife_section .btn',
		'settings'            => 'travelism_pro_theme_options[wildlife_btn_label]',
		'container_inclusive' => false,
		'fallback_refresh'    => true,
		'render_callback'     => 'travelism_pro_wildlife_btn_label_partial',
    ) );
}

// Wildlife content type control and setting
$wp_customize->add_setting( 'travelism_pro_theme_options[wildlife_content_type]', array(
	'default'          	=> $options['wildlife_content_type'],
	'sanitize_callback' => 'travelism_pro_sanitize_select',
) );

$wp_customize->add_control( 'travelism_pro_theme_options[wildlife_content_type]', array(
	'label'             => esc_html__( 'Content Type', 'travelism-pro' ),
	'section'           => 'travelism_wildlife_section',
	'type'				=> 'select',
	'active_callback' 	=> 'travelism_pro_is_wildlife_section_enable',
	'choices'			=> travelism_pro_wildlife_content_type(),
) );

	// Popular deatination pages drop down chooser control and setting
	$wp_customize->add_setting( 'travelism_pro_theme_options[wildlife_content_page]', array(
		'sanitize_callback' => 'travelism_pro_sanitize_page',
	) );

	$wp_customize->add_control( new Travelism_Pro_Dropdown_Chooser( $wp_customize, 'travelism_pro_theme_options[wildlife_content_page]', array(
		'label'             => esc_html__( 'Select Page', 'travelism-pro' ),
		'section'           => 'travelism_wildlife_section',
		'choices'			=> travelism_pro_page_choices(),
		'active_callback'	=> 'travelism_pro_is_wildlife_section_content_page_enable',
	) ) );

	// Popular deatination posts drop down chooser control and setting
	$wp_customize->add_setting( 'travelism_pro_theme_options[wildlife_content_post]', array(
		'sanitize_callback' => 'travelism_pro_sanitize_page',
	) );

	$wp_customize->add_control( new Travelism_Pro_Dropdown_Chooser( $wp_customize, 'travelism_pro_theme_options[wildlife_content_post]', array(
		'label'             => esc_html__( 'Select posts', 'travelism-pro' ),
		'section'           => 'travelism_wildlife_section',
		'choices'			=> travelism_pro_post_choices(),
		'active_callback'	=> 'travelism_pro_is_wildlife_section_content_post_enable',
	) ) );

	// wildlife trips drop down chooser control and setting
	$wp_customize->add_setting( 'travelism_pro_theme_options[wildlife_content_trip]', array(
		'sanitize_callback' => 'travelism_pro_sanitize_page',
	) );

	$wp_customize->add_control( new Travelism_Pro_Dropdown_Chooser( $wp_customize, 'travelism_pro_theme_options[wildlife_content_trip]', array(
		'label'             => esc_html__( 'Select Trip', 'travelism-pro' ),
		'section'           => 'travelism_wildlife_section',
		'choices'			=> travelism_pro_trip_choices(),
		'active_callback'	=> 'travelism_pro_is_wildlife_section_content_trip_enable',
	) ) );