<?php
/**
 * Footer options
 *
 * @package Theme Palace
 * @subpackage Travelism Pro
 * @since Travelism Pro 1.0.0
 */

// Footer Section
$wp_customize->add_section( 'travelism_pro_section_footer',
	array(
		'title'      			=> esc_html__( 'Footer Options', 'travelism-pro' ),
		'priority'   			=> 900,
		'panel'      			=> 'travelism_pro_theme_options_panel',
	)
);

// scroll top visible
$wp_customize->add_setting( 'travelism_pro_theme_options[footer_image_enable]',
	array(
		'default'       		=> $options['footer_image_enable'],
		'sanitize_callback' => 'travelism_pro_sanitize_switch_control',
	)
);
$wp_customize->add_control( new Travelism_Pro_Switch_Control( $wp_customize, 'travelism_pro_theme_options[footer_image_enable]',
    array(
		'label'      			=> esc_html__( 'Footer Image Enable/Disable', 'travelism-pro' ),
		'section'    			=> 'travelism_pro_section_footer',
		'on_off_label' 		=> travelism_pro_switch_options(),
    )
) );

$wp_customize->add_setting( 'travelism_pro_theme_options[footer_bg_image]', array(
	'sanitize_callback' => 'travelism_pro_sanitize_image',
) );

$wp_customize->add_control( new WP_Customize_Image_Control( $wp_customize, 'travelism_pro_theme_options[footer_bg_image]',
		array(
		'label'       		=> esc_html__( 'Background Image', 'travelism-pro' ),
		'section'     		=> 'travelism_pro_section_footer',		
		'active_callback'	=> 'travelism_pro_is_footer_bg_image_enable',
) ) );

// scroll top visible
$wp_customize->add_setting( 'travelism_pro_theme_options[footer_copyright_enable]',
	array(
		'default'       		=> $options['footer_copyright_enable'],
		'sanitize_callback' => 'travelism_pro_sanitize_switch_control',
	)
);
$wp_customize->add_control( new Travelism_Pro_Switch_Control( $wp_customize, 'travelism_pro_theme_options[footer_copyright_enable]',
    array(
		'label'      			=> esc_html__( 'Copyright Section Enable/Disable', 'travelism-pro' ),
		'section'    			=> 'travelism_pro_section_footer',
		'on_off_label' 		=> travelism_pro_switch_options(),
    )
) );

// footer text
$wp_customize->add_setting( 'travelism_pro_theme_options[copyright_text]',
	array(
		'default'       		=> $options['copyright_text'],
		'sanitize_callback'		=> 'travelism_pro_santize_allow_tag',
		'transport'				=> 'postMessage',
	)
);
$wp_customize->add_control( 'travelism_pro_theme_options[copyright_text]',
    array(
		'label'      			=> esc_html__( 'Copyright Text', 'travelism-pro' ),
		'section'    			=> 'travelism_pro_section_footer',
		'type'		 			=> 'textarea',
		'active_callback'	=> 'travelism_pro_is_footer_section_section_enable',
    )
);

// Abort if selective refresh is not available.
if ( isset( $wp_customize->selective_refresh ) ) {
    $wp_customize->selective_refresh->add_partial( 'travelism_pro_theme_options[copyright_text]', array(
		'selector'            => '.site-info .copyright p',
		'settings'            => 'travelism_pro_theme_options[copyright_text]',
		'container_inclusive' => false,
		'fallback_refresh'    => true,
		'render_callback'     => 'travelism_pro_copyright_text_partial',
    ) );
}

// scroll top visible
$wp_customize->add_setting( 'travelism_pro_theme_options[footer_social_menu]',
	array(
		'default'       		=> $options['footer_social_menu'],
		'sanitize_callback' => 'travelism_pro_sanitize_switch_control',
	)
);
$wp_customize->add_control( new Travelism_Pro_Switch_Control( $wp_customize, 'travelism_pro_theme_options[footer_social_menu]',
    array(
		'label'      			=> esc_html__( 'Footer Social Menu', 'travelism-pro' ),
		'section'    			=> 'travelism_pro_section_footer',
		'on_off_label' 		=> travelism_pro_switch_options(),
		'active_callback'	=> 'travelism_pro_is_footer_section_section_enable',
    )
) );

// scroll top visible
$wp_customize->add_setting( 'travelism_pro_theme_options[scroll_top_visible]',
	array(
		'default'       		=> $options['scroll_top_visible'],
		'sanitize_callback' => 'travelism_pro_sanitize_switch_control',
	)
);
$wp_customize->add_control( new Travelism_Pro_Switch_Control( $wp_customize, 'travelism_pro_theme_options[scroll_top_visible]',
    array(
		'label'      			=> esc_html__( 'Display Scroll Top Button', 'travelism-pro' ),
		'section'    			=> 'travelism_pro_section_footer',
		'on_off_label' 		=> travelism_pro_switch_options(),
    )
) );

$wp_customize->add_setting( 'travelism_pro_theme_options[footer_hr]', array(
		'sanitize_callback' => 'sanitize_text_field'
	) );

	$wp_customize->add_control( new Travelism_Pro_Customize_Horizontal_Line( $wp_customize, 'travelism_pro_theme_options[footer_hr]',
		array(
			'section'         => 'travelism_pro_section_footer',
			'type'			  => 'hr',
	) ) );

	$wp_customize->add_setting( 'travelism_pro_theme_options[footer_overlay_color]', array(
		'sanitize_callback' => 'sanitize_hex_color',
		'transport'			=> 'postMessage',
		) );

	$wp_customize->add_control( new WP_Customize_Color_Control( $wp_customize, 'travelism_pro_theme_options[footer_overlay_color]', array(
		'label'             => esc_html__( 'Footer Overlay Color', 'travelism-pro' ),
		'section'  => 'travelism_pro_section_footer',
		'active_callback'	=> 'travelism_pro_is_footer_bg_image_enable',
		) ) );

	$wp_customize->add_setting( 'travelism_pro_theme_options[footer_bg_color]', array(
		'sanitize_callback' => 'sanitize_hex_color',
		'transport'			=> 'postMessage',
		) );

	$wp_customize->add_control( new WP_Customize_Color_Control( $wp_customize, 'travelism_pro_theme_options[footer_bg_color]', array(
		'label'             => esc_html__( 'Footer BG Color', 'travelism-pro' ),
		'section'  => 'travelism_pro_section_footer',
		'active_callback'	=> 'travelism_pro_is_footer_bg_color_enable',
		) ) );

	$wp_customize->add_setting( 'travelism_pro_theme_options[widget_title_color]', array(
		'sanitize_callback' => 'sanitize_hex_color',
		'transport'			=> 'postMessage',
		) );

	$wp_customize->add_control( new WP_Customize_Color_Control( $wp_customize, 'travelism_pro_theme_options[widget_title_color]', array(
		'label'             => esc_html__( 'Widget Title Color', 'travelism-pro' ),
		'section'  => 'travelism_pro_section_footer',
		) ) );

	$wp_customize->add_setting( 'travelism_pro_theme_options[widget_content_color]', array(
		'sanitize_callback' => 'sanitize_hex_color',
		'transport'			=> 'postMessage',
		) );

	$wp_customize->add_control( new WP_Customize_Color_Control( $wp_customize, 'travelism_pro_theme_options[widget_content_color]', array(
		'label'             => esc_html__( 'Widget Content Color', 'travelism-pro' ),
		'section'  => 'travelism_pro_section_footer',
		) ) );

	$wp_customize->add_setting( 'travelism_pro_theme_options[footer_hover_color]', array(
		'sanitize_callback' => 'sanitize_hex_color',
		) );

	$wp_customize->add_control( new WP_Customize_Color_Control( $wp_customize, 'travelism_pro_theme_options[footer_hover_color]', array(
		'label'             => esc_html__( 'Footer Hover Color', 'travelism-pro' ),
		'section'  => 'travelism_pro_section_footer',
		) ) );

	$wp_customize->add_setting( 'travelism_pro_theme_options[footer_social_icon_color]', array(
		'sanitize_callback' => 'sanitize_hex_color',
		'transport'			=> 'postMessage',
		) );

	$wp_customize->add_control( new WP_Customize_Color_Control( $wp_customize, 'travelism_pro_theme_options[footer_social_icon_color]', array(
		'label'             => esc_html__( 'Footer Social Icon Color', 'travelism-pro' ),
		'section'  => 'travelism_pro_section_footer',
		) ) );

	$wp_customize->add_setting( 'travelism_pro_theme_options[footer_hr_color]', array(
		'sanitize_callback' => 'sanitize_hex_color',
		) );

	$wp_customize->add_control( new WP_Customize_Color_Control( $wp_customize, 'travelism_pro_theme_options[footer_hr_color]', array(
		'label'             => esc_html__( 'Footer Horizontal (hr) Color', 'travelism-pro' ),
		'section'  => 'travelism_pro_section_footer',
		) ) );