<?php
/**
 * Menu options
 *
 * @package Theme Palace
 * @subpackage Travelism Pro
 * @since Travelism Pro 1.0.0
 */

// Add sidebar section
$wp_customize->add_section( 'travelism_pro_menu', array(
	'title'             => esc_html__('Header Menu','travelism-pro'),
	'description'       => esc_html__( 'Header Menu options.', 'travelism-pro' ),
	'panel'             => 'nav_menus',
) );

// Menu sticky setting and control.
$wp_customize->add_setting( 'travelism_pro_theme_options[menu_sticky]', array(
	'sanitize_callback' => 'travelism_pro_sanitize_switch_control',
	'default'           => $options['menu_sticky'],
) );

$wp_customize->add_control( new Travelism_Pro_Switch_Control( $wp_customize, 'travelism_pro_theme_options[menu_sticky]', array(
	'label'             => esc_html__( 'Make Menu Sticky', 'travelism-pro' ),
	'section'           => 'travelism_pro_menu',
	'on_off_label' 		=> travelism_pro_switch_options(),
) ) );

// Topbar contact number control and setting
$wp_customize->add_setting( 'travelism_pro_theme_options[contact_number]', array(
	'default'			=> $options['contact_number'],
    'sanitize_callback' => 'sanitize_text_field',
    'transport'			=> 'postMessage',
) );
    
$wp_customize->add_control( 'travelism_pro_theme_options[contact_number]', array(
    'label'           	=> esc_html__( 'Contact Number', 'travelism-pro' ),
    'section'        	=> 'travelism_pro_menu',
    'type'				=> 'text',
) );

// Abort if selective refresh is not available.
if ( isset( $wp_customize->selective_refresh ) ) {
    $wp_customize->selective_refresh->add_partial( 'travelism_pro_theme_options[contact_number]', array(
		'selector'            => '.contact-info',
		'settings'            => 'travelism_pro_theme_options[contact_number]',
		'container_inclusive' => false,
		'fallback_refresh'    => true,
		'render_callback'     => 'travelism_pro_contact_number_partial',
    ) );
}

if ( class_exists('WooCommerce') ) {

$wp_customize->add_setting( 'travelism_pro_theme_options[cart_icon]', array(
	'sanitize_callback' => 'travelism_pro_sanitize_switch_control',
	'default'           => $options['cart_icon'],
) );

$wp_customize->add_control( new Travelism_Pro_Switch_Control( $wp_customize, 'travelism_pro_theme_options[cart_icon]', array(
	'label'             => esc_html__( 'Enable Cart Icon', 'travelism-pro' ),
	'section'           => 'travelism_pro_menu',
	'on_off_label' 		=> travelism_pro_switch_options(),
) ) );

}

$wp_customize->add_setting( 'travelism_pro_theme_options[menu_button_enable]', array(
	'sanitize_callback' => 'travelism_pro_sanitize_switch_control',
	'default'           => $options['menu_button_enable'],
) );

$wp_customize->add_control( new Travelism_Pro_Switch_Control( $wp_customize, 'travelism_pro_theme_options[menu_button_enable]', array(
	'label'             => esc_html__( 'Enable Top Menu Button', 'travelism-pro' ),
	'section'           => 'travelism_pro_menu',
	'on_off_label' 		=> travelism_pro_switch_options(),
) ) );

// Popular deatination btn label setting and control
$wp_customize->add_setting( 'travelism_pro_theme_options[menu_btn_label]', array(
	'sanitize_callback' => 'sanitize_text_field',
	'default'			=> $options['menu_btn_label'],
	'transport'			=> 'postMessage',
) );

$wp_customize->add_control( 'travelism_pro_theme_options[menu_btn_label]', array(
	'label'           	=> esc_html__( 'Top Menu Button Label', 'travelism-pro' ),
	'section'        	=> 'travelism_pro_menu',
	'type'				=> 'text',
	'active_callback'	=> 'travelism_pro_is_cart_icon_section_enable',
) );

// Abort if selective refresh is not available.
if ( isset( $wp_customize->selective_refresh ) ) {
    $wp_customize->selective_refresh->add_partial( 'travelism_pro_theme_options[menu_btn_label]', array(
		'selector'            => '#site-navigation .custom-button',
		'settings'            => 'travelism_pro_theme_options[menu_btn_label]',
		'container_inclusive' => false,
		'fallback_refresh'    => true,
		'render_callback'     => 'travelism_pro_menu_btn_label_partial',
    ) );
}

$wp_customize->add_setting( 'travelism_pro_theme_options[menu_btn_url]', array(
'sanitize_callback' => 'esc_url_raw',
	) );

$wp_customize->add_control( 'travelism_pro_theme_options[menu_btn_url]', array(
	'label'           	=> esc_html__( 'Button URL', 'travelism-pro' ),
	'section'        	=> 'travelism_pro_menu',
	'type'				=> 'url',
	'active_callback'	=> 'travelism_pro_is_cart_icon_section_enable',
) );

$wp_customize->add_setting( 'travelism_pro_theme_options[menu_hr]', array(
		'sanitize_callback' => 'sanitize_text_field'
	) );

	$wp_customize->add_control( new Travelism_Pro_Customize_Horizontal_Line( $wp_customize, 'travelism_pro_theme_options[menu_hr]',
		array(
			'section'         => 'travelism_pro_menu',
			'type'			  => 'hr',
	) ) );

	$wp_customize->add_setting( 'travelism_pro_theme_options[menu_bg_color]', array(
		'sanitize_callback' => 'sanitize_hex_color',
		'transport'			=> 'postMessage',
		) );

	$wp_customize->add_control( new WP_Customize_Color_Control( $wp_customize, 'travelism_pro_theme_options[menu_bg_color]', array(
		'label'             => esc_html__( 'Sticky Menu BG Color', 'travelism-pro' ),
		'section'  => 'travelism_pro_menu',
		'active_callback'	=> 'travelism_pro_is_menu_sticky_enable',
		) ) );

	$wp_customize->add_setting( 'travelism_pro_theme_options[menu_item_color]', array(
		'sanitize_callback' => 'sanitize_hex_color',
		'transport'			=> 'postMessage',
		) );

	$wp_customize->add_control( new WP_Customize_Color_Control( $wp_customize, 'travelism_pro_theme_options[menu_item_color]', array(
		'label'             => esc_html__( 'Menu Item Color', 'travelism-pro' ),
		'section'  => 'travelism_pro_menu',
		) ) );

	$wp_customize->add_setting( 'travelism_pro_theme_options[menu_item_hover_color]', array(
		'sanitize_callback' => 'sanitize_hex_color',
		) );

	$wp_customize->add_control( new WP_Customize_Color_Control( $wp_customize, 'travelism_pro_theme_options[menu_item_hover_color]', array(
		'label'             => esc_html__( 'Menu Item Hover Color', 'travelism-pro' ),
		'section'  => 'travelism_pro_menu',
		) ) );

	$wp_customize->add_setting( 'travelism_pro_theme_options[menu_no_color]', array(
		'sanitize_callback' => 'sanitize_hex_color',
		'transport'			=> 'postMessage',
		) );

	$wp_customize->add_control( new WP_Customize_Color_Control( $wp_customize, 'travelism_pro_theme_options[menu_no_color]', array(
		'label'             => esc_html__( 'Contact Number Color', 'travelism-pro' ),
		'section'  => 'travelism_pro_menu',
		) ) );

	$wp_customize->add_setting( 'travelism_pro_theme_options[menu_no_hover_color]', array(
		'sanitize_callback' => 'sanitize_hex_color',
		) );

	$wp_customize->add_control( new WP_Customize_Color_Control( $wp_customize, 'travelism_pro_theme_options[menu_no_hover_color]', array(
		'label'             => esc_html__( 'Contact Number Hover Color', 'travelism-pro' ),
		'section'  => 'travelism_pro_menu',
		) ) );

	$wp_customize->add_setting( 'travelism_pro_theme_options[menu_button_color]', array(
		'sanitize_callback' => 'sanitize_hex_color',
		'transport'			=> 'postMessage',
		) );

	$wp_customize->add_control( new WP_Customize_Color_Control( $wp_customize, 'travelism_pro_theme_options[menu_button_color]', array(
		'label'             => esc_html__( 'Menu Button BG Color', 'travelism-pro' ),
		'section'  => 'travelism_pro_menu',
		) ) );

	$wp_customize->add_setting( 'travelism_pro_theme_options[menu_button_hover_color]', array(
		'sanitize_callback' => 'sanitize_hex_color',
		) );

	$wp_customize->add_control( new WP_Customize_Color_Control( $wp_customize, 'travelism_pro_theme_options[menu_button_hover_color]', array(
		'label'             => esc_html__( 'Menu Button BG Hover Color', 'travelism-pro' ),
		'section'  => 'travelism_pro_menu',
		) ) );