<?php
/**
 * Theme Palace options
 *
 * @package Theme Palace
 * @subpackage Travelism Pro
 * @since Travelism Pro 1.0.0
 */

/**
 * List of pages for page choices.
 * @return Array Array of page ids and name.
 */
function travelism_pro_page_choices() {
    $pages = get_pages();
    $choices = array();
    $choices[0] = esc_html__( '--Select--', 'travelism-pro' );
    foreach ( $pages as $page ) {
        $choices[ $page->ID ] = $page->post_title;
    }
    return  $choices;
}

/**
 * List of posts for post choices.
 * @return Array Array of post ids and name.
 */
function travelism_pro_post_choices() {
    $posts = get_posts( array( 'numberposts' => -1 ) );
    $choices = array();
    $choices[0] = esc_html__( '--Select--', 'travelism-pro' );
    foreach ( $posts as $post ) {
        $choices[ $post->ID ] = $post->post_title;
    }
    return  $choices;
}

/**
 * List of trips for post choices.
 * @return Array Array of post ids and name.
 */
function travelism_pro_trip_choices() {
    $posts = get_posts( array( 'post_type' => 'itineraries', 'numberposts' => -1 ) );
    $choices = array();
    $choices[0] = esc_html__( '--Select--', 'travelism-pro' );
    foreach ( $posts as $post ) {
        $choices[ $post->ID ] = $post->post_title;
    }
    return  $choices;
}

function travelism_pro_product_choices() {
    $full_product_list = array();
    $product_id = array();
    $loop = new WP_Query(array('post_type' => array('product', 'product_variation'), 'posts_per_page' => -1));
    while ($loop->have_posts()) : $loop->the_post();
        $product_id[] = get_the_id();
    endwhile;
    wp_reset_postdata();
    $choices = array();
    $choices[0] = esc_html__( '--Select--', 'travelism-pro' );
    foreach ( $product_id  as $id ) {
        $choices[ $id ] = get_the_title( $id );
    }
    return  $choices;
}

if ( ! function_exists( 'travelism_pro_typography_options' ) ) :
    /**
     * Returns list of typography
     * @return array font styles
     */
    function travelism_pro_typography_options(){
        $font_family_arr = array();
        $font_family_arr[''] = esc_html__( '--Default--', 'travelism-pro' );

        // Make the request
        $request = wp_remote_get( get_theme_file_uri( 'assets/webfonts.json' ) );

        if( is_wp_error( $request ) ) {
            return false; // Bail early
        }
        // Retrieve the data
        $body = wp_remote_retrieve_body( $request );
        $data = json_decode( $body );
        if ( ! empty( $data ) ) {
            foreach ( $data->items as $items => $fonts ) {
                $family_str_arr = explode( ' ', $fonts->family );
                $family_value = implode( '+', $family_str_arr );
                $font_family_arr[ $family_value ] = $fonts->family;
            }
        }

        return $font_family_arr;
    }
endif;


if ( ! function_exists( 'travelism_pro_selected_sidebar' ) ) :
    /**
     * Sidebars options
     * @return array Sidbar positions
     */
    function travelism_pro_selected_sidebar() {
        $travelism_pro_selected_sidebar = array(
            'sidebar-1'             => esc_html__( 'Default Sidebar', 'travelism-pro' ),
            'optional-sidebar'      => esc_html__( 'Optional Sidebar 1', 'travelism-pro' ),
            'optional-sidebar-2'    => esc_html__( 'Optional Sidebar 2', 'travelism-pro' ),
            'optional-sidebar-3'    => esc_html__( 'Optional Sidebar 3', 'travelism-pro' ),
            'optional-sidebar-4'    => esc_html__( 'Optional Sidebar 4', 'travelism-pro' ),
        );

        $output = apply_filters( 'travelism_pro_selected_sidebar', $travelism_pro_selected_sidebar );

        return $output;
    }
endif;

if ( ! function_exists( 'travelism_pro_site_layout' ) ) :
    /**
     * Site Layout
     * @return array site layout options
     */
    function travelism_pro_site_layout() {
        $travelism_pro_site_layout = array(
            'wide-layout'  => get_template_directory_uri() . '/assets/images/full.png',
            'boxed-layout' => get_template_directory_uri() . '/assets/images/boxed.png',
            'frame-layout' => get_template_directory_uri() . '/assets/images/framed.png',
        );

        $output = apply_filters( 'travelism_pro_site_layout', $travelism_pro_site_layout );
        return $output;
    }
endif;


if ( ! function_exists( 'travelism_pro_global_sidebar_position' ) ) :
    /**
     * Global Sidebar position
     * @return array Global Sidebar positions
     */
    function travelism_pro_global_sidebar_position() {
        $travelism_pro_global_sidebar_position = array(
            'right-sidebar' => get_template_directory_uri() . '/assets/images/right.png',
            'left-sidebar'  => get_template_directory_uri() . '/assets/images/left.png',
            'no-sidebar'    => get_template_directory_uri() . '/assets/images/full.png',
        );

        $output = apply_filters( 'travelism_pro_global_sidebar_position', $travelism_pro_global_sidebar_position );

        return $output;
    }
endif;


if ( ! function_exists( 'travelism_pro_sidebar_position' ) ) :
    /**
     * Sidebar position
     * @return array Sidbar positions
     */
    function travelism_pro_sidebar_position() {
        $travelism_pro_sidebar_position = array(
            'right-sidebar' => get_template_directory_uri() . '/assets/images/right.png',
            'left-sidebar'  => get_template_directory_uri() . '/assets/images/left.png',
            'no-sidebar'    => get_template_directory_uri() . '/assets/images/full.png',
            'no-sidebar-content'   => get_template_directory_uri() . '/assets/images/boxed.png',
        );

        $output = apply_filters( 'travelism_pro_sidebar_position', $travelism_pro_sidebar_position );

        return $output;
    }
endif;


if ( ! function_exists( 'travelism_pro_pagination_options' ) ) :
    /**
     * Pagination
     * @return array site pagination options
     */
    function travelism_pro_pagination_options() {
        $travelism_pro_pagination_options = array(
            'numeric'   => esc_html__( 'Numeric', 'travelism-pro' ),
            'default'   => esc_html__( 'Default(Older/Newer)', 'travelism-pro' ),
            'infinite'  => esc_html__( 'Infinite', 'travelism-pro' ),
        );

        $output = apply_filters( 'travelism_pro_pagination_options', $travelism_pro_pagination_options );

        return $output;
    }
endif;

if ( ! function_exists( 'travelism_pro_get_spinner_list' ) ) :
    /**
     * List of spinner icons options.
     * @return array List of all spinner icon options.
     */
    function travelism_pro_get_spinner_list() {
        $arr = array(
            'default'               => esc_html__( 'Default', 'travelism-pro' ),
            'spinner-wheel'         => esc_html__( 'Wheel', 'travelism-pro' ),
            'spinner-double-circle' => esc_html__( 'Double Circle', 'travelism-pro' ),
            'spinner-two-way'       => esc_html__( 'Two Way', 'travelism-pro' ),
            'spinner-umbrella'      => esc_html__( 'Umbrella', 'travelism-pro' ),
            'spinner-dots'          => esc_html__( 'Dots', 'travelism-pro' ),
            'spinner-one-way'       => esc_html__( 'One Way', 'travelism-pro' ),
            'spinner-fidget'        => esc_html__( 'Fidget', 'travelism-pro' ),
        );
        return apply_filters( 'travelism_pro_spinner_list', $arr );
    }
endif;

if ( ! function_exists( 'travelism_pro_switch_options' ) ) :
    /**
     * List of custom Switch Control options
     * @return array List of switch control options.
     */
    function travelism_pro_switch_options() {
        $arr = array(
            'on'        => esc_html__( 'Enable', 'travelism-pro' ),
            'off'       => esc_html__( 'Disable', 'travelism-pro' )
        );
        return apply_filters( 'travelism_pro_switch_options', $arr );
    }
endif;

if ( ! function_exists( 'travelism_pro_hide_options' ) ) :
    /**
     * List of custom Switch Control options
     * @return array List of switch control options.
     */
    function travelism_pro_hide_options() {
        $arr = array(
            'on'        => esc_html__( 'Yes', 'travelism-pro' ),
            'off'       => esc_html__( 'No', 'travelism-pro' )
        );
        return apply_filters( 'travelism_pro_hide_options', $arr );
    }
endif;

if ( ! function_exists( 'travelism_pro_featured_content_type' ) ) :
    /**
     * featured Options
     * @return array site featured options
     */
    function travelism_pro_featured_content_type() {
        $travelism_pro_featured_content_type = array(
            'page'      => esc_html__( 'Page', 'travelism-pro' ),
            'post'      => esc_html__( 'Post', 'travelism-pro' ),
            'category'  => esc_html__( 'Category', 'travelism-pro' ),
        );

        if ( class_exists( 'WP_Travel' ) ) {
            $travelism_pro_featured_content_type = array_merge( $travelism_pro_featured_content_type, array(
                'trip'          => esc_html__( 'Trip', 'travelism-pro' ),
                'trip-types'    => esc_html__( 'Trip Types', 'travelism-pro' ),
                'destination'   => esc_html__( 'Destination', 'travelism-pro' ),
                'activity'      => esc_html__( 'Activity', 'travelism-pro' ),
                ) );
        }

        $output = apply_filters( 'travelism_pro_featured_content_type', $travelism_pro_featured_content_type );


        return $output;
    }
endif;

if ( ! function_exists( 'travelism_pro_video_content_type' ) ) :
    /**
     * featured Options
     * @return array site featured options
     */
    function travelism_pro_video_content_type() {
        $travelism_pro_video_content_type = array(
            'page'      => esc_html__( 'Page', 'travelism-pro' ),
            'post'      => esc_html__( 'Post', 'travelism-pro' ),
            'category'  => esc_html__( 'Category', 'travelism-pro' ),
        );

        if ( class_exists( 'WP_Travel' ) ) {
            $travelism_pro_video_content_type = array_merge( $travelism_pro_video_content_type, array(
                'trip'          => esc_html__( 'Trip', 'travelism-pro' ),
                'trip-types'    => esc_html__( 'Trip Types', 'travelism-pro' ),
                'destination'   => esc_html__( 'Destination', 'travelism-pro' ),
                'activity'      => esc_html__( 'Activity', 'travelism-pro' ),
                ) );
        }

        $output = apply_filters( 'travelism_pro_video_content_type', $travelism_pro_video_content_type );


        return $output;
    }
endif;

if ( ! function_exists( 'travelism_pro_wildlife_content_type' ) ) :
    /**
     * featured Options
     * @return array site featured options
     */
    function travelism_pro_wildlife_content_type() {
        $travelism_pro_wildlife_content_type = array(
            'page'      => esc_html__( 'Page', 'travelism-pro' ),
            'post'      => esc_html__( 'Post', 'travelism-pro' ),
        );

        if ( class_exists( 'WP_Travel' ) ) {
            $travelism_pro_wildlife_content_type = array_merge( $travelism_pro_wildlife_content_type, array(
                'trip'          => esc_html__( 'Trip', 'travelism-pro' ),
                ) );
        }

        $output = apply_filters( 'travelism_pro_wildlife_content_type', $travelism_pro_wildlife_content_type );


        return $output;
    }
endif;

if ( ! function_exists( 'travelism_pro_gallery_content_type' ) ) :
    /**
     * gallery Options
     * @return array site gallery options
     */
    function travelism_pro_gallery_content_type() {
        $travelism_pro_gallery_content_type = array(
            'page'      => esc_html__( 'Page', 'travelism-pro' ),
            'post'      => esc_html__( 'Post', 'travelism-pro' ),
            'category'  => esc_html__( 'Category', 'travelism-pro' ),
        );

        if ( class_exists( 'WP_Travel' ) ) {
            $travelism_pro_gallery_content_type = array_merge( $travelism_pro_gallery_content_type, array(
                'trip'          => esc_html__( 'Trip', 'travelism-pro' ),
                'trip-types'    => esc_html__( 'Trip Types', 'travelism-pro' ),
                'destination'   => esc_html__( 'Destination', 'travelism-pro' ),
                'activity'      => esc_html__( 'Activity', 'travelism-pro' ),
                ) );
        }

        $output = apply_filters( 'travelism_pro_gallery_content_type', $travelism_pro_gallery_content_type );

        return $output;
    }
endif;

if ( ! function_exists( 'travelism_pro_sortable_sections' ) ) :
    /**
     * List of sections Control options
     * @return array List of Sections control options.
     */
    function travelism_pro_sortable_sections() {
        $sections = array(
            'hero_banner'             => esc_html__( 'Hero Banner Section', 'travelism-pro' ),
            'northface_jacket'        => esc_html__( 'Northface Jacket Section', 'travelism-pro' ),
            'featured'                => esc_html__( 'Featured Section', 'travelism-pro' ),
            'video'                   => esc_html__( 'Video Section', 'travelism-pro' ),
            'wildlife'                => esc_html__( 'Wildlife Section', 'travelism-pro' ),
            'gallery'                 => esc_html__( 'Gallery Section', 'travelism-pro' ),
            'happy_clients'           => esc_html__( 'Happy Clients Section', 'travelism-pro' ),
            'logos'                   => esc_html__( 'Clients / Partners Logo Section', 'travelism-pro' ),
            'articles'                => esc_html__( 'Articles Section', 'travelism-pro' ),
            'blog_slider'             => esc_html__( 'Slider Section', 'travelism-pro' ),
            'blog_featured_post'      => esc_html__( 'Featured Posts Section', 'travelism-pro' ),
            'blog_popular_post'       => esc_html__( 'Popular Posts Section', 'travelism-pro' ),
            'blog_cta'                => esc_html__( 'CTA Section', 'travelism-pro' ),
            'most_read_post'          => esc_html__( 'Most Read Section', 'travelism-pro' ),
            'subscribe_now'           => esc_html__( 'Subscribe Now Section', 'travelism-pro' ),
            'recent_post'             => esc_html__( 'Recent Post Section', 'travelism-pro' ),
            'business_service'        => esc_html__( 'Service Section', 'travelism-pro' ),
            'business_about'          => esc_html__( 'About Section', 'travelism-pro' ),
            'business_team'           => esc_html__( 'Team Section', 'travelism-pro' ),
            'business_counter'        => esc_html__( 'Counter Section', 'travelism-pro' ),
            'shop_recent_products'    => esc_html__( 'Recent Products Section', 'travelism-pro' ),
            'trending_products'       => esc_html__( 'Trending Products Section', 'travelism-pro' ),
            'featured_products'       => esc_html__( 'Featured Products Section', 'travelism-pro' ),
        );
        return apply_filters( 'travelism_pro_sortable_sections', $sections );
    }
endif;

if ( ! function_exists( 'travelism_pro_heading_tags' ) ) :
    /**
     * Destination Options
     * @return array site gallery options
     */
    function travelism_pro_heading_tags() {
        
        $travelism_pro_heading_tags = array(
			'h1'	=> esc_html__('H1', 'travelism-pro'),
			'h2'	=> esc_html__('H2', 'travelism-pro'),
			'h3'	=> esc_html__('H3', 'travelism-pro'),
			'h4'	=> esc_html__('H4', 'travelism-pro'),
			'h5'	=> esc_html__('H5', 'travelism-pro'),
			'h6'	=> esc_html__('H6', 'travelism-pro'),
			'p'		=> esc_html__('Paragraph', 'travelism-pro'),
		);

        $output = apply_filters( 'travelism_pro_heading_tags', $travelism_pro_heading_tags );


        return $output;
    }
endif;