<?php
/**
 * CTA section
 *
 * This is the template for the content of hero banner section
 *
 * @package Theme Palace
 * @subpackage Travelism Pro
 * @since Travelism Pro 1.0.0
 */
if ( ! function_exists( 'travelism_pro_add_blog_cta_section' ) ) :
    /**
    * Add hero banner section
    *
    *@since Travelism Pro 1.0.0
    */
    function travelism_pro_add_blog_cta_section() {
    	$options = travelism_pro_get_theme_options();
        // Check if hero banner is enabled on frontpage
        $blog_cta_enable = apply_filters( 'travelism_pro_section_status', true, 'blog_cta_section_enable' );

        if ( true !== $blog_cta_enable ) {
            return false;
        }
        // Get hero banner section details
        $section_details = array();
        $section_details = apply_filters( 'travelism_pro_filter_blog_cta_section_details', $section_details );

        if ( empty( $section_details ) ) {
            return;
        }

        // Render hero banner section now.
        travelism_pro_render_blog_cta_section( $section_details );
    }
endif;

if ( ! function_exists( 'travelism_pro_get_blog_cta_section_details' ) ) :
    /**
    * hero banner section details.
    *
    * @since Travelism Pro 1.0.0
    * @param array $input hero banner section details.
    */
    function travelism_pro_get_blog_cta_section_details( $input ) {
        $options = travelism_pro_get_theme_options();

        // Content type.
        $blog_cta_content_type  = $options['blog_cta_content_type'];
        
        $content = array();
        switch ( $blog_cta_content_type ) {
        	
            case 'custom':
                $custom['title']        = ! empty( $options['blog_cta_title'] ) ? $options['blog_cta_title'] : '';
                $custom['excerpt']      = ! empty( $options['blog_cta_description'] ) ? $options['blog_cta_description'] : '';

                // Push to the main array.
                array_push( $content, $custom );
            break;

            case 'page':
                $page_id = ! empty( $options['blog_cta_content_page'] ) ? $options['blog_cta_content_page'] : '';
                $args = array(
                    'post_type'         => 'page',
                    'page_id'           => $page_id,
                    'posts_per_page'    => 1,
                    );                    
            break;

            case 'post':
                $post_id = ! empty( $options['blog_cta_content_post'] ) ? $options['blog_cta_content_post'] : '';
                $args = array(
                    'post_type'         => 'post',
                    'p'                 => $post_id,
                    'posts_per_page'    => 1,
                    );
            break;

            default:
            break;
        }

        if ( 'custom' !== $blog_cta_content_type ) :
            // Run The Loop.
            $query = new WP_Query( $args );
            if ( $query->have_posts() ) : 
                while ( $query->have_posts() ) : $query->the_post();
                    $page_post['id']        = get_the_id();
                    $page_post['title']     = get_the_title();
                    $page_post['excerpt']   = travelism_pro_trim_content( $options['blog_cta_excerpt_length'] );
                    $page_post['url']       = get_the_permalink();

                    // Push to the main array.
                    array_push( $content, $page_post );
                endwhile;
            endif;
            wp_reset_postdata();
        endif;
            
        if ( ! empty( $content ) ) {
            $input = $content;
        }
        return $input;
    }
endif;
// hero banner section content details.
add_filter( 'travelism_pro_filter_blog_cta_section_details', 'travelism_pro_get_blog_cta_section_details' );


if ( ! function_exists( 'travelism_pro_render_blog_cta_section' ) ) :
  /**
   * Start hero banner section
   *
   * @return string hero banner content
   * @since Travelism Pro 1.0.0
   *
   */
   function travelism_pro_render_blog_cta_section( $content_details = array() ) {
        $options = travelism_pro_get_theme_options();

        if ( empty( $content_details ) ) {
            return;
        } 

        foreach ( $content_details as $content ) : 
            $blog_cta_bg_image = !empty( $options['blog_cta_bg_image'] ) ? $options['blog_cta_bg_image'] : '';
        ?>
            
             <div id="travelism_blog_cta_section" class="relative page-section same-background">
                <div class="wrapper">

                <?php if ( is_customize_preview()):
                    travelism_pro_section_tooltip( 'travelism_blog_cta_section' );
                    endif; ?>
                    <article style="background-image: url('<?php echo esc_html( $blog_cta_bg_image ); ?>');">
                        <div class="overlay"></div>
                            <div class="entry-container">
                            <?php if( !empty( $options['blog_cta_video_url'] ) ): ?>
                            <div class="video-button">
                                <a href="<?php echo esc_url( $options['blog_cta_video_url'] ); ?>" class="popup-video"><i class="fa fa-play"></i></a>
                            </div><!-- .video-button -->
                        <?php endif; ?>

                            <header class="entry-header">
                                <h2 class="entry-title"><?php echo esc_html( $content['title'] ); ?></h2>
                            </header>

                            <div class="entry-content">
                                <p><?php echo esc_html( $content['excerpt'] ); ?></p>
                            </div><!-- .entry-content -->
                        </div>
                    </article>
                </div><!-- .wrapper -->
            </div><!-- #travelism_blog_cta_section -->
            
        <?php endforeach;
    }
endif;