<?php
/**
 * Featured Posts section
 *
 * This is the template for the content of featured_post section
 *
 * @package Theme Palace
 * @subpackage Travelism Pro
 * @since Travelism Pro 1.0.0
 */
if ( ! function_exists( 'travelism_pro_add_blog_featured_post_section' ) ) :
    /**
    * Add featured_post section
    *
    *@since Travelism Pro 1.0.0
    */
    function travelism_pro_add_blog_featured_post_section() {
        $options = travelism_pro_get_theme_options();
        // Check if featured_post is enabled on frontpage
        $featured_post_enable = apply_filters( 'travelism_pro_section_status', true, 'blog_featured_post_section_enable' );

        if ( true !== $featured_post_enable ) {
            return false;
        }
        // Get featured_post section details
        $section_details = array();
        $section_details = apply_filters( 'travelism_pro_filter_blog_featured_post_section_details', $section_details );

        if ( empty( $section_details ) ) {
            return;
        }

        // Render featured_post section now.
        travelism_pro_render_blog_featured_post_section( $section_details );
    }
endif;

if ( ! function_exists( 'travelism_pro_get_blog_featured_post_section_details' ) ) :
    /**
    * featured_post section details.
    *
    * @since Travelism Pro 1.0.0
    * @param array $input featured_post section details.
    */
    function travelism_pro_get_blog_featured_post_section_details( $input ) {
        $options = travelism_pro_get_theme_options();

        // Content type.
        $blog_featured_post_content_type  = $options['blog_featured_post_content_type'];
        $blog_featured_post_count = ! empty( $options['blog_featured_post_count'] ) ? $options['blog_featured_post_count'] : 3;
        
        $content = array();
        switch ( $blog_featured_post_content_type ) {
            
            case 'page':
                $page_ids = array();

                for ( $i = 1; $i <= $blog_featured_post_count; $i++ ) {
                    if ( ! empty( $options['blog_featured_post_content_page_' . $i] ) )
                        $page_ids[] = $options['blog_featured_post_content_page_' . $i];
                }
                
                $args = array(
                    'post_type'         => 'page',
                    'post__in'          => ( array ) $page_ids,
                    'posts_per_page'    => absint( $blog_featured_post_count ),
                    'orderby'           => 'post__in',
                    );                    
            break;

            case 'post':
                $post_ids = array();

                for ( $i = 1; $i <= $blog_featured_post_count; $i++ ) {
                    if ( ! empty( $options['blog_featured_post_content_post_' . $i] ) )
                        $post_ids[] = $options['blog_featured_post_content_post_' . $i];
                }
                $args = array(
                    'post_type'         => 'post',
                    'post__in'          => ( array ) $post_ids,
                    'posts_per_page'    => absint( $blog_featured_post_count ),
                    'orderby'           => 'post__in',
                    'ignore_sticky_posts'   => true,
                    );                    
            break;

            case 'category':
                $cat_id = ! empty( $options['blog_featured_post_content_category'] ) ? $options['blog_featured_post_content_category'] : '';
                $args = array(
                    'post_type'         => 'post',
                    'posts_per_page'    => absint( $blog_featured_post_count ),
                    'cat'               => absint( $cat_id ),
                    'ignore_sticky_posts'   => true,
                    );                    
            break;

            default:
            break;
        }
            // Run The Loop.
            $query = new WP_Query( $args );
            if ( $query->have_posts() ) : 
                while ( $query->have_posts() ) : $query->the_post();
                    $page_post['id']        = get_the_id();
                    $page_post['title']     = get_the_title();
                    $page_post['url']       = get_the_permalink();
                    $page_post['image']     = has_post_thumbnail() ? get_the_post_thumbnail_url( get_the_id(), 'large' ) : get_template_directory_uri() . '/assets/uploads/no-featured-image-590x650.jpg';

                    // Push to the main array.
                    array_push( $content, $page_post );
                endwhile;
            endif;
            wp_reset_postdata();
            
        if ( ! empty( $content ) ) {
            $input = $content;
        }
        return $input;
    }
endif;
// featured_post section content details.
add_filter( 'travelism_pro_filter_blog_featured_post_section_details', 'travelism_pro_get_blog_featured_post_section_details' );


if ( ! function_exists( 'travelism_pro_render_blog_featured_post_section' ) ) :
  /**
   * Start featured_post section
   *
   * @return string featured_post content
   * @since Travelism Pro 1.0.0
   *
   */
   function travelism_pro_render_blog_featured_post_section( $content_details = array() ) {
        $options = travelism_pro_get_theme_options();

        if ( empty( $content_details ) ) {
            return;
        } ?>
        
         <div id="travelism_blog_featured_post_section" class="relative page-section">
                <div class="wrapper"> 
                <?php if ( is_customize_preview()):
                    travelism_pro_section_tooltip( 'travelism_blog_featured_post_section' );
                    endif; ?>
                    <div class="blog-section-content <?php echo esc_attr( $options['blog_featured_post_col_layout'] ); ?> clear">
                       
                       <?php foreach ($content_details as $content ): ?>

                        <article>
                            <div class="blog-featured-item" style="background-image: url('<?php echo esc_url( $content['image'] ); ?>');">
                                <header class="entry-header">
                                    <h2 class="entry-title"><a href="<?php echo esc_url( $content['url'] ); ?>"><?php echo esc_html( $content['title'] ); ?></a></h2>
                                </header>
                            </div><!-- .blog-featured-item -->
                        </article>
                           
                       <?php endforeach; ?>

                    </div><!-- .blog-section-content -->
                </div><!-- .wrapper -->
            </div><!-- #travelism_blog_featured_post_section -->
       
    <?php }
endif;