<?php
/**
 * Slider section
 *
 * This is the template for the content of slider section
 *
 * @package Theme Palace
 * @subpackage Travelism Pro
 * @since Travelism Pro 1.0.0
 */
if ( ! function_exists( 'travelism_pro_add_blog_slider_section' ) ) :
    /**
    * Add slider section
    *
    *@since Travelism Pro 1.0.0
    */
    function travelism_pro_add_blog_slider_section() {
    	$options = travelism_pro_get_theme_options();
        // Check if slider is enabled on frontpage
        $slider_enable = apply_filters( 'travelism_pro_section_status', true, 'blog_slider_section_enable' );

        if ( true !== $slider_enable ) {
            return false;
        }
        // Get slider section details
        $section_details = array();
        $section_details = apply_filters( 'travelism_pro_filter_blog_slider_section_details', $section_details );

        if ( empty( $section_details ) ) {
            return;
        }

        // Render slider section now.
        travelism_pro_render_blog_slider_section( $section_details );
    }
endif;

if ( ! function_exists( 'travelism_pro_get_blog_slider_section_details' ) ) :
    /**
    * slider section details.
    *
    * @since Travelism Pro 1.0.0
    * @param array $input slider section details.
    */
    function travelism_pro_get_blog_slider_section_details( $input ) {
        $options = travelism_pro_get_theme_options();

        // Content type.
        $blog_slider_content_type  = $options['blog_slider_content_type'];
        $blog_slider_count = ! empty( $options['blog_slider_count'] ) ? $options['blog_slider_count'] : 3;
        
        $content = array();
        switch ( $blog_slider_content_type ) {
        	
            case 'page':
                $page_ids = array();

                for ( $i = 1; $i <= $blog_slider_count; $i++ ) {
                    if ( ! empty( $options['blog_slider_content_page_' . $i] ) )
                        $page_ids[] = $options['blog_slider_content_page_' . $i];
                }
                
                $args = array(
                    'post_type'         => 'page',
                    'post__in'          => ( array ) $page_ids,
                    'posts_per_page'    => absint( $blog_slider_count ),
                    'orderby'           => 'post__in',
                    );                    
            break;

            case 'post':
                $post_ids = array();

                for ( $i = 1; $i <= $blog_slider_count; $i++ ) {
                    if ( ! empty( $options['blog_slider_content_post_' . $i] ) )
                        $post_ids[] = $options['blog_slider_content_post_' . $i];
                }
                $args = array(
                    'post_type'         => 'post',
                    'post__in'          => ( array ) $post_ids,
                    'posts_per_page'    => absint( $blog_slider_count ),
                    'orderby'           => 'post__in',
                    'ignore_sticky_posts'   => true,
                    );                    
            break;

            case 'category':
                $cat_id = ! empty( $options['blog_slider_content_category'] ) ? $options['blog_slider_content_category'] : '';
                $args = array(
                    'post_type'         => 'post',
                    'posts_per_page'    => absint( $blog_slider_count ),
                    'cat'               => absint( $cat_id ),
                    'ignore_sticky_posts'   => true,
                    );                    
            break;

            default:
            break;
        }
            // Run The Loop.
            $query = new WP_Query( $args );
            if ( $query->have_posts() ) : 
                while ( $query->have_posts() ) : $query->the_post();
                    $page_post['id']        = get_the_id();
                    $page_post['title']     = get_the_title();
                    $page_post['url']       = get_the_permalink();
                    $page_post['excerpt']   = travelism_pro_trim_content( $options['blog_slider_excerpt_length'] );
                    $page_post['image']     = has_post_thumbnail() ? get_the_post_thumbnail_url( get_the_id(), 'full' ) : get_template_directory_uri() . '/assets/uploads/no-featured-image-590x650.jpg';

                    // Push to the main array.
                    array_push( $content, $page_post );
                endwhile;
            endif;
            wp_reset_postdata();
            
        if ( ! empty( $content ) ) {
            $input = $content;
        }
        return $input;
    }
endif;
// slider section content details.
add_filter( 'travelism_pro_filter_blog_slider_section_details', 'travelism_pro_get_blog_slider_section_details' );


if ( ! function_exists( 'travelism_pro_render_blog_slider_section' ) ) :
  /**
   * Start slider section
   *
   * @return string slider content
   * @since Travelism Pro 1.0.0
   *
   */
   function travelism_pro_render_blog_slider_section( $content_details = array() ) {
        $options = travelism_pro_get_theme_options();
        $btn_label = ! empty( $options['blog_slider_btn_label'] ) ? $options['blog_slider_btn_label'] : '';
        $arrows = $options['blog_slider_arrow'] ? 'true' : 'false';
        $autoplay = $options['blog_slider_autoplay'] ? 'true' : 'false';

        if ( empty( $content_details ) ) {
            return;
        } ?>
        
         <div id="travelism_blog_slider_section" data-slick='{"slidesToShow": 1, "slidesToScroll": 1, "infinite": true, "speed": 1500, "dots": true, "arrows": <?php echo esc_attr( $arrows ); ?>, "autoplay": <?php echo esc_attr( $autoplay ); ?>, "draggable": true, "fade": false }'>

                
                <?php $i=1; foreach ($content_details as $content ): ?>

                    <article style="background-image: url('<?php echo esc_url( $content['image'] ); ?>');">
                    <div class="wrapper">

                    <?php if ( is_customize_preview()):
                    travelism_pro_section_tooltip( 'travelism_blog_slider_section' );
                    endif; ?>
                        <div class="blog-slider-content">

                        <?php if( !empty( $options['blog_slider_subtitle_'.$i] ) ): ?>
                            <h4 class="sub-title"><?php echo esc_html( $options['blog_slider_subtitle_'.$i] ); ?></h4>
                        <?php endif; ?>
                            <header class="entry-header">
                                <h2 class="entry-title"><a href="<?php echo esc_url( $content['url'] ); ?>"><?php echo esc_html( $content['title'] ); ?></a></h2>
                            </header>
                        <div class="entry-content">
                            <p><?php echo esc_html( $content['excerpt'] ); ?></p>
                        </div><!-- .entry-content -->

                        <?php if( !empty( $btn_label ) ): ?>
                        <div class="read-more">
                            <a href="<?php echo esc_url( $content['url'] ); ?>" class="btn btn-primary" tabindex="-1"><?php echo esc_html( $btn_label ); ?></a>
                        </div><!-- .read-more -->
                    <?php endif; ?>
                        </div><!-- .blog-slider-content -->
                    </div><!-- .wrapper -->
                </article>
                    
                <?php $i++; endforeach; ?>

            </div><!-- #travelism_blog_slider_section -->
       
    <?php }
endif;