<?php
/**
 * About section
 *
 * This is the template for the content of about section
 *
 * @package Theme Palace
 * @subpackage Travelism Pro
 * @since Travelism Pro 1.0.0
 */
if ( ! function_exists( 'travelism_pro_add_business_about_section' ) ) :
    /**
    * Add about section
    *
    *@since Travelism Pro 1.0.0
    */
    function travelism_pro_add_business_about_section() {
    	$options = travelism_pro_get_theme_options();
        // Check if about is enabled on frontpage
        $business_about_enable = apply_filters( 'travelism_pro_section_status', true, 'business_about_section_enable' );

        if ( true !== $business_about_enable ) {
            return false;
        }
        // Get about section details
        $section_details = array();
        $section_details = apply_filters( 'travelism_pro_filter_business_about_section_details', $section_details );

        if ( empty( $section_details ) ) {
            return;
        }

        // Render about section now.
        travelism_pro_render_business_about_section( $section_details );
    }
endif;

if ( ! function_exists( 'travelism_pro_get_business_about_section_details' ) ) :
    /**
    * about section details.
    *
    * @since Travelism Pro 1.0.0
    * @param array $input about section details.
    */
    function travelism_pro_get_business_about_section_details( $input ) {
        $options = travelism_pro_get_theme_options();

        // Content type.
        $business_about_content_type  = $options['business_about_content_type'];
        
        $content = array();
        switch ( $business_about_content_type ) {
        	
            case 'custom':
                $custom['title']        = ! empty( $options['business_about_title'] ) ? $options['business_about_title'] : '';
                $custom['excerpt']      = ! empty( $options['business_about_description'] ) ? $options['business_about_description'] : '';
                $custom['url']          = ! empty( $options['business_about_btn_link'] ) ? $options['business_about_btn_link'] : '';
                $custom['image']        = ! empty( $options['business_about_image'] ) ? $options['business_about_image'] : '';

                // Push to the main array.
                array_push( $content, $custom );
            break;

            case 'page':
                $page_id = ! empty( $options['business_about_content_page'] ) ? $options['business_about_content_page'] : '';
                $args = array(
                    'post_type'         => 'page',
                    'page_id'           => $page_id,
                    'posts_per_page'    => 1,
                    );                    
            break;

            case 'post':
                $post_id = ! empty( $options['business_about_content_post'] ) ? $options['business_about_content_post'] : '';
                $args = array(
                    'post_type'         => 'post',
                    'p'                 => $post_id,
                    'posts_per_page'    => 1,
                    );
            break;

            default:
            break;
        }

        if ( 'custom' !== $business_about_content_type ) :
            // Run The Loop.
            $query = new WP_Query( $args );
            if ( $query->have_posts() ) : 
                while ( $query->have_posts() ) : $query->the_post();
                    $page_post['id']        = get_the_id();
                    $page_post['title']     = get_the_title();
                    $page_post['excerpt']   = travelism_pro_trim_content( $options['business_about_excerpt_length'] );
                    $page_post['url']       = get_the_permalink();
                    $page_post['image']     = has_post_thumbnail() ? get_the_post_thumbnail_url( get_the_id(), 'large' ) : get_template_directory_uri() . '/assets/uploads/no-featured-image-590x650.jpg';

                    // Push to the main array.
                    array_push( $content, $page_post );
                endwhile;
            endif;
            wp_reset_postdata();
        endif;
            
        if ( ! empty( $content ) ) {
            $input = $content;
        }
        return $input;
    }
endif;
// about section content details.
add_filter( 'travelism_pro_filter_business_about_section_details', 'travelism_pro_get_business_about_section_details' );


if ( ! function_exists( 'travelism_pro_render_business_about_section' ) ) :
  /**
   * Start about section
   *
   * @return string about content
   * @since Travelism Pro 1.0.0
   *
   */
   function travelism_pro_render_business_about_section( $content_details = array() ) {
        $options = travelism_pro_get_theme_options();
        $subtitle = !empty( $options['business_about_sub_title'] ) ? $options['business_about_sub_title'] : '';
        $btn = !empty( $options['business_about_btn_title'] ) ? $options['business_about_btn_title'] : '';

        if ( empty( $content_details ) ) {
            return;
        } 

        foreach ( $content_details as $content ) : 
        ?>
            
    <div id="travelism_business_about_section" class="relative page-section">
        <div class="wrapper">

         <?php if ( is_customize_preview()):
                    travelism_pro_section_tooltip( 'travelism_business_about_section' );
                    endif; ?>
            <article class="has-post-thumbnail">
                <div class="featured-image"  style="background-image: url('<?php echo esc_url( $content['image'] ); ?>');">
                </div><!-- .featured-image -->

                <div class="entry-container">
                    <div class="section-header">
                        <?php if( !empty( $subtitle ) ): ?>
                            <p class="section-subtitle"><?php echo esc_html( $subtitle ); ?></p>
                        <?php endif;

                        if( !empty( $content['title'] ) && !empty( $content['url'] ) ): ?>
                            <h2 class="section-title"><a href="<?php echo esc_url( $content['url'] ); ?>"><?php echo esc_html( $content['title'] ); ?></a></h2>
                        <?php endif; ?>
                    </div><!-- .section-header -->

                    <?php if( !empty( $content['excerpt'] ) ): ?>
                        <div class="entry-content">
                            <p><?php echo esc_html( $content['excerpt'] ); ?></p>
                        </div><!-- .entry-content -->
                    <?php endif; ?>

                    <?php if( !empty( $btn ) && !empty( $content['url'] ) ): ?>
                        <div class="read-more">
                            <a href="<?php echo esc_url( $content['url'] ); ?>" class="btn"><?php echo esc_html( $btn ); ?></a>
                        </div><!-- .read-more -->
                    <?php endif; ?>
                </div><!-- .entry-container -->
            </article>
        </div><!-- .wrapper -->
    </div><!-- #travelism_business_about_section -->
            
        <?php endforeach;
    }
endif;

