<?php
/**
 * Counter section
 *
 * This is the template for the content of counter section
 *
 * @package Theme Palace
 * @subpackage Travelism Pro
 * @since Travelism Pro 1.0.0
 */
if ( ! function_exists( 'travelism_pro_add_business_counter_section' ) ) :
    /**
    * Add counter section
    *
    *@since Travelism Pro 1.0.0
    */
    function travelism_pro_add_business_counter_section() {
        $options = travelism_pro_get_theme_options();
        // Check if counter is enabled on frontpage
        $business_counter_enable = apply_filters( 'travelism_pro_section_status', true, 'business_counter_section_enable' );

        if ( true !== $business_counter_enable ) {
            return false;
        }

        // Render counter section now.
        travelism_pro_render_business_counter_section();
    }
endif;

if ( ! function_exists( 'travelism_pro_render_business_counter_section' ) ) :
  /**
   * Start counter section
   *
   * @return string counter content
   * @since Travelism Pro 1.0.0
   *
   */
   function travelism_pro_render_business_counter_section() {
        $options = travelism_pro_get_theme_options();
        $business_counter_column = ! empty( $options['business_counter_column'] ) ? $options['business_counter_column'] : 'col-4';
        $image = !empty( $options['business_counter_image'] ) ? $options['business_counter_image'] : '';
      
        ?>
        
        <div id="travelism_business_counter_section" class="relative page-section" style="background-image: url('<?php echo esc_url( $image ); ?>');">
          <div class="overlay"></div>
          <div class="wrapper">
           <?php if ( is_customize_preview()):
                    travelism_pro_section_tooltip( 'travelism_business_counter_section' );
                    endif; ?>
            <div class="section-content <?php echo esc_attr( $business_counter_column ); ?> clear">

              <?php for( $i=1; $i<= $options['business_counter_count']; $i++ ) { 
                $icon    = isset($options['business_counter_icon_'.$i]) ? $options['business_counter_icon_'.$i] : 'fa-trophy';
                ?>     

                <article>
                  <div class="counter-item">

                    <?php if (!empty( $icon )): ?>

                      <div class="counter-icon">
                        <i class="fa <?php echo esc_attr( $icon ); ?>"></i>
                      </div>

                    <?php endif ?>

                    <?php if( !empty( $options['business_counter_value_' . $i] ) && !empty( $options['business_counter_label_' . $i] ) ): ?>

                      <h2 class="counter-value"><?php echo esc_html( $options['business_counter_value_' . $i] ); ?></h2>
                      <h3 class="counter-title"><?php echo esc_html( $options['business_counter_label_' . $i] ); ?></h3>

                    <?php endif; ?>

                  </div><!-- .counter-item -->
                </article>

                <?php } ?>

              </div><!-- .section-content -->
            </div><!-- .wrapper -->
          </div><!-- #travelism_business_counter_section -->
        
    <?php }
endif;