<?php
/**
 * Business Section section
 *
 * This is the template for the content of business_service section
 *
 * @package Theme Palace
 * @subpackage Travelism Pro
 * @since Travelism Pro 1.0.0
 */
if ( ! function_exists( 'travelism_pro_add_business_service_section' ) ) :
    /**
    * Add business_service section
    *
    *@since Travelism Pro 1.0.0
    */
    function travelism_pro_add_business_service_section() {
        $options = travelism_pro_get_theme_options();
        // Check if business_service is enabled on frontpage
        $business_service_enable = apply_filters( 'travelism_pro_section_status', true, 'business_service_section_enable' );

        if ( true !== $business_service_enable ) {
            return false;
        }
        // Get business_service section details
        $section_details = array();
        $section_details = apply_filters( 'travelism_pro_filter_business_service_section_details', $section_details );

        if ( empty( $section_details ) ) {
            return;
        }

        // Render business_service section now.
        travelism_pro_render_business_service_section( $section_details );
    }
endif;

if ( ! function_exists( 'travelism_pro_get_business_service_section_details' ) ) :
    /**
    * business_service section details.
    *
    * @since Travelism Pro 1.0.0
    * @param array $input business_service section details.
    */
    function travelism_pro_get_business_service_section_details( $input ) {
        $options = travelism_pro_get_theme_options();

        // Content type.
        $business_service_content_type  = $options['business_service_content_type'];
        $business_service_count = ! empty( $options['business_service_count'] ) ? $options['business_service_count'] : 3;
        $content = array();
        switch ( $business_service_content_type ) {
            
            case 'page':
                $page_ids = array();
                $author = array();

                for ( $i = 1; $i <= $business_service_count; $i++ ) {
                    if ( ! empty( $options['business_service_content_page_' . $i] ) ) :
                        $page_ids[] = $options['business_service_content_page_' . $i];
                    endif;
                }
                
                $args = array(
                    'post_type'         => 'page',
                    'post__in'          => ( array ) $page_ids,
                    'posts_per_page'    => absint( $business_service_count ),
                    'orderby'           => 'post__in',
                    );                    
            break;

            case 'post':
                $post_ids = array();
                $author = array();

                for ( $i = 1; $i <= $business_service_count; $i++ ) {
                    if ( ! empty( $options['business_service_content_post_' . $i] ) ) :
                        $post_ids[] = $options['business_service_content_post_' . $i];
                    endif;
                }
                
                $args = array(
                    'post_type'         => 'post',
                    'post__in'          => ( array ) $post_ids,
                    'posts_per_page'    => absint( $business_service_count ),
                    'orderby'           => 'post__in',
                    'ignore_sticky_posts'   => true,
                    );                    
            break;

            case 'category':
                $cat_id = ! empty( $options['business_service_content_category'] ) ? $options['business_service_content_category'] : '';
                $args = array(
                    'post_type'         => 'post',
                    'posts_per_page'    => absint( $business_service_count ),
                    'cat'               => absint( $cat_id ),
                    'ignore_sticky_posts'   => true,
                    );                    
            break;
            
            default:
            break;
        }

        // Run The Loop.
        $query = new WP_Query( $args );
        if ( $query->have_posts() ) : 
            while ( $query->have_posts() ) : $query->the_post();
                $page_post['id']        = get_the_id();
                $page_post['title']     = get_the_title();
                $page_post['url']       = get_the_permalink();
                $page_post['excerpt']   = travelism_pro_trim_content( $options['business_service_excerpt_length'] );
                $page_post['image']     = has_post_thumbnail() ? get_the_post_thumbnail_url( get_the_id(), 'large' ) : get_template_directory_uri() . '/assets/uploads/no-featured-image-590x650.jpg';

                // Push to the main array.
                array_push( $content, $page_post );
            endwhile;
        endif;
        wp_reset_postdata();
   
            
        if ( ! empty( $content ) ) {
            $input = $content;
        }
        return $input;
    }
endif;
// business_service section content details.
add_filter( 'travelism_pro_filter_business_service_section_details', 'travelism_pro_get_business_service_section_details' );


if ( ! function_exists( 'travelism_pro_render_business_service_section' ) ) :
  /**
   * Start business_service section
   *
   * @return string business_service content
   * @since Travelism Pro 1.0.0
   *
   */
   function travelism_pro_render_business_service_section( $content_details = array() ) {
        $options = travelism_pro_get_theme_options();

        $business_service_sub_title = !empty( $options['business_service_sub_title'] ) ? $options['business_service_sub_title'] : '';
        $business_service_title = !empty( $options['business_service_title'] ) ? $options['business_service_title'] : '';
        $btn = !empty( $options['business_service_btn'] ) ? $options['business_service_btn'] : '';

        if ( empty( $content_details ) ) {
            return;
        } ?>
       
       <div id="travelism_business_service_section" class="relative page-section">
                <div class="wrapper">
                 <?php if ( is_customize_preview()):
                    travelism_pro_section_tooltip( 'travelism_business_service_section' );
                    endif; ?>
                    <div class="section-header">
                    <?php if( !empty( $business_service_sub_title ) ): ?>
                        <p class="section-subtitle"><?php echo esc_html( $business_service_sub_title ); ?></p>
                    <?php endif;

                    if( !empty( $business_service_title ) ): ?>
                        <h2 class="section-title"><?php echo esc_html( $business_service_title ); ?></h2>
                    <?php endif; ?>
                    </div><!-- .section-header -->

                    <div class="section-content col-3 clear">
                        
                        <?php foreach ($content_details as $content ): ?>

                        <article>
                            <div class="service-item">
                                <div class="entry-container">

                                    <div class="featured-image">
                                        <a href="<?php echo esc_url( $content['url'] ); ?>"><img src="<?php echo esc_url( $content['image'] ); ?>" alt="service-image"></a>
                                    </div><!-- .featured-image -->

                                    <header class="entry-header">
                                        <h2 class="entry-title"><a href="<?php echo esc_url( $content['url'] ); ?>"><?php echo esc_html( $content['title'] ); ?></a></h2>
                                    </header>

                                    <div class="entry-content">
                                        <p><?php echo esc_html( $content['excerpt'] ); ?></p>
                                    </div><!-- .entry-content -->

                                    <?php if( !empty( $btn ) ): ?>
                                    <div class="read-more">
                                        <a href="<?php echo esc_url( $content['url'] ); ?>"><i class="fa fa-plus"></i><?php echo esc_html( $btn ); ?></a>
                                    </div><!-- .read-more -->
                                <?php endif; ?>
                                </div><!-- .entry-container -->
                            </div><!-- .service-item -->
                        </article>
                            
                        <?php endforeach; ?>
                       
                    </div><!-- .col-3 -->
                </div><!-- .wrapper -->
            </div><!-- #travelism_business_servic_section -->

    <?php }
endif;