<?php
/**
 * team section
 *
 * This is the template for the content of team section
 *
 * @team Theme Palace
 * @subteam Travelism Pro
 * @since Travelism Pro 1.0.0
 */
if ( ! function_exists( 'travelism_pro_add_business_team_section' ) ) :
    /**
    * Add team section
    *
    *@since Travelism Pro 1.0.0
    */
    function travelism_pro_add_business_team_section() {
        $options = travelism_pro_get_theme_options();
        // Check if team is enabled on frontpage
        $business_team_enable = apply_filters( 'travelism_pro_section_status', true, 'business_team_section_enable' );

        if ( true !== $business_team_enable ) {
            return false;
        }
        // Get team section details
        $section_details = array();
        $section_details = apply_filters( 'travelism_pro_filter_business_team_section_details', $section_details );

        if ( empty( $section_details ) ) {
            return;
        }

        // Render team section now.
        travelism_pro_render_business_team_section( $section_details );
    }
endif;

if ( ! function_exists( 'travelism_pro_get_business_team_section_details' ) ) :
    /**
    * team section details.
    *
    * @since Travelism Pro 1.0.0
    * @param array $input team section details.
    */
    function travelism_pro_get_business_team_section_details( $input ) {
        $options = travelism_pro_get_theme_options();

        // Content type.
        $business_team_content_type  = $options['business_team_content_type'];
        $business_team_count  = ! empty( $options['business_team_count'] ) ? $options['business_team_count'] : 3;
        
        $content = array();
        switch ( $business_team_content_type ) {
            
            case 'page':
                $page_ids = array();

                for ( $i = 1; $i <= $business_team_count; $i++ ) {
                    if ( ! empty( $options['business_team_content_page_' . $i] ) )
                        $page_ids[] = $options['business_team_content_page_' . $i];
                }
                
                $args = array(
                    'post_type'         => 'page',
                    'post__in'          => ( array ) $page_ids,
                    'posts_per_page'    => $business_team_count,
                    'orderby'           => 'post__in',
                    );                    
            break;

            case 'post':
                $post_ids = array();

                for ( $i = 1; $i <= $business_team_count; $i++ ) {
                    if ( ! empty( $options['business_team_content_post_' . $i] ) )
                        $post_ids[] = $options['business_team_content_post_' . $i];
                }
                
                $args = array(
                    'post_type'         => 'post',
                    'post__in'          => ( array ) $post_ids,
                    'posts_per_page'    => $business_team_count,
                    'orderby'           => 'post__in',
                    'ignore_sticky_posts'   => true,
                    );                    
            break;

            case 'category':
                $cat_id = ! empty( $options['business_team_content_category'] ) ? $options['business_team_content_category'] : '';
                $args = array(
                    'post_type'         => 'post',
                    'posts_per_page'    => $business_team_count,
                    'cat'               => absint( $cat_id ),
                    'ignore_sticky_posts'   => true,
                    );                    
            break;

            default:
            break;
        }


            // Run The Loop.
            $query = new WP_Query( $args );
            if ( $query->have_posts() ) : 
                while ( $query->have_posts() ) : $query->the_post();
                    $page_post['title']     = get_the_title();
                    $page_post['url']       = get_the_permalink();
                    $page_post['image']     = has_post_thumbnail() ? get_the_post_thumbnail_url( get_the_id(), 'large' ) : get_template_directory_uri() . '/assets/uploads/no-featured-image-590x650.jpg';

                    // Push to the main array.
                    array_push( $content, $page_post );
                endwhile;
            endif;
            wp_reset_postdata();

            
        if ( ! empty( $content ) ) {
            $input = $content;
        }
        return $input;
    }
endif;
// team section content details.
add_filter( 'travelism_pro_filter_business_team_section_details', 'travelism_pro_get_business_team_section_details' );


if ( ! function_exists( 'travelism_pro_render_business_team_section' ) ) :
  /**
   * Start team section
   *
   * @return string team content
   * @since Travelism Pro 1.0.0
   *
   */
   function travelism_pro_render_business_team_section( $content_details = array() ) {
        $options = travelism_pro_get_theme_options();  

        $titles = !empty( $options['business_team_title'] ) ? $options['business_team_title'] : ''; 
        $sub_titles = !empty( $options['business_team_sub_title'] ) ? $options['business_team_sub_title'] : ''; 

        if ( empty( $content_details ) ) {
            return;
        } 
        ?> 
        
        <div id="travelism_business_team_section" class="relative page-section same-background">
            <div class="wrapper">
            <?php if ( is_customize_preview()):
                    travelism_pro_section_tooltip( 'travelism_business_team_section' );
                    endif; ?>
                <div class="section-header">
                <?php if( !empty( $sub_titles ) ): ?>
                    <p class="section-subtitle"><?php echo esc_html( $sub_titles ); ?></p>
                <?php endif;

                if( !empty( $titles ) ): ?>
                <h2 class="section-title"><?php echo esc_html( $titles ); ?></h2>
            <?php endif; ?>
        </div><!-- .section-header -->

        <div class="section-content col-<?php echo esc_attr( $options['business_team_column'] ); ?> clear">

            <?php $i=1; foreach ($content_details as $content ): ?>

            <article>
                <div class="team-item-wrapper">
                    <div class="featured-image">
                        <a href="<?php echo esc_url( $content['url'] ); ?>"><img src="<?php echo esc_url( $content['image'] ); ?>" alt="team"></a>
                    </div><!-- .featured-image -->

                    <div class="entry-container">
                        <header class="entry-header">
                            <h2 class="entry-title"><a href="<?php echo esc_url( $content['url'] ); ?>"><?php echo esc_html( $content['title'] ); ?></a></h2>
                            <?php if( !empty( $options['business_team_position_'.$i] ) ): ?>
                                <span class="team-position"><?php echo esc_html( $options['business_team_position_'.$i] ) ?></span>
                            <?php endif; ?>
                        </header>

                        <div class="social-icons">
                            <ul>
                                <?php 
                                $business_team_socials = ! empty( $options['business_team_social_' . $i ] ) ? explode( '|', $options['business_team_social_' . $i ] ) : array(); 

                                foreach ( $business_team_socials as $business_team_social ) : ?>
                                <li>
                                    <a href="<?php echo esc_url( $business_team_social ); ?>"><?php echo travelism_pro_return_social_icon( $business_team_social ); ?></a>
                                </li>
                            <?php endforeach; ?>
                        </ul>
                    </div><!-- .social-icons -->
                </div><!-- .entry-container -->
            </div><!-- team-item-wrapper -->
        </article>

        <?php $i++; endforeach; ?>

    </div><!-- .col-3 -->
</div><!-- .wrapper -->
</div><!-- #travelism_business_team_section -->
            
    <?php }
endif;