<?php
/**
 * Most Read section
 *
 * This is the template for the content of most_read_post section
 *
 * @package Theme Palace
 * @subpackage Travelism Pro
 * @since Travelism Pro 1.0.0
 */
if ( ! function_exists( 'travelism_pro_add_most_read_post_section' ) ) :
    /**
    * Add most_read_post section
    *
    *@since Travelism Pro 1.0.0
    */
    function travelism_pro_add_most_read_post_section() {
        $options = travelism_pro_get_theme_options();
        // Check if most_read_post is enabled on frontpage
        $most_read_post_enable = apply_filters( 'travelism_pro_section_status', true, 'most_read_post_section_enable' );

        if ( true !== $most_read_post_enable ) {
            return false;
        }
        // Get most_read_post section details
        $section_details = array();
        $section_details = apply_filters( 'travelism_pro_filter_most_read_post_section_details', $section_details );

        if ( empty( $section_details ) ) {
            return;
        }

        // Render most_read_post section now.
        travelism_pro_render_most_read_post_section( $section_details );
    }
endif;

if ( ! function_exists( 'travelism_pro_get_most_read_post_section_details' ) ) :
    /**
    * most_read_post section details.
    *
    * @since Travelism Pro 1.0.0
    * @param array $input most_read_post section details.
    */
    function travelism_pro_get_most_read_post_section_details( $input ) {
        $options = travelism_pro_get_theme_options();

        // Content type.
        $most_read_post_content_type  = $options['most_read_post_content_type'];
        $most_read_post_count = ! empty( $options['most_read_post_count'] ) ? $options['most_read_post_count'] : 4;
        $content = array();
        switch ( $most_read_post_content_type ) {
            
            case 'page':
                $page_ids = array();
                $author = array();

                for ( $i = 1; $i <= $most_read_post_count; $i++ ) {
                    if ( ! empty( $options['most_read_post_content_page_' . $i] ) ) :
                        $page_ids[] = $options['most_read_post_content_page_' . $i];
                    endif;
                }
                
                $args = array(
                    'post_type'         => 'page',
                    'post__in'          => ( array ) $page_ids,
                    'posts_per_page'    => absint( $most_read_post_count ),
                    'orderby'           => 'post__in',
                    );                    
            break;

            case 'post':
                $post_ids = array();
                $author = array();

                for ( $i = 1; $i <= $most_read_post_count; $i++ ) {
                    if ( ! empty( $options['most_read_post_content_post_' . $i] ) ) :
                        $post_ids[] = $options['most_read_post_content_post_' . $i];
                    endif;
                }
                
                $args = array(
                    'post_type'         => 'post',
                    'post__in'          => ( array ) $post_ids,
                    'posts_per_page'    => absint( $most_read_post_count ),
                    'orderby'           => 'post__in',
                    'ignore_sticky_posts'   => true,
                    );                    
            break;

            case 'category':
                $cat_id = ! empty( $options['most_read_post_content_category'] ) ? $options['most_read_post_content_category'] : '';
                $args = array(
                    'post_type'         => 'post',
                    'posts_per_page'    => absint( $most_read_post_count ),
                    'cat'               => absint( $cat_id ),
                    'ignore_sticky_posts'   => true,
                    );                    
            break;
            
            default:
            break;
        }

        // Run The Loop.
        $query = new WP_Query( $args );
        if ( $query->have_posts() ) : 
            while ( $query->have_posts() ) : $query->the_post();
                $page_post['id']        = get_the_id();
                $page_post['author_id'] = get_post_field('post_author', get_the_ID());
                $page_post['title']     = get_the_title();
                $page_post['url']       = get_the_permalink();
                $page_post['excerpt']   = get_the_content();
                $page_post['image']     = has_post_thumbnail() ? get_the_post_thumbnail_url( get_the_id(), 'large' ) : get_template_directory_uri() . '/assets/uploads/no-featured-image-590x650.jpg';

                // Push to the main array.
                array_push( $content, $page_post );
            endwhile;
        endif;
        wp_reset_postdata();
   
            
        if ( ! empty( $content ) ) {
            $input = $content;
        }
        return $input;
    }
endif;
// most_read_post section content details.
add_filter( 'travelism_pro_filter_most_read_post_section_details', 'travelism_pro_get_most_read_post_section_details' );


if ( ! function_exists( 'travelism_pro_render_most_read_post_section' ) ) :
  /**
   * Start most_read_post section
   *
   * @return string most_read_post content
   * @since Travelism Pro 1.0.0
   *
   */
   function travelism_pro_render_most_read_post_section( $content_details = array() ) {
        $options = travelism_pro_get_theme_options();

        $most_read_post_title = !empty( $options['most_read_post_title'] ) ? $options['most_read_post_title'] : '';

        if ( empty( $content_details ) ) {
            return;
        } ?>
       
        <div id="travelism_most_read_post_section" class="relative page-section same-background">
                <div class="wrapper">
                 <?php if ( is_customize_preview()):
                    travelism_pro_section_tooltip( 'travelism_most_read_post_section' );
                    endif; ?>
                <?php if( !empty( $most_read_post_title ) ): ?>
                    <div class="section-header">
                        <h2 class="section-title"><?php echo esc_html( $most_read_post_title ); ?></h2>
                    </div><!-- .section-header -->
                <?php endif; ?>

                    <div class="section-content col-4 clear">
                        
                    <?php foreach ($content_details as $content ): ?>

                        <article>
                            <div class="most-read-post-wrapper">
                                <div class="featured-image" style="background-image: url('<?php echo esc_url( $content['image'] ); ?>');">
                                    <a href="<?php echo esc_url( $content['url'] ); ?>" class="post-thumbnail-link"></a>
                                </div><!-- .featured-image -->

                                <div class="entry-container">
                                    <span class="cat-links">
                                        <?php the_category( '', '', $content['id'] ); ?>
                                    </span><!-- .cat-links -->

                                    <header class="entry-header">
                                        <h2 class="entry-title"><a href="<?php echo esc_url( $content['url'] ); ?>"><?php echo esc_html( $content['title'] ); ?></a></h2>
                                    </header>

                                    <div class="admin-profile">
                                        <div class="admin-image">
                                            <a href="<?php echo esc_url( get_author_posts_url( $content['author_id']) ); ?>"><img src="<?php echo get_avatar_url($content['author_id'], ['size' => '70']); ?>" alt="admin"></a>
                                        </div><!-- .admin-image -->

                                        <div class="admin-container">
                                            <div class="admin-header">
                                                <h2 class="admin-name"><a href="<?php echo esc_url( get_author_posts_url( $content['author_id']) ); ?>"><?php echo get_the_author_meta('display_name', $content['author_id']); ?></a></h2>
                                            </div><!-- .admin-header -->

                                            <div class="entry-meta">
                                                <span class="posted-on">

                                                <time class="entry-date published updated" datetime="2018-04-06T11:33:16+00:00"><?php echo esc_html( get_the_date( 'M m', $content['id'] ) ); ?></time>
                                                </span><!-- .posted-on -->
                                                <span class="reading-time"><?php echo travelism_pro_time_interval( $content['excerpt'] ); echo esc_html__(' min to read', 'travelism-pro'); ?></span>
                                            </div><!-- .entry-meta -->
                                        </div><!-- .entry-container -->
                                    </div><!-- .admin-profile -->
                                </div><!-- .entry-container -->
                            </div><!-- .most-read-post-wrapper -->
                        </article>
                        
                    <?php endforeach; ?>

                    </div><!-- .section-content -->
                </div><!-- .wrapper -->
            </div><!-- #travelism_most_read_post_section -->

    <?php }
endif;