<?php
/**
 * Recent Post section
 *
 * This is the template for the content of recent_post section
 *
 * @package Theme Palace
 * @subpackage Travelism Pro
 * @since Travelism Pro 1.0.0
 */
if ( ! function_exists( 'travelism_pro_add_recent_post_section' ) ) :
    /**
    * Add recent_post section
    *
    *@since Travelism Pro 1.0.0
    */
    function travelism_pro_add_recent_post_section() {
        $options = travelism_pro_get_theme_options();
        // Check if recent_post is enabled on frontpage
        $recent_post_enable = apply_filters( 'travelism_pro_section_status', true, 'recent_post_section_enable' );

        if ( true !== $recent_post_enable ) {
            return false;
        }
        // Get recent_post section details
        $section_details = array();
        $section_details = apply_filters( 'travelism_pro_filter_recent_post_section_details', $section_details );

        if ( empty( $section_details ) ) {
            return;
        }

        // Render recent_post section now.
        travelism_pro_render_recent_post_section( $section_details );
    }
endif;

if ( ! function_exists( 'travelism_pro_get_recent_post_section_details' ) ) :
    /**
    * recent_post section details.
    *
    * @since Travelism Pro 1.0.0
    * @param array $input recent_post section details.
    */
    function travelism_pro_get_recent_post_section_details( $input ) {
        $options = travelism_pro_get_theme_options();

        // Content type.
        $recent_post_content_type  = $options['recent_post_content_type'];
        $recent_post_count = ! empty( $options['recent_post_count'] ) ? $options['recent_post_count'] : 3;
        $content = array();
        switch ( $recent_post_content_type ) {
            
            case 'page':
                $page_ids = array();
                $author = array();

                for ( $i = 1; $i <= $recent_post_count; $i++ ) {
                    if ( ! empty( $options['recent_post_content_page_' . $i] ) ) :
                        $page_ids[] = $options['recent_post_content_page_' . $i];
                    endif;
                }
                
                $args = array(
                    'post_type'         => 'page',
                    'post__in'          => ( array ) $page_ids,
                    'posts_per_page'    => absint( $recent_post_count ),
                    'orderby'           => 'post__in',
                    );                    
            break;

            case 'post':
                $post_ids = array();
                $author = array();

                for ( $i = 1; $i <= $recent_post_count; $i++ ) {
                    if ( ! empty( $options['recent_post_content_post_' . $i] ) ) :
                        $post_ids[] = $options['recent_post_content_post_' . $i];
                    endif;
                }
                
                $args = array(
                    'post_type'         => 'post',
                    'post__in'          => ( array ) $post_ids,
                    'posts_per_page'    => absint( $recent_post_count ),
                    'orderby'           => 'post__in',
                    'ignore_sticky_posts'   => true,
                    );                    
            break;

            case 'category':
                $cat_id = ! empty( $options['recent_post_content_category'] ) ? $options['recent_post_content_category'] : '';
                $args = array(
                    'post_type'         => 'post',
                    'posts_per_page'    => absint( $recent_post_count ),
                    'cat'               => absint( $cat_id ),
                    'ignore_sticky_posts'   => true,
                    );                    
            break;
            
            default:
            break;
        }

        // Run The Loop.
        $query = new WP_Query( $args );
        if ( $query->have_posts() ) : 
            while ( $query->have_posts() ) : $query->the_post();
                $page_post['id']        = get_the_id();
                $page_post['title']     = get_the_title();
                $page_post['url']       = get_the_permalink();
                $page_post['excerpt']   = travelism_pro_trim_content( $options['recent_post_excerpt_length'] );
                $page_post['image']     = has_post_thumbnail() ? get_the_post_thumbnail_url( get_the_id(), 'large' ) : get_template_directory_uri() . '/assets/uploads/no-featured-image-590x650.jpg';

                // Push to the main array.
                array_push( $content, $page_post );
            endwhile;
        endif;
        wp_reset_postdata();
   
            
        if ( ! empty( $content ) ) {
            $input = $content;
        }
        return $input;
    }
endif;
// recent_post section content details.
add_filter( 'travelism_pro_filter_recent_post_section_details', 'travelism_pro_get_recent_post_section_details' );


if ( ! function_exists( 'travelism_pro_render_recent_post_section' ) ) :
  /**
   * Start recent_post section
   *
   * @return string recent_post content
   * @since Travelism Pro 1.0.0
   *
   */
   function travelism_pro_render_recent_post_section( $content_details = array() ) {
        $options = travelism_pro_get_theme_options();

        $recent_post_title = !empty( $options['recent_post_title'] ) ? $options['recent_post_title'] : '';
        $btn = !empty( $options['recent_post_btn'] ) ? $options['recent_post_btn'] : '';

        if ( empty( $content_details ) ) {
            return;
        } ?>
       
        <div id="travelism_recent_post_section" class="relative page-section same-background">
                <div class="wrapper">
                <?php if ( is_customize_preview()):
                    travelism_pro_section_tooltip( 'travelism_recent_post_section' );
                    endif; ?>
                <?php if( !empty( $recent_post_title ) ): ?>
                    <div class="section-header">
                        <h2 class="section-title"><?php echo esc_html( $recent_post_title ); ?></h2>
                    </div><!-- .section-header -->
                <?php endif; ?>

                    <div class="col-3 clear">

                    <?php foreach ($content_details as $content ): ?>

                        <article>
                            <div class="recent-post-item">
                                <div class="blog-featured-image">
                                    <a href="<?php echo esc_url( $content['url'] ); ?>"><img src="<?php echo esc_url( $content['image'] ); ?>"></a>
                                </div><!-- .blog-featured-image -->

                                <div class="entry-container">
                                    <span class="cat-links">
                                        <?php the_category( '', '', $content['id'] ); ?>                 
                                    </span><!-- .cat-links -->

                                    <header class="entry-header">
                                        <h2 class="entry-title"><a href="<?php echo esc_url( $content['url'] ); ?>"><?php echo esc_html( $content['title'] ); ?></a></h2>
                                    </header>

                                     <?php travelism_pro_posted_on( $content['id'] ); ?>

                                    <div class="entry-content">
                                       <p><?php echo esc_html( $content['excerpt'] ); ?></p>
                                    </div>

                                    <?php if( !empty( $btn ) ): ?>

                                    <div class="read-more">
                                        <a href="<?php echo esc_url( $content['url'] ); ?>" class="btn"><?php echo esc_html( $btn ); ?></a>
                                    </div>

                                <?php endif; ?>
                                
                                </div><!-- .entry-container -->
                            </div><!-- .recent-post-item -->
                        </article>
                        
                    <?php endforeach; ?>
                           
                    </div><!-- .blog-section-content -->
                </div><!-- .wrapper -->
            </div><!-- #travelism_recent_post_section -->

    <?php }
endif;