<?php
/**
 * shop_recent_products section
 *
 * This is the template for the content of shop_recent_products section
 *
 * @package Theme Palace
 * @subpackage Travelism Pro
 * @since Travelism Pro 1.0.0
 */
if ( ! function_exists( 'travelism_pro_add_shop_recent_products_section' ) ) :
    /**
    * Add shop_recent_products section
    *
    *@since Travelism Pro 1.0.0
    */
    function travelism_pro_add_shop_recent_products_section() {
        $options = travelism_pro_get_theme_options();
        // Check if shop_recent_products is enabled on frontpage
        $shop_recent_products_enable = apply_filters( 'travelism_pro_section_status', true, 'shop_recent_products_section_enable' );

        if ( ( true !== $shop_recent_products_enable ) || ! class_exists( 'WooCommerce' ) ) {
            return false;
        }
        // Get shop_recent_products section details
        $section_details = array();
        $section_details = apply_filters( 'travelism_pro_filter_shop_recent_products_section_details', $section_details );

        if ( empty( $section_details ) ) {
            return;
        }

        // Render shop_recent_products section now.
        travelism_pro_render_shop_recent_products_section( $section_details );
    }
endif;

if ( ! function_exists( 'travelism_pro_get_shop_recent_products_section_details' ) ) :
    /**
    * shop_recent_products section details.
    *
    * @since Travelism Pro 1.0.0
    * @param array $input shop_recent_products section details.
    */
    function travelism_pro_get_shop_recent_products_section_details( $input ) {
        $options = travelism_pro_get_theme_options();

        // Content type.
        $shop_recent_products_content_type  = $options['shop_recent_products_content_type'];     
        $shop_recent_products_count = ! empty( $options['shop_recent_products_count'] ) ? $options['shop_recent_products_count'] : 4;
        
        $content = array();
        $content = array();
        switch ( $shop_recent_products_content_type ) {

            case 'product':
                $page_ids = array();

                for ( $i = 1; $i <= $shop_recent_products_count; $i++ ) {
                    if ( ! empty( $options['shop_recent_products_content_page_' . $i] ) )
                        $page_ids[] = $options['shop_recent_products_content_page_' . $i];
                }

                $args = array(
                    'post_type'         => 'product',
                    'post__in'          => ( array ) $page_ids,
                    'posts_per_page'    => absint( $shop_recent_products_count ),
                    'orderby'           => 'post__in',
                    );
            break;
            case 'product-category':
                $cat_id = ! empty( $options['shop_recent_products_category'] ) ? $options['shop_recent_products_category'] : '';

                $args = array(
                'post_type'         => 'product',
                'posts_per_page'    => absint( $shop_recent_products_count ),
                'tax_query'         => array(
                    array(
                        'taxonomy'  => 'product_cat',
                        'field'     => 'id',
                        'terms'     => $cat_id
                    )
                ) );
            break;

            default:
            break;
        }


        // Run The Loop.
        $query = new WP_Query( $args );
        if ( $query->have_posts() ) : 
            while ( $query->have_posts() ) : $query->the_post();
                $page_post['id']        = get_the_id();
                $page_post['title']     = get_the_title();
                $page_post['url']       = get_the_permalink();
                $page_post['image']     = has_post_thumbnail() ? get_the_post_thumbnail_url( get_the_id(), 'large' ) : get_template_directory_uri() . '/assets/uploads/no-featured-image-590x650.jpg';

                // Push to the main array.
                array_push( $content, $page_post );
            endwhile;
        endif;
        wp_reset_postdata();

        
    
        if ( ! empty( $content ) ) {
            $input = $content;
        }
        return $input;
    }
endif;
// shop_recent_products section content details.
add_filter( 'travelism_pro_filter_shop_recent_products_section_details', 'travelism_pro_get_shop_recent_products_section_details' );


if ( ! function_exists( 'travelism_pro_render_shop_recent_products_section' ) ) :
  /**
   * Start shop_recent_products section
   *
   * @return string shop_recent_products content
   * @since Travelism Pro 1.0.0
   *
   */
   function travelism_pro_render_shop_recent_products_section( $content_details = array() ) {
        $options = travelism_pro_get_theme_options();

        $sub_titles = !empty( $options['shop_recent_products_sub_title'] ) ? $options['shop_recent_products_sub_title'] : '';
        $titles = !empty( $options['shop_recent_products_title'] ) ? $options['shop_recent_products_title'] : '';

        if ( empty( $content_details ) ) {
            return;
        } ?>
        
        <div id="travelism_shop_recent_products_section" class="relative page-section no-padding-top">
            <div class="wrapper">
            <?php if ( is_customize_preview()):
                    travelism_pro_section_tooltip( 'travelism_shop_recent_products_section' );
                    endif; ?>
                <div class="section-header">
                <?php if( !empty( $sub_titles ) ): ?>
                    <p class="section-subtitle"><?php echo esc_html( $sub_titles ); ?></p>
                <?php endif;

                if( !empty( $titles ) ): ?>
                <h2 class="section-title"><?php echo esc_html( $titles ); ?></h2>
            <?php endif; ?>
        </div><!-- .section-header -->

        <div class="section-content">
            <ul class="products col-4">

                <?php foreach ( $content_details as $content ): 
                $image = $content['image'] == '' ? get_template_directory_uri().'/assets/uploads/no-featured-image-590x650.jpg' : $content['image'] ;
                ?>

                <li class="product">
                    <a href="<?php echo esc_url( $content['url'] ) ; ?>" class="woocommerce-LoopProduct-link woocommerce-loop-product__link">

                        <?php 
                        $product = new WC_Product( $content['id'] );
                        if ( $product->get_sale_price() ): 
                            ?>

                        <span class="onsale">
                            <?php esc_html_e('Sale!', 'travelism-pro'); ?>
                        </span>
                    <?php endif; ?>

                    <img width="330" height="400" src="<?php echo esc_url($image); ?>">
                </a>
                <div class="product_meta">

                    <?php 
                    $terms = get_the_terms ( $content['id'], 'product_cat' );
                    foreach ( $terms as $term ) { ?>
                    <span class="posted_in">
                        <a href="<?php echo esc_url( get_term_link( $term->term_id, 'product_cat' ) ) ?>"><?php echo esc_html( $term->name) ; ?></a>
                    </span><!-- .posted_in -->
                    <?php } ?>

                </div><!-- .product-meta -->
                <h2 class="woocommerce-loop-product__title">
                    <?php echo esc_html( $content['title'] ); ?>
                </h2>
                <span class="price">
                    <?php 
                    $product = new WC_Product( $content['id'] );
                    echo $product->get_price_html();
                    ?> 
                </span>

                <a href="<?php echo do_shortcode( '[add_to_cart_url id="' . absint( $content['id'] ) . '"]' ); ?>" class="button product_type_simple add_to_cart_button ajax_add_to_cart"><?php esc_html_e('Add to cart', 'travelism-pro'); ?></a>
            </li>

        <?php endforeach; ?>

    </ul><!-- .product-slider -->
</div><!-- .section-content -->

</div><!-- .wrapper -->
</div><!-- #travelism_shop-recent-products_section -->
       
    <?php }
endif;