<?php
/**
 * subscribe_now section
 *
 * This is the template for the content of subscription section
 *
 * @package Theme Palace
 * @subpackage Travelism Pro
 * @since Travelism Pro 1.0.0
 */
if ( ! function_exists( 'travelism_pro_add_subscribe_now_section' ) ) :
    /**
    * Add subscription section
    *
    *@since Travelism Pro 1.0.0
    */
    function travelism_pro_add_subscribe_now_section() {
        $options = travelism_pro_get_theme_options();
        // Check if subscription is enabled on frontpage
        $subscribe_now_enable = apply_filters( 'travelism_pro_section_status', true, 'subscribe_now_section_enable' );

        if ( true !== $subscribe_now_enable ) {
            return false;
        }

        // Render subscription section now.
        travelism_pro_render_subscribe_now_section();
    }
endif;

if ( ! function_exists( 'travelism_pro_render_subscribe_now_section' ) ) :
  /**
   * Start subscription section
   *
   * @return string subscription content
   * @since Travelism Pro 1.0.0
   *
   */
   function travelism_pro_render_subscribe_now_section() {
        if ( ! class_exists( 'Jetpack' ) ) {
            return;
        } elseif ( class_exists( 'Jetpack' ) ) {
            if ( ! Jetpack::is_module_active( 'subscriptions' ) )
                return;
        }

        $options = travelism_pro_get_theme_options();
        $bg_image = ! empty( $options['subscribe_now_bg_image'] ) ? $options['subscribe_now_bg_image'] : '';
        $titles = ! empty( $options['subscribe_now_title'] ) ? $options['subscribe_now_title'] : '';
        $btn_label = ! empty( $options['subscribe_now_btn_title'] ) ? $options['subscribe_now_btn_title'] : '';

        ?>
        
        <div id="travelism_subscribe_now_section" class="relative page-section same-background">
            <div class="wrapper">
            <?php if ( is_customize_preview()):
                    travelism_pro_section_tooltip( 'travelism_subscribe_now_section' );
                    endif; ?>
                <article  style="background-image: url('<?php echo esc_url( $bg_image ); ?>');">
                    <div class="overlay"></div>
                    <div class="entry-container">
                        <?php if( !empty( $titles ) ): ?>
                            <div class="section-header">
                                <h2 class="section-title"><?php echo esc_html( $titles ); ?></h2>
                            </div><!-- .section-header -->
                        <?php endif; ?>

                        <div class="subscribe-form-wrapper">
                            <div class="jetpack_subscription_widget">
                                <?php 
                                $subscribe_now_shortcode = '[jetpack_subscription_form title="" subscribe_text="" subscribe_button="' . esc_html( $btn_label ) . '" show_subscribers_total="0"]';
                                echo do_shortcode( wp_kses_post( $subscribe_now_shortcode ) ); 
                                ?>

                            </div>
                        </div><!-- .subscribe-form-wrapper -->
                    </div>
                </article>
            </div><!-- .wrapper -->
        </div><!-- #travelism_subscribe_now_section -->
       
    <?php }
endif;
