<?php
/**
 * trending_product section
 *
 * This is the template for the content of trending_product section
 *
 * @package Theme Palace
 * @subpackage Travelism Pro
 * @since Travelism Pro 1.0.0
 */
if ( ! function_exists( 'travelism_pro_add_trending_products_section' ) ) :
    /**
    * Add trending_product section
    *
    *@since Travelism Pro 1.0.0
    */
    function travelism_pro_add_trending_products_section() {
        $options = travelism_pro_get_theme_options();
        // Check if trending_product is enabled on frontpage
        $trending_products_enable = apply_filters( 'travelism_pro_section_status', true, 'trending_products_section_enable' );

        if ( true !== $trending_products_enable ) {
            return false;
        }
        if ( !class_exists('WooCommerce') ) {
            return;
        }
        // Get trending_product section details
        $section_details = array();
        $section_details = apply_filters( 'travelism_pro_filter_trending_products_section_details', $section_details );

        if ( empty( $section_details ) ) {
            return;
        }

        // Render trending_product section now.
        travelism_pro_render_trending_products_section( $section_details );
    }
endif;

if ( ! function_exists( 'travelism_pro_get_trending_products_section_details' ) ) :
    /**
    * trending_product section details.
    *
    * @since Travelism Pro 1.0.0
    * @param array $input trending_product section details.
    */
    function travelism_pro_get_trending_products_section_details( $input ) {
        $options = travelism_pro_get_theme_options();
        $content = array();
        $content[1] = array();
        $content[2] = array();
        $content[3] = array();

        for ($i=1; $i <= 3 ; $i++) { 
                // Content type.
            $trending_products_content_type  = empty( $options['trending_content_type_'.$i] ) ? 'product' : $options['trending_content_type_'.$i];
            $trending_products_count = ! empty( $options['trending_products_count'] ) ? $options['trending_products_count'] : 3;

            switch ( $trending_products_content_type ) {

                case 'product':
                    $page_ids = array();

                    for ( $j = 1; $j <=  $options['trending_products_count']; $j++ ){
                        if ( ! empty( $options['trending_products_content_page_' . $i.$j] ) ){
                            $page_ids[] = $options['trending_products_content_page_' . $i.$j];
                        }
                        
                    }
                      
                    $args = array(
                        'post_type'         => 'product',
                        'post__in'          => ( array ) $page_ids,
                        'posts_per_page'    => $options['trending_products_count'],
                        'orderby'           => 'post__in',
                        );
                break;
                case 'product_cat':
                    $cat_id = ! empty( $options['trending_products_category_'.$i] ) ? $options['trending_products_category_'.$i] : '';

                    $args = array(
                    'post_type'         => 'product',
                    'posts_per_page'    => absint( $options['trending_products_count'] ),
                    'tax_query'         => array(
                        array(
                            'taxonomy'  => 'product_cat',
                            'field'     => 'id',
                            'terms'     => $cat_id
                        )
                    ) );
                break;

                default:
                break;
            }


            // Run The Loop.
            $query = new WP_Query( $args );
            if ( $query->have_posts() ) : 
 
                while ( $query->have_posts() ) : $query->the_post();
                    $page_post['id']        = get_the_id();
                    $page_post['title']     = get_the_title();
                    $page_post['url']       = get_the_permalink();
                    $page_post['image']     = has_post_thumbnail() ? get_the_post_thumbnail_url( get_the_id(), 'large' ) : get_template_directory_uri() . '/assets/uploads/no-featured-image-590x650.jpg';

                    // Push to the main array.
                    array_push( $content[$i], $page_post );
               
                endwhile;
            endif;
            wp_reset_postdata();
        }
            
        if ( ! empty( $content ) ) {
            $input = $content;
        }
        return $input;
    }
endif;
// trending_product section content details.
add_filter( 'travelism_pro_filter_trending_products_section_details', 'travelism_pro_get_trending_products_section_details' );


if ( ! function_exists( 'travelism_pro_render_trending_products_section' ) ) :
  /**
   * Start trending_product section
   *
   * @return string trending_product content
   * @since Travelism Pro 1.0.0
   *
   */
   function travelism_pro_render_trending_products_section( $content_details = array() ) {
        $options = travelism_pro_get_theme_options();

        if ( empty( $content_details ) ) {
            return;
        } ?>
        
        <div id="travelism_trending_products_section" class="relative page-section same-background">
            <div class="wrapper">
            <?php if ( is_customize_preview()):
                    travelism_pro_section_tooltip( 'travelism_trending_products_section' );
                    endif; ?>
                <div class="section-content clear">

                    <?php for ( $i=1; $i <=3 ; $i++) { 
                        $title = empty( $options['trending_products_title_'.$i] ) ? '' : $options['trending_products_title_'.$i];
                        ?>
                        <div class="product-wrapper">
                            <h2 class="category-title"><?php echo esc_html( $title ) ; ?></h2>
                            <div class="product-items">

                                <?php foreach ($content_details[$i] as $content): 
                                $image = $content['image'] == '' ? get_template_directory_uri().'/assets/uploads/no-featured-image-590x650.jpg' : $content['image'] ;
                                ?>

                                <article>
                                    <div class="featured-image">
                                        <a href="<?php echo esc_url( $content['url'] ) ; ?>"><img src="<?php echo esc_url( $image );?>"></a>
                                    </div><!-- .featured-image -->

                                    <div class="entry-container">
                                        <span class="cat-links">
                                            <ul class="post-categories">
                                                <?php 
                                                $terms = get_the_terms ( $content['id'], 'product_cat' );
                                                foreach ( $terms as $term ) { ?>
                                                <li class="posted_in">
                                                    <a href="<?php echo esc_url( get_term_link( $term->term_id, 'product_cat' ) ) ?>"><?php echo esc_html( $term->name) ; ?></a>
                                                </li><!-- .posted_in -->

                                                <?php } ?>
                                            </ul>
                                        </span><!-- .cat-links -->

                                        <header class="entry-header">
                                            <h2 class="entry-title"><a href="<?php echo esc_url( $content['url'] ) ; ?>"><?php echo esc_html( $content['title'] ) ; ?></a></h2>
                                        </header>

                                        <span class="price">
                                            <?php 
                                            $product = new WC_Product( $content['id'] );
                                            echo $product->get_price_html();
                                            ?>
                                        </span><!-- .price -->
                                    </div><!-- .entry-container -->
                                </article>

                            <?php endforeach; ?>

                        </div><!-- .product-items -->
                    </div><!-- .product-wrapper -->

                    <?php } ?> 

                </div><!-- .section-content -->
            </div><!-- .wrapper -->
        </div><!-- #travelism_trending_products_section -->
       
    <?php }
endif;