<?php
/**
 * Video section
 *
 * This is the template for the content of video section
 *
 * @package Theme Palace
 * @subpackage Travelism Pro
 * @since Travelism Pro 1.0.0
 */
if ( ! function_exists( 'travelism_pro_add_video_section' ) ) :
    /**
    * Add video section
    *
    *@since Travelism Pro 1.0.0
    */
    function travelism_pro_add_video_section() {
    	$options = travelism_pro_get_theme_options();
        // Check if video is enabled on frontpage
        $video_enable = apply_filters( 'travelism_pro_section_status', true, 'video_section_enable' );

        if ( true !== $video_enable ) {
            return false;
        }
        // Get video section details
        $section_details = array();
        $section_details = apply_filters( 'travelism_pro_filter_video_section_details', $section_details );

        if ( empty( $section_details ) ) {
            return;
        }

        // Render video section now.
        travelism_pro_render_video_section( $section_details );
    }
endif;

if ( ! function_exists( 'travelism_pro_get_video_section_details' ) ) :
    /**
    * video section details.
    *
    * @since Travelism Pro 1.0.0
    * @param array $input video section details.
    */
    function travelism_pro_get_video_section_details( $input ) {
        $options = travelism_pro_get_theme_options();

        // Content type.
        $video_content_type  = $options['video_content_type'];
        $video_count = ! empty( $options['video_count'] ) ? $options['video_count'] : 3;
        
        $content = array();
        switch ( $video_content_type ) {
        	
            case 'page':
                $page_ids = array();

                for ( $i = 1; $i <= $video_count; $i++ ) {
                    if ( ! empty( $options['video_content_page_' . $i] ) )
                        $page_ids[] = $options['video_content_page_' . $i];
                }
                
                $args = array(
                    'post_type'         => 'page',
                    'post__in'          => ( array ) $page_ids,
                    'posts_per_page'    => absint( $video_count ),
                    'orderby'           => 'post__in',
                    );                    
            break;

            case 'post':
                $post_ids = array();

                for ( $i = 1; $i <= $video_count; $i++ ) {
                    if ( ! empty( $options['video_content_post_' . $i] ) )
                        $post_ids[] = $options['video_content_post_' . $i];
                }
                $args = array(
                    'post_type'         => 'post',
                    'post__in'          => ( array ) $post_ids,
                    'posts_per_page'    => absint( $video_count ),
                    'orderby'           => 'post__in',
                    'ignore_sticky_posts'   => true,
                    );                    
            break;

            case 'category':
                $cat_id = ! empty( $options['video_content_category'] ) ? $options['video_content_category'] : '';
                $args = array(
                    'post_type'         => 'post',
                    'posts_per_page'    => absint( $video_count ),
                    'cat'               => absint( $cat_id ),
                    'ignore_sticky_posts'   => true,
                    );                    
            break;

            case 'trip':
                if ( ! class_exists( 'WP_Travel' ) )
                    return;

                $page_ids = array();

                for ( $i = 1; $i <= $video_count; $i++ ) {
                    if ( ! empty( $options['video_content_trip_' . $i] ) )
                        $page_ids[] = $options['video_content_trip_' . $i];
                }
                
                $args = array(
                    'post_type'         => 'itineraries',
                    'post__in'          => ( array ) $page_ids,
                    'posts_per_page'    => absint( $video_count ),
                    'orderby'           => 'post__in',
                    );                    
            break;

            case 'trip-types':
                if ( ! class_exists( 'WP_Travel' ) )
                    return;

                $cat_id = ! empty( $options['video_content_trip_types'] ) ? $options['video_content_trip_types'] : '';
                $args = array(
                    'post_type'      => 'itineraries',
                    'tax_query' => array(
                        array(
                            'taxonomy' => 'itinerary_types',
                            'field'    => 'id',
                            'terms'    => $cat_id,
                        ),
                    ),
                    'posts_per_page'  => absint( $video_count ),
                    );                    
            break;

            case 'destination':
                if ( ! class_exists( 'WP_Travel' ) )
                    return;

                $cat_id = ! empty( $options['video_content_destination'] ) ? $options['video_content_destination'] : '';
                $args = array(
                    'post_type'      => 'itineraries',
                    'tax_query' => array(
                        array(
                            'taxonomy' => 'travel_locations',
                            'field'    => 'id',
                            'terms'    => $cat_id,
                        ),
                    ),
                    'posts_per_page'  => absint( $video_count ),
                    );                    
            break;

            case 'activity':
                if ( ! class_exists( 'WP_Travel' ) )
                    return;
                
                $cat_id = ! empty( $options['video_content_activity'] ) ? $options['video_content_activity'] : '';
                $args = array(
                    'post_type'      => 'itineraries',
                    'tax_query' => array(
                        array(
                            'taxonomy' => 'activity',
                            'field'    => 'id',
                            'terms'    => $cat_id,
                        ),
                    ),
                    'posts_per_page'  => absint( $video_count ),
                    );                    
            break;

            default:
            break;
        }


            // Run The Loop.
            $query = new WP_Query( $args );
            if ( $query->have_posts() ) : 
                while ( $query->have_posts() ) : $query->the_post();
                    $page_post['id']        = get_the_id();
                    $page_post['title']     = get_the_title();
                    $page_post['url']       = get_the_permalink();
                    $page_post['excerpt']   = travelism_pro_trim_content( $options['video_excerpt_length'] );
                    $page_post['image']  	= has_post_thumbnail() ? get_the_post_thumbnail_url( get_the_id(), 'full' ) : '';

                    // Push to the main array.
                    array_push( $content, $page_post );
                endwhile;
            endif;
            wp_reset_postdata();
            
        if ( ! empty( $content ) ) {
            $input = $content;
        }
        return $input;
    }
endif;
// video section content details.
add_filter( 'travelism_pro_filter_video_section_details', 'travelism_pro_get_video_section_details' );


if ( ! function_exists( 'travelism_pro_render_video_section' ) ) :
  /**
   * Start video section
   *
   * @return string video content
   * @since Travelism Pro 1.0.0
   *
   */
   function travelism_pro_render_video_section( $content_details = array() ) {
        $options = travelism_pro_get_theme_options();
        $video_content_type     = $options['video_content_type'];
        $section_bg_image       = !empty($options['video_bg_image']) ? $options['video_bg_image'] : '';
        $video_sub_title        = !empty($options['video_sub_title']) ? $options['video_sub_title'] : '';
        $video_title            = !empty($options['video_title']) ? $options['video_title'] : '';
        $video_btn_label        = !empty($options['video_btn_label']) ? $options['video_btn_label'] : '';
        $video_url = ! empty( $options['video_url'] ) ? $options['video_url'] : '';

        if ( empty( $content_details ) ) {
            return;
        } ?>
        
        <div id="travelism_video_section" class="relative page-section" style="background-image: url('<?php echo esc_url( $section_bg_image ); ?>');">
                <div class="overlay"></div>
                <div class="wrapper">
                 <?php if ( is_customize_preview()):
                    travelism_pro_section_tooltip( 'travelism_video_section' );
                    endif; ?>
                    <div class="main-video">
                        <div class="section-header">
                           <?php if( !empty( $video_sub_title ) ): ?>
                            <p class="section-subtitle"><?php echo esc_html( $video_sub_title ); ?></p>
                        <?php endif;

                            if( !empty( $video_title ) ):
                         ?>
                            <h2 class="section-title"><?php echo esc_html( $video_title ); ?></h2>

                        <?php endif; ?>
                        </div>
                        <?php if( !empty( $video_url ) ): ?>
                        <div class="video-button">
                            <a href="<?php echo esc_url( $video_url ); ?>" class="popup-video"><i class="fa fa-play"></i></a>
                        </div><!-- .video-button -->
                    <?php endif; ?>
                    </div>
                    <div class="video-showcase">

                    <?php $i = 1; foreach ( $content_details as $content ) : ?>

                        <article class="has-post-thumbnail">
                            <div class="featured-image" style="background-image: url('<?php echo esc_url( $content['image'] ); ?>');">
                                <div class="overlay"></div>
                            </div>

                            <?php if( !empty( $options['post_video_url_'.$i] ) ): ?>

                            <div class="video-button">
                                <a href="<?php echo esc_url( $options['post_video_url_'.$i] ); ?>" class="popup-video"><i class="fa fa-play"></i></a>
                            </div><!-- .video-button -->

                        <?php endif; ?>

                            <div class="entry-container">
                                <header class="entry-header">
                                    <h2 class="entry-title"><a href="<?php echo esc_url( $content['url'] ); ?>"><?php echo esc_html( $content['title'] ); ?></a></h2>
                                </header>

                                <div class="entry-content">
                                    <p><?php echo esc_html( $content['excerpt'] ); ?></p>
                                </div><!-- .entry-content -->

                                <?php if( !empty( $video_btn_label ) ): ?>
                                <div class="read-story">
                                    <a href="<?php echo esc_url( $content['url'] ); ?>"><?php echo esc_html( $video_btn_label ); ?></a>
                                </div>
                            <?php endif; ?>
                            </div>
                        </article>

                    <?php $i++; endforeach; ?>

                    </div>
                </div>   
            </div><!-- #travelism_video_section -->
       
    <?php }
endif;